<?xml version="1.0" encoding="UTF-8"?>
<!-- 
    Implementatiehandleiding HL7v3 Basiscomponenten, v2.2 - Alle genoemde datatypen
    Status: in behandeling
-->
<pattern abstract="true" id="DTr1" see="http://hl7book.net/index.php?title=DatatypesR1" xmlns="http://purl.oclc.org/dsdl/schematron">

    <rule abstract="true" id="AD" see="http://hl7book.net/index.php?title=DatatypesR1:AD">
        <!-- Test op mixed content en lege adressen -->
        <assert test="(count(*)>0 and string-length(normalize-space(text()[1]))=0) or count(*)=0">Datatype AD: adres geheel in tekst of geheel in
            elementen (geen mixed content)</assert>
        <assert test="not(@nullFlavor) or (not(thumbnail) or useablePeriod/@nullFlavor)">Datatype AD: no useablePeriod if null</assert>
        <assert test="count(*[self::useablePeriod][@validTimeLow or @validTimeHigh or @controlActRoot or @controlActExtension or @updateMode])=0"
            >Datatype AD: no updateMode or History on AD attributes</assert>

        <!-- Test formaat postcode -->
        <let name="postalCode" value="hl7:postalCode/text()"/>
        <let name="countryCode" value="hl7:country/@code"/>
        <let name="countryCodeSystem" value="hl7:country/@codeSystem"/>
        <let name="countryText" value="upper-case(normalize-space(hl7:country))"/>
        <!-- Zonder het bogus statement 1=1 in de else clause gaat de if verkeerd ?! -->
        <assert
            test="if (hl7:postalCode and (not(hl7:country) or 
            ($countryCode='NL' and ($countryCodeSystem='2.16.1' or $countryCodeSystem='1.3.6.1.4.1.1466.115.121.1.11' or $countryCodeSystem='1.0.3166.1.2.2')) or
            ($countryCode='NLD' and $countryCodeSystem='2.16.2') or
            ($countryCode='528' and $countryCodeSystem='2.16.3') or
            $countryText='NL' or
            $countryText='NLD' or
            $countryText='NEDERLAND'
            )) then ( matches($postalCode,'^[0-9]{4} [A-Z]{2}$')
            ) else (
            1=1
            )"
            >Datatype AD: ongeldig formaat '<value-of select="hl7:postalCode"/>' voor een Nederlandse postcode. Moet zijn 'nnnn AA'.</assert>

        <let name="illegalAddressPart"
            value="*[local-name(.)!='delimiter' and
            local-name(.)!='country' and local-name(.)!='county' and
            local-name(.)!='city' and local-name(.)!='postalCode' and
            local-name(.)!='houseNumber' and local-name(.)!='streetName' and
            local-name(.)!='additionalLocator'][1]/name()"/>
        <assert test="count(*)=0 or string-length($illegalAddressPart)=0">Datatype AD: ongeldig adresdeel '<value-of select="$illegalAddressPart"/>'.
            Alleen delimiter, country, county, city, postalCode, houseNumber, streetName en additionalLocator zijn toegestaan </assert>

        <assert test="count(*)=0 or count(*[not(local-name(.)='country') and @code])=0">Datatype AD: ongeldig adresdeel '<value-of
                select="*[not(local-name(.)='country') and @code][1]/name()"/>'. Alleen country kan attribuut code hebben</assert>

    </rule>

    <rule abstract="true" id="BL" see="http://hl7book.net/index.php?title=DatatypesR1:BL">
        <assert test="@nullFlavor or (not(@nullFlavor) and @value)">Datatype BL: value or null</assert>
    </rule>

    <rule abstract="true" id="CS" see="http://hl7book.net/index.php?title=DatatypesR1:CS">
        <assert test="@nullFlavor or (not(@nullFlavor) and @code)">Datatype CS: code is required</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@code))">Datatype CS: no code if null</assert>
    </rule>

    <rule abstract="true" id="CV" see="http://hl7book.net/index.php?title=DatatypesR1:CV">
        <extends rule="CS"/>
        <assert
            test="@nullFlavor or @code or (originalText and not(originalText/@nullFlavor)) or (originalTextReference and not(originalTextReference/@nullFlavor))"
            >Datatype CV: null or code and/or originalText</assert>
        <assert test="@nullFlavor != &#34;OTH&#34; or @codeSystem or @valueSet">Datatype CV: other requires codeSystem or valueSet</assert>
        <assert test="@codeSystem or not(@code)">Datatype CV: code requires codeSystem</assert>
        <assert test="@codeSystem or not(@codeSystemName)">Datatype CV: codeSystemName only if codeSystem</assert>
        <assert test="@codeSystem or not(@codeSystemVersion)">Datatype CV: codeSystemVersion only if codeSystem</assert>
        <assert test="@code or not(@displayName)">Datatype CV: displayName only if code</assert>
        <assert test="not(@valueSet) or (@valueSet and @valueSetVersion)">Datatype CV: valueSet requires valueSetVersion</assert>
        <assert test="not(translation/originalText)">Datatype CV: no originalText on translations</assert>
        <assert
            test="count(*[self::displayName or self::originalText or self::originalTextReference or self::translation][@validTimeLow or @validTimeHigh or @controlActRoot or @controlActExtension or @updateMode])=0"
            >Datatype CV: no updateMode or history on CD elements</assert>
        <assert test="not(@nullFlavor) or (not(thumbnail) or code/@nullFlavor)">Datatype CV: no code if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@displayName))">Datatype CV: no displayName if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@source))">Datatype CV: no source if null</assert>

        <assert test="not(translation)">Datatype CV: no translation</assert>
        <assert test="not(qualifier)">Datatype CV: no qualifier</assert>
    </rule>

    <rule abstract="true" id="CE" see="http://hl7book.net/index.php?title=DatatypesR1:CE">
        <extends rule="CV"/>
        <assert
            test="@nullFlavor or @code or (originalText and not(originalText/@nullFlavor)) or (originalTextReference and not(originalTextReference/@nullFlavor))"
            >Datatype CE: null or code and/or originalText</assert>
        <assert test="@nullFlavor!= &#34;OTH&#34; or @codeSystem or @valueSet">Datatype CE: other requires codeSystem or valueSet</assert>
        <assert test="@codeSystem or not(@code)">Datatype CE: code requires codeSystem</assert>
        <assert test="@codeSystem or not(@codeSystemName)">Datatype CE: codeSystemName only if codeSystem</assert>
        <assert test="@codeSystem or not(@codeSystemVersion)">Datatype CE: codeSystemVersion only if codeSystem</assert>
        <assert test="@code or not(@displayName)">Datatype CE: displayName only if code</assert>
        <assert test="not(@valueSet) or (@valueSet and @valueSetVersion)">Datatype CE: valueSet requires valueSetVersion</assert>
        <assert test="not(translation/originalText)">Datatype CE: no originalText on translations</assert>
        <assert test="not(translation/translation)">Datatype CE: translations cannot have translations</assert>
        <assert
            test="count(*[self::displayName or self::originalText or self::originalTextReference or self::translation][@validTimeLow or @validTimeHigh or @controlActRoot or @controlActExtension or @updateMode])=0"
            >Datatype CE: no updateMode or history on CE elements</assert>
        <assert test="not(@nullFlavor) or (not(thumbnail) or code/@nullFlavor)">Datatype CE: no code if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@displayName))">Datatype CE: no displayName if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@source))">Datatype CE: no source if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@qualifier))">Datatype CE: no qualifier if null</assert>

        <assert test="not(qualifier)">Datatype CE: no qualifier</assert>
    </rule>

    <rule abstract="true" id="CO" see="http://hl7book.net/index.php?title=DatatypesR1:CO">
        <extends rule="CV"/>
        <assert
            test="@nullFlavor or @code or (originalText and not(originalText/@nullFlavor)) or (originalTextReference and not(originalTextReference/@nullFlavor))"
            >Datatype CO: null or code and/or originalText</assert>
        <assert test="@nullFlavor != &#34;OTH&#34; or @codeSystem or @valueSet">Datatype CO: other requires codeSystem or valueSet</assert>
        <assert test="@codeSystem or not(@code)">Datatype CO: code requires codeSystem</assert>
        <assert test="@codeSystem or not(@codeSystemName)">Datatype CO: codeSystemName only if codeSystem</assert>
        <assert test="@codeSystem or not(@codeSystemVersion)">Datatype CO: codeSystemVersion only if codeSystem</assert>
        <assert test="@code or not(@displayName)">Datatype CO: displayName only if code</assert>
        <assert test="not(@valueSet) or (@valueSet and @valueSetVersion)">Datatype CO: valueSet requires valueSetVersion</assert>
        <assert test="not(translation/originalText)">Datatype CO: no originalText on translations</assert>
        <assert
            test="count(*[self::displayName or self::originalText or self::originalTextReference or self::translation][@validTimeLow or @validTimeHigh or @controlActRoot or @controlActExtension or @updateMode])=0"
            >Datatype CO: no updateMode or history on CO elements</assert>
        <assert test="not(@nullFlavor) or (not(thumbnail) or code/@nullFlavor)">Datatype CO: no code if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@displayName))">Datatype CO: no displayName if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@source))">Datatype CO: no source if null</assert>

        <assert test="not(translation)">Datatype CO: no translation</assert>
        <assert test="not(qualifier)">Datatype CO: no qualifier</assert>

    </rule>

    <rule abstract="true" id="CD" see="http://hl7book.net/index.php?title=DatatypesR1:CD">
        <extends rule="CE"/>
        <assert
            test="@nullFlavor or @code or (originalText and not(originalText/@nullFlavor)) or (originalTextReference and not(originalTextReference/@nullFlavor))"
            >Datatype CD: null or code and/or originalText</assert>
        <assert test="@nullFlavor != 'OTH' or @codeSystem or @valueSet">Datatype CD: other requires codeSystem or valueSet</assert>
        <assert test="@codeSystem or not(@code)">Datatype CD: code requires codeSystem</assert>
        <assert test="@codeSystem or not(@codeSystemName)">Datatype CD: codeSystemName only if codeSystem</assert>
        <assert test="@codeSystem or not(@codeSystemVersion)">Datatype CD: codeSystemVersion only if codeSystem</assert>
        <assert test="@code or not(@displayName)">Datatype CD: displayName only if code</assert>
        <assert test="not(translation/originalText)">Datatype CD: no original text on translations</assert>
        <assert test="not(translation/translation)">Datatype CD: translations cannot have translations</assert>
        <assert test="not(@nullFlavor) or (not(thumbnail) or code/@nullFlavor)">Datatype CD: no code if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@displayName))">Datatype CD: no displayName if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@qualifier))">Datatype CD: no qualifier if null</assert>

        <assert test="@codeSystem and doc-available(concat('../vocab/',@codeSystem,'.xml'))">Datatype CD: warning: unknown codeSystem '<value-of
                select="@codeSystem"/>'</assert>
    </rule>

    <rule abstract="true" id="ED" see="http://hl7book.net/index.php?title=DatatypesR1:ED">
        <assert test="@nullFlavor or text() or reference">Datatype ED: content is required if not null</assert>
        <assert test="not(integrityCheck) or @integrityCheckAlgorithm">Datatype ED: integrityCheckAlgorithm required if integrityCheck</assert>
        <assert test="not(thumbnail) or thumbnail[not(@nullFlavor and reference)]">Datatype ED: thumbnails do not use reference</assert>
        <assert test="not(thumbnail) or thumbnail[not(thumbnail)]">Datatype ED: thumbnails do not have thumbnails</assert>
        <assert test="(@compression and (reference/@value or (@representation='B64' and text()))) or not(@compression)">Datatype ED: compression only
            on binary</assert>

        <!--assert test="@mediaType">Datatype ED: mediaType cannot be null</assert-->

        <assert test="not(@value) or (@value and (not(@mediaType) or @mediaType='text/plain'))">Datatype ED: value implies mediaType is
            text/plain</assert>
        <assert
            test="count(*[self::reference or self::thumbnail][@validTimeLow or @validTimeHigh or @controlActRoot or @controlActExtension or @updateMode])=0"
            >Datatype ED: no history or updateMode</assert>
        <assert test="not(@value or xml) or not(@charset)">Datatype ED: no charset for value or xml</assert>
        <assert test="not(translation) or thumbnail[not(translation)]">Datatype ED: no nested translations</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@mediaType))">Datatype ED: no mediaType if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@charset))">Datatype ED: no charset if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@language))">Datatype ED: no language if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@compression))">Datatype ED: no compression if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheck))">Datatype ED: no integrityCheck if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@integrityCheckAlgorithm))">Datatype ED: no integrityCheckAlgorithm if null</assert>
        <assert test="not(@nullFlavor) or (not(thumbnail) or thumbnail/@nullFlavor)">Datatype ED: no thumbnail if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@translation))">Datatype ED: no translation if null</assert>

        <let name="mediaType" value="@mediaType"/>
        <assert test="not(@mediaType) or document('../vocab/ED.mediaType.xml')/*/hl7:code[@code=$mediaType]">Datatype ED: unsupported mediaType value
                '<value-of select="$mediaType"/>'</assert>

        <assert test="not(thumbnail)">Datatype ED: thumbnail is in Nederland vooralsnog niet toegestaan</assert>
    </rule>

    <rule abstract="true" id="EIVL_TS" see="http://hl7book.net/index.php?title=DatatypesR1:EIVL_TS">
        <assert test="@nullFlavor or (event)">Datatype EIVL_TS: required attributes</assert>
        <assert test="count(*[self::offset][@validTimeLow or @validTimeHigh or @controlActRoot or @controlActExtension or @updateMode])=0">Datatype
            EIVL_TS: no updateMode or history on EIVL attributes</assert>
    </rule>

    <rule abstract="true" id="GTS" see="http://hl7book.net/index.php?title=DatatypesR1:GTS">
        <!-- TODO -->
    </rule>

    <rule abstract="true" id="II" see="http://hl7book.net/index.php?title=DatatypesR1:II">
        <assert test="@nullFlavor or (not(@nullFlavor) and @root)">Datatype II: root is required if not null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@root))">Datatype II: no root if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@extension))">Datatype II: no extension if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@identifierName))">Datatype II: no identifierName if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@displayable))">Datatype II: no displayable if null</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@reliability))">Datatype II: no reliability if null</assert>

        <assert test="not(@nullFlavor) or (@nullFlavor and not(@assigningAuthorityName))">Datatype II: no assigningAuthorityName if null</assert>

        <!-- 
            Issue 27375
            DICOM heeft een maximum van 64 tekens op een OID
            Canada hanteert 200 tekens op OID's
        -->
        <report test="not(string-length(@root) &lt;= 64)">attribuut root is langer dan 64 tekens. Er is nog geen maximum gesteld, maar
            hier is wel naar gevraagd. Gaarne melden als deze waarschuwing verschijnt, omdat huidige waarde dan blijkbaar te klein is</report>

        <report test="not(string-length(@extension) &lt;= 64)">attribuut extension is langer dan 64 tekens. Er is nog geen maximum
            gesteld, maar hier is wel naar gevraagd. Gaarne melden als deze waarschuwing verschijnt, omdat huidige waarde dan blijkbaar te klein
            is</report>
    </rule>

    <rule abstract="true" id="INT" see="http://hl7book.net/index.php?title=DatatypesR1:INT">
        <assert test="not(uncertainty)">Datatype INT: no uncertainty</assert>
        <assert test="(@nullFlavor or @value) and not(@nullFlavor and @value)">Datatype INT: null or value</assert>
    </rule>

    <rule abstract="true" id="IVL_INT" see="http://hl7book.net/index.php?title=DatatypesR1:IVL_INT">
        <assert test="(@nullFlavor and not(any|hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and (any|hl7:low|hl7:high|hl7:width))">Datatypes
            IVL_INT: null rules</assert>
        <assert
            test="(((any and not(any/@nullFlavor)) and not((hl7:low and not(hl7:low/@nullFlavor)) or (hl7:high and not(hl7:high/@nullFlavor)) or (hl7:width and not(hl7:width/@nullFlavor)))) or (not(any) or any/@nullFlavor)) and ((any and not(any/@nullFlavor)) or (not(any) or any/@nullFlavor) and (((hl7:width and not(hl7:width/@nullFlavor)) and (not(hl7:low) or hl7:low/@nullFlavor) and (not(hl7:high) or hl7:high/@nullFlavor))) or ((not(hl7:width) or hl7:width/@nullFlavor) and ((hl7:low and not(hl7:low/@nullFlavor)) or (hl7:high and not(hl7:high/@nullFlavor))))))"
            >Datatype IVL_INT: co-occurence rules</assert>
        <assert test="not(hl7:low and @hl7:lowClosed) and not(hl7:high and @hl7:highClosed)">Datatype IVL_INT: closed attributes only if
            limited</assert>
        <assert
            test="count(*[self::hl7:low or self::hl7:high or self::hl7:width][@validTimehl7:low or @validTimehl7:high or @controlActRoot or @controlActExtension or @updateMode])=0"
            >Datatype IVL_INT: no updateMode or history on IVL attributes</assert>
    </rule>

    <rule abstract="true" id="IVL_PQ" see="http://hl7book.net/index.php?title=DatatypesR1:IVL_PQ">
        <assert test="(@nullFlavor and not(any|hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and (any|hl7:low|hl7:high|hl7:width))">Datatypes
            IVL_PQ: null rules</assert>
        <assert
            test="(((any and not(any/@nullFlavor)) and not((hl7:low and not(hl7:low/@nullFlavor)) or (hl7:high and not(hl7:high/@nullFlavor)) or (hl7:width and not(hl7:width/@nullFlavor)))) or (not(any) or any/@nullFlavor)) and ((any and not(any/@nullFlavor)) or (not(any) or any/@nullFlavor) and (((hl7:width and not(hl7:width/@nullFlavor)) and (not(hl7:low) or hl7:low/@nullFlavor) and (not(hl7:high) or hl7:high/@nullFlavor))) or ((not(hl7:width) or hl7:width/@nullFlavor) and ((hl7:low and not(hl7:low/@nullFlavor)) or (hl7:high and not(hl7:high/@nullFlavor))))))"
            >Datatype IVL_PQ: co-occurence rules</assert>
        <assert test="not(hl7:low and @hl7:lowClosed) and not(hl7:high and @hl7:highClosed)">Datatype IVL_PQ: closed attributes only if
            limited</assert>
        <assert
            test="count(*[self::hl7:low or self::hl7:high or self::hl7:width][@validTimehl7:low or @validTimehl7:high or @controlActRoot or @controlActExtension or @updateMode])=0"
            >Datatype IVL_PQ: no updateMode or history on IVL attributes</assert>
    </rule>

    <rule abstract="true" id="IVL_TS" see="http://hl7book.net/index.php?title=DatatypesR1:IVL_TS">
        <assert test="(@nullFlavor and not(any|hl7:low|hl7:high|hl7:width)) or (not(@nullFlavor) and (any|hl7:low|hl7:high|hl7:width))">Datatype
            IVL_TS: null rules</assert>
        <assert
            test="(((any and not(any/@nullFlavor)) and not((hl7:low and not(hl7:low/@nullFlavor)) or (hl7:high and not(hl7:high/@nullFlavor)) or 
            (hl7:width and not(hl7:width/@nullFlavor)))) or (not(any) or any/@nullFlavor)) and ((any and not(any/@nullFlavor)) or 
            (not(any) or any/@nullFlavor) and (((hl7:width and not(hl7:width/@nullFlavor)) and (not(hl7low) or hl7:low/@nullFlavor) and 
            (not(hl7:high) or hl7:high/@nullFlavor))) or ((not(hl7:width) or hl7:width/@nullFlavor) and ((hl7:low and not(hl7:low/@nullFlavor)) or 
            (hl7:high and not(hl7:high/@nullFlavor)))))"
            >Datatype IVL_TS: co-occurence rules</assert>
        <assert test="not(low and @lowClosed) and not(high and @highClosed)">Datatype IVL_TS:closed attributes only if limited</assert>
        <assert
            test="count(*[self::low or self::high or self::width][@validTimeLow or @validTimeHigh or @controlActRoot or @controlActExtension or @updateMode])=0"
            >Datatype IVL_TS: no updateMode or history on IVL attributes</assert>
    </rule>

    <rule abstract="true" id="MO" see="http://hl7book.net/index.php?title=DatatypesR1:MO">
        <assert test="(@nullFlavor or @value) and not(@nullFlavor and @value)">Datatype MO: null or value</assert>
        <assert test="(@nullFlavor or @currency) and not(@nullFlavor and @currency)">Datatype MO: null or currency</assert>
    </rule>

    <rule abstract="true" id="ON" see="http://hl7book.net/index.php?title=DatatypesR1:ON">
        <assert test="count(part[type = 'FAM' or type = 'GIV'])=0">Datatype ON: no parts may be person types</assert>
        <assert test="(@nullFlavor or part) and not(@nullFlavor and part)">Datatype ON: null or parts</assert>
    </rule>

    <rule abstract="true" id="PIVL_TS" see="http://hl7book.net/index.php?title=DatatypesR1:PIVL_TS">
        <assert test="not(period) or not(frequency)">Datatype PIVL_TS: period or frequency</assert>
        <assert
            test="count(*[self::phase or self::period][@validTimeLow or @validTimeHigh or @controlActRoot or @controlActExtension or @updateMode])=0"
            >Datatype PIVL_TS: no updateMode or history on PIVL attributes</assert>
    </rule>

    <rule abstract="true" id="PN" see="http://hl7book.net/index.php?title=DatatypesR1:PN">
        <assert test="count(part[contains(@qualifier, 'LS')])=0">Datatype PN: no parts are qualified by LS</assert>
        <assert test="(@nullFlavor or part) and not(@nullFlavor and part)">Datatype PN: null or parts</assert>
    </rule>

    <rule abstract="true" id="PQ" see="http://hl7book.net/index.php?title=DatatypesR1:PQ">
        <assert test="(@nullFlavor or @value) and not(@nullFlavor and (@value or @specialValue))">Datatype PQ: null or value</assert>
        <assert test="not(@nullFlavor) or (@nullFlavor and not(@translation))">Datatype PQ: no translation if null</assert>
    </rule>

    <rule abstract="true" id="QTY" see="http://hl7book.net/index.php?title=DatatypesR1:QTY">
        <assert test="not(uncertainty/@expression) and not(uncertainty/@uncertainty) and not(uncertainty/@originalText)">Datatype QTY: no
            uncertainty</assert>
        <assert
            test="count(*[self::originalText or self::uncertainty or self::expression][@validTimeLow or @validTimeHigh or @controlActRoot or @controlActExtension or @updateMode])=0"
            >Datatype QTY: no history or updateMode</assert>
    </rule>

    <rule abstract="true" id="REAL" see="http://hl7book.net/index.php?title=DatatypesR1:REAL">
        <assert test="(@nullFlavor or @value) and not(@nullFlavor and @value)">Datatype REAL: null or value</assert>
    </rule>

    <rule abstract="true" id="RTO" see="http://hl7book.net/index.php?title=DatatypesR1:RTO">
        <assert test="@nullFlavor or ((numerator and not(numerator/@nullFlavor)) and (numerator and not(numerator/@nullFlavor)))">Datatype RTO:
            numerator and denominator required</assert>
        <assert
            test="count(*[self::numerator or self::denominator][@validTimeLow or @validTimeHigh or @controlActRoot or @controlActExtension or @updateMode])=0"
            >Datatype RTO: no updateMode or History on RTO Attributes</assert>
        <assert test="not(uncertainty)">Datatype RTO: no uncertainty</assert>
    </rule>

    <rule abstract="true" id="SC" see="http://hl7book.net/index.php?title=DatatypesR1:SC">
        <assert test="not(@nullFlavor) or (not(code) or (code/@nullFlavor))">Datatype SC: no code if no value</assert>
        <assert test="count(*[self::code][@validTimeLow or @validTimeHigh or @controlActRoot or @controlActExtension or @updateMode])=0">Datatype SC:
            no updateMode or history on SC attributes</assert>
        <assert test="(not(originalText) or not(originalText/@nullFlavor)) or (not(code) or (code/@nullFlavor))">Datatype SC: no originalText</assert>
    </rule>

    <rule abstract="true" id="ST" see="http://hl7book.net/index.php?title=DatatypesR1:ST">
        <assert test="not(translation) or thumbnail[not(translation)]">Datatype ST: no nested translations</assert>
        <assert test="(@nullFlavor or (@value and string-length(@value)&amp;gt;0)) and not(@nullFlavor and @value)">Datatype ST: null or
            content</assert>
    </rule>

    <rule abstract="true" id="TEL" see="http://hl7book.net/index.php?title=DatatypesR1:TEL">
        <let name="urlScheme" value="substring-before(@value,':')"/>
        <assert test="@value and document('../vocab/URL.urlScheme.xml')/*/hl7:code[@code=$urlScheme]">Datatype TEL: unsupported URL scheme value
                '<value-of select="$urlScheme"/>'</assert>

        <assert test="@value=iri-to-uri(@value)">Datatype TEL: value must be a valid URI, e.g. '<value-of select="iri-to-uri(@value)"/>'.</assert>
    </rule>

    <rule abstract="true" id="TS" see="http://hl7book.net/index.php?title=DatatypesR1:TS">
        <assert test="(@nullFlavor or @value) and not(@nullFlavor and @value)">Datatype TS: null or value</assert>
    </rule>

    <rule abstract="true" id="URL" see="http://hl7book.net/index.php?title=DatatypesR1:URL">
        <let name="urlScheme" value="substring-after(@value,':')"/>
        <assert test="if (@value) then (document('../vocab/URL.urlScheme.xml')/*/hl7:code[@code=$urlScheme])">Datatype URL: unsupported URL scheme
            value '<value-of select="$urlScheme"/>'</assert>
    </rule>

    <!-- End abstracts -->

    <rule context="$element">
        <extends rule="$dt"/>
    </rule>

</pattern>
