<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="urn:Nictiz.AORTA.CareApplicationData" prefix="cad"/>
    <ns uri="urn:Nictiz.AORTA.XISApplicationData" prefix="xad"/>
    <let name="interactionVocabFile" value="'../../vocab/2.16.840.1.113883.1.6.xml'"/>
    <let name="profileFile" value="'../../vocab/2.16.840.1.113883.2.4.3.11.1.xml'"/>
    <let name="systeemrolFile" value="'../../vocab/2.16.840.1.113883.2.4.3.11.3.xml'"/>
    <let name="schemaDir" value="'../../schemas'"/>
    
    <pattern>
        <title>CareApplicationRole</title>
        <rule context="/cad:CareApplicationData/cad:CareApplicationRole/cad:CARName">
            <let name="systeemrolId" value="."/>
            <assert role="error" test="document($systeemrolFile)/*/hl7:code[@code=$systeemrolId]"
                >CARName <value-of select="$systeemrolId"/> moet bestaan in <value-of select="$systeemrolFile"/></assert>
        </rule>
        <rule context="/cad:CareApplicationData/cad:CareApplicationRole/cad:CARRelease">
            <let name="profileId" value="."/>
            <assert role="error" test="document($profileFile)/*/hl7:code[@code=$profileId]"
                >CARRelease <value-of select="$profileId"/> moet bestaan in <value-of select="$profileFile"/></assert>
        </rule>
        
        <rule context="/cad:CareApplicationData/cad:CareApplicationRole/cad:SupportedInteraction">
            <let name="interactionId" value="cad:InteractionID"/>
            <let name="interactionName" value="document($interactionVocabFile)/*/hl7:code[@code=$interactionId]/@displayName"/>
            
            <assert role="error" test="not(cad:Sending/text()='false' and cad:Receiving/text()='false')"
                >InteractionID <value-of select="$interactionId"/> (<value-of select="$interactionName"/>) is geconfigureerd op 'niet zenden' EN 'niet ontvangen'. Dit bestand moet interacties bevatten waarop WEL gekwalificeerd moet/kan worden.</assert>
        </rule>
        
        <rule context="/cad:CareApplicationData/cad:CareApplicationRole/cad:SupportedInteraction/cad:InteractionID">
            <let name="interactionId" value="."/>
            <let name="interactionName" value="document($interactionVocabFile)/*/hl7:code[@code=$interactionId]/@displayName"/>
            <let name="interactionFile" value="concat($schemaDir,'/',$interactionId,'.xsd')"/>
            <assert role="error" test="document($interactionVocabFile)/*/hl7:code[@code=$interactionId]"
                >InteractionID <value-of select="$interactionId"/> moet bestaan in <value-of select="$interactionVocabFile"/></assert>
            <assert role="warning" test="doc-available($interactionFile) or not(document($interactionVocabFile)/*/hl7:code[@code=$interactionId])"
                >InteractionID <value-of select="$interactionId"/> (<value-of select="$interactionName"/>) bestaat niet in <value-of select="$schemaDir"/></assert>
            <assert role="error" test="not(document($interactionVocabFile)/*/hl7:code[@code=$interactionId]/hl7:qualifier[@name='Actief']/@value='false')"
                >InteractionID <value-of select="$interactionId"/> (<value-of select="$interactionName"/>) is niet (meer) Actief in <value-of select="$interactionVocabFile"/></assert>
        </rule>
    </pattern>
</schema>
