<?xml version="1.0" encoding="UTF-8"?>
<pattern xmlns="http://purl.oclc.org/dsdl/schematron" abstract="true" id="COCT_MT940000NL">
    <title>A_MedicationAdministrationRequestNL universal</title>
    <rule context="$element">
        <assert role="error" test="not(@classCode) or @classCode='SBADM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#SBADM"
            >COCT_MT940000NL: @classCode moet indien aanwezig 'SBADM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >COCT_MT940000NL: @moodCode moet indien aanwezig 'RQO' zijn</assert>
        
        <let name="xsiType" value="string(hl7:effectiveTime/@xsi:type)"/>
        <assert role="error" test="not(hl7:effectiveTime) or ($xsiType='TS' or $xsiType='IVL_TS' or $xsiType='PIVL_TS' or $xsiType='SXPR_TS')"
            >COCT_MT940000NL: effectiveTime is niet van het type TS, IVL_TS, PIVL_TS of SXPR_TS</assert>
    </rule>
    <rule context="$element/hl7:id">
        <assert role="error" test="not(.)"
            >COCT_MT940000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    <rule context="$element/hl7:text">
        <extends rule="ST"/>
        <assert test="@mediaType='text/plain'"
            >COCT_MT940000NL: @mediaType moet 'text/plain' zijn</assert>
    </rule>
    <rule context="$element/hl7:statusCode">
        <extends rule="CS"/>
        <assert role="error" test="@nullFlavor='NA'"
            >COCT_MT940000NL: statusCode/@nullFlavor moet 'NA' zijn</assert>
    </rule>
    <rule context="$element/hl7:effectiveTime[@xsi:type='TS']">
        <extends rule="TS"/>
    </rule>
    <rule context="$element/hl7:effectiveTime[@xsi:type='SXPR_TS']">
        <extends rule="SXPR_TS"/>
    </rule>
    <rule context="$element/hl7:effectiveTime[@xsi:type='PIVL_TS']">
        <extends rule="PIVL_TS"/>
        <assert role="error" test="hl7:period/@value > 0"
            >COCT_MT940000NL: als effectiveTime van het type PIVL_TS is, moet de periode groter dan 0 zijn</assert>
        <assert role="error" test="hl7:period/@value and hl7:period/@unit"
            >COCT_MT940000NL: als effectiveTime van het type PIVL_TS is, moeten @value en @unit een waarde hebben period</assert>
        <assert role="error" test="hl7:period[@unit='h' or @unit='d' or @unit='wk' or @unit='mo' or @unit='a']"
            >COCT_MT940000NL: als effectiveTime van het type PIVL_TS is, moet de eenheid in de periode 'h', 'd', 'wk', 'mo' of 'a' zijn</assert>
    </rule>
    <rule context="$element/hl7:effectiveTime[@xsi:type='IVL_TS']">
        <extends rule="IVL_TS"/>
        <assert role="error" test="hl7:low/@value and hl7:high/@value"
            >COCT_MT940000NL: als effectiveTime van het type IVL_TS is, moeten low en high beiden een waarde hebben</assert>
    </rule>
    <rule context="$element/hl7:priorityCode">
        <assert role="error" test="not(.)"
            >COCT_MT940000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    <rule context="$element/hl7:routeCode">
        <extends rule="CE"/>
        <assert role="error" test="@codeSystem='2.16.840.1.113883.2.4.4.9' and @displayName"
            >COCT_MT940000NL: toedieningsweg moet komen uit codesysteem '2.16.840.1.113883.2.4.4.9' (G-standaard thesaurus subtabel 0007) en een weergavenaam hebben</assert>
        <assert role="error" test="not(hl7:translation)"
            >COCT_MT940000NL: toedieningsweg mag geen vertaling hebben</assert>
    </rule>
    <rule context="$element/hl7:approachSiteCode">
        <assert role="error" test="not(.)"
            >COCT_MT940000NL: <value-of select="local-name(.)"/> niet gebruiken</assert>
    </rule>
    <rule context="$element/hl7:doseQuantity">
        <extends rule="IVL_PQ"/>
        <assert role="error" test="(count(*//hl7:translation)=1 and hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2']) or 
            (count(*//hl7:translation)=2 and hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2'] and hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361'])"
            >COCT_MT940000NL: doseerhoeveelheid moet een vertaling hebben naar G-Standaard basiseenheden tabel 2 en mag ook een vertaling hebben naar Tabel 25 eenheden gebruiksadvies</assert>
        <assert role="error" test="not(hl7:translation/@codeSystem) or hl7:translation/@displayName"
            >COCT_MT940000NL: in translation elementen moet @displayName een waarde hebben als er een code is</assert>
        <assert role="error" test="not(hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2']) or 
            hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2' and @value=../@value]"
            >COCT_MT940000NL: translation/@value in G-Standaard basiseenheden tabel 2 moet gelijk zijn aan doseQuantity/@value</assert>
        <assert role="error" test="not(hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361' and @code='10' and not(@value=../@value div 15)])"
            >COCT_MT940000NL: als NHG Tabel 25 code '10' is, dan moet value in Tabel 25 vertaling gelijk zijn aan doseQuantity/@value / 15</assert>
        <assert role="error" test="not(hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361' and @code='11' and not(@value=../@value div 8)])"
            >COCT_MT940000NL: als NHG Tabel 25 code '11' is, dan moet value in Tabel 25 vertaling gelijk zijn aan doseQuantity/@value / 8</assert>
        <assert role="error" test="not(hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361' and @code='14' and not(@value=../@value div 3)])"
            >COCT_MT940000NL: als NHG Tabel 25 code '14' is, dan moet value in Tabel 25 vertaling gelijk zijn aan doseQuantity/@value / 3</assert>
    </rule>
    <rule context="$element/hl7:rateQuantity">
        <extends rule="IVL_PQ"/>
    </rule>
    <rule context="$element/hl7:maxDoseQuantity">
        <extends rule="RTO_QTY_QTY"/>
    </rule>
    <rule context="$element/hl7:support2">
        <assert role="error" test="not(@typeCode) or @typeCode='SPRT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#SPRT"
            >COCT_MT940000NL: @typeCode moet indien aanwezig 'SPRT' zijn</assert>
    </rule>
    <rule context="$element/hl7:support2/hl7:medicationAdministrationInstruction">
        <assert role="error" test="not(@classCode) or @classCode='INFRM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#INFRM"
            >COCT_MT940000NL: @classCode moet indien aanwezig 'INFRM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >COCT_MT940000NL: @moodCode moet indien aanwezig 'RQO' zijn</assert>
    </rule>
    <rule context="$element/hl7:support2/hl7:medicationAdministrationInstruction/hl7:code">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.5'"
            >COCT_MT940000NL: toedieningsinstructie moet komen uit '2.16.840.1.113883.2.4.4.5' (NHG Tabel 25 B-codes)</assert>
    </rule>
    <rule context="$element/hl7:precondition">
        <assert role="error" test="not(@typeCode) or @typeCode='PRCN'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#PRCN"
            >COCT_MT940000NL: @typeCode moet indien aanwezig 'PRCN' zijn</assert>
    </rule>
    <rule context="$element/hl7:precondition/hl7:pauseQuantity">
        <extends rule="PQ"/>
    </rule>
    <rule context="$element/hl7:precondition/hl7:observationEventCriterion">
        <assert role="error" test="not(@classCode) or @classCode='OBS'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#OBS"
            >COCT_MT940000NL: @classCode moet indien aanwezig 'OBS' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='EVN.CRT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN.CRT"
            >COCT_MT940000NL: @moodCode moet indien aanwezig 'EVN.CRT' zijn</assert>
    </rule>
    <rule context="$element/hl7:precondition/hl7:observationEventCriterion/hl7:code">
        <extends rule="CD"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.5'"
            >COCT_MT940000NL: preconditie moet komen uit '2.16.840.1.113883.2.4.4.5' (NHG Tabel 25 B-codes)</assert>
    </rule>
    <rule context="$element/hl7:support1">
        <assert role="error" test="not(@typeCode) or @typeCode='SPRT'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActRelationshipType.htm#SPRT"
            >COCT_MT940000NL: @typeCode moet indien aanwezig 'SPRT' zijn</assert>
    </rule>
    <rule context="$element/hl7:support1/hl7:medicationStorageInstruction">
        <assert role="error" test="not(@classCode) or @classCode='INFRM'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#INFRM"
            >COCT_MT940000NL: @classCode moet indien aanwezig 'INFRM' zijn</assert>
        <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#RQO"
            >COCT_MT940000NL: @moodCode moet indien aanwezig 'RQO' zijn</assert>
    </rule>
    <rule context="$element/hl7:support1/hl7:medicationStorageInstruction/hl7:code">
        <extends rule="CV"/>
        <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.2.4.4.5'"
            >COCT_MT940000NL: opslaginstructie moet komen uit '2.16.840.1.113883.2.4.4.5' (NHG Tabel 25 B-codes)</assert>
    </rule>
</pattern>