<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <title>Schematronvalidatie van POOR_IN900550NL - Find Composite Order FulFillment Requests, Response </title>
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
    <include href="coreschematron/xml.sch"/>
    <include href="coreschematron/attentionLine.sch"/>
    
    <include href="coreschematron/transmission-wrapper.sch"/>
    <include href="coreschematron/controlAct-wrapper.sch"/>

    <pattern is-a="transmission-wrapper" id="POOR_IN900550NL-wrapper">
        <param name="element" value="hl7:POOR_IN900550NL"/>
    </pattern>
    
    <pattern is-a="controlAct-wrapper" id="POOR_IN900550NL-controlAct">
        <param name="element" value="hl7:POOR_IN900550NL/hl7:ControlActProcess"/>
    </pattern>

    <pattern id="Wrapper">
        <!-- profileId -->
        <rule context="hl7:profileId">
            <assert test="@root='2.16.840.1.113883.2.4.3.11.1' and(@extension='810')">In de
                transmission wrapper moet het element profileId worden gevuld met de waarde
                '810'</assert>
        </rule>
    </pattern>

    <pattern>
        <rule context="hl7:ControlActProcess">
            <assert test="count(hl7:subject) = 1">ControlActProcess moet precies één subject
                bevatten.</assert>
        </rule>
    </pattern>

    <pattern>
        <title>PlacerGroup</title>
        <rule context="hl7:PlacerGroup">

            <assert test="(hl7:id/@root and hl7:id/@extension) or hl7:id/@nullFlavor='UNK'"
                >PlacerGroup.id is niet compleet, of nullFlavor ontbreekt</assert>

            <assert test="hl7:code/@codeSystem='2.16.840.1.113883.6.1'">PlacerGroup.code
                codeSystem OID is niet gelijk aan LOINC 2.16.840.1.113883.6.1</assert>

            <!-- text bevat het document in base 64 enc, omdat dit een content response is moet er altijd een document B64 aanwezig zijn -->
            <assert test="hl7:text/@mediaType='application/hl7-sda+xml'">PlacerGroup.text
                mediaType is niet gelijk aan application/hl7-sda+xml</assert>
            <assert test="hl7:text/@representation='B64'">PlacerGroup.text representation is
                niet gelijk aan B64 base 64</assert>
            <assert test="string-length(hl7:text)>0">PlacerGroup.text bevat geen inhoud
                (document)</assert>

            <assert test="count(hl7:statusCode) = 1">PlacerGroup.statusCode (hl7:statusCode)
                element required/mandatory [min/max 1x]</assert>

            <assert test="count(hl7:effectiveTime)=1">PlacerGroup.effectiveTime
                (hl7:effectiveTime) element required/mandatory [min 1x]</assert>

            <assert test="count(hl7:confidentialityCode)=1 ">PlacerGroup.confidentialityCode
                (hl7:confidentialityCode) element required/mandatory [min/max 1x]</assert>
            <assert test="hl7:confidentialityCode/@codeSystem='2.16.840.1.113883.5.25'"
                >PlacerGroup.confidentialityCode codeSystem OID is niet gelijk aan LOINC
                2.16.840.1.113883.5.25</assert>
        </rule>
    
        <title>ProcedureRequest</title>
        <rule context="hl7:ProcedureRequest">
            
            <assert test="(hl7:id/@root and hl7:id/@extension) or hl7:id/@nullFlavor='UNK'"
                >ProcedureRequest.id is niet compleet, of nullFlavor ontbreekt</assert>
            
            <assert test="hl7:code/@codeSystem='2.16.840.1.113883.6.1'">ProcedureRequest.code
                codeSystem OID is niet gelijk aan LOINC 2.16.840.1.113883.6.1</assert>
            
            <!-- text bevat het document in base 64 enc, omdat dit een content response is moet er altijd een document B64 aanwezig zijn -->
            <assert test="hl7:text/@mediaType='application/hl7-sda+xml'">ProcedureRequest.text
                mediaType is niet gelijk aan application/hl7-sda+xml</assert>
            <assert test="hl7:text/@representation='B64'">ProcedureRequest.text representation is
                niet gelijk aan B64 base 64</assert>
            <assert test="string-length(hl7:text)>0">ProcedureRequest.text bevat geen inhoud
                (document)</assert>
            
            <assert test="count(hl7:statusCode) = 1">ProcedureRequest.statusCode (hl7:statusCode)
                element required/mandatory [min/max 1x]</assert>
            
            <assert test="count(hl7:effectiveTime)=1">ProcedureRequest.effectiveTime
                (hl7:effectiveTime) element required/mandatory [min 1x]</assert>
            
            <assert test="count(hl7:confidentialityCode)=1 ">ProcedureRequest.confidentialityCode
                (hl7:confidentialityCode) element required/mandatory [min/max 1x]</assert>
            <assert test="hl7:confidentialityCode/@codeSystem='2.16.840.1.113883.5.25'"
                >ProcedureRequest.confidentialityCode codeSystem OID is niet gelijk aan LOINC
                2.16.840.1.113883.5.25</assert>
        </rule>
 
        <title>RecordTarget</title>
        <rule context="hl7:recordTarget">
            <assert
                test="count(hl7:patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3' and @extension])>0"
                >BSN ontbreekt in Patient</assert>

            <assert test="hl7:patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3']"
                >RecordTarget/patient/id moet een burgerservicenummer zijn</assert>

            <assert test="count(hl7:patient/hl7:Person/hl7:name[@qualifier='BR'])=0">RecordTarget/patient/person/name moet
                tenminste één element met qualifier=BR hebben.</assert>
        </rule>
       
        <title>Author</title>
        <rule context="hl7:author">
            <assert test="hl7:time/@value or
                hl7:time/@nullFlavor='UNK'">Moment van
                aanmaken uitslagdocument ontbreekt of nullFlavor is niet gelijk aan 'UNK'</assert>
            <assert test="hl7:assignedEntity/hl7:id[@root='2.16.528.1.1007.3.1']">OID root van
                assignedEntity.id wijst niet naar UZI register personen</assert>
        </rule>

    </pattern>

</schema>
