<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <title>Schematronvalidatie van QURX_IN990113NL - Medication Dispense List Query Response</title>
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
    <include href="coreschematron/xml.sch"/>
    <include href="coreschematron/attentionLine.sch"/>
    
    <include href="coreschematron/transmission-wrapper.sch"/>
    <include href="coreschematron/controlAct-wrapper.sch"/>
    
    <include href="Mp/PORX_MT924000NL.sch"/>
    
    <!--pattern is-a="attentionLine" id="attentionLine">
        <param name="messagePatientId" value="hl7:ControlActProcess/hl7:subject/hl7:MedicationDispenseList/hl7:subject/hl7:Patient/hl7:id"/>
        <param name="attentionLineOptional" value="'false'"/>
        </pattern-->
    
    <pattern is-a="transmission-wrapper" id="QURX_IN990113NL-wrapper">
        <param name="element" value="hl7:QURX_IN990113NL"/>
    </pattern>
    
    <pattern is-a="controlAct-wrapper" id="QURX_IN990113NL-controlAct">
        <param name="element" value="hl7:QURX_IN990113NL/hl7:ControlActProcess"/>
    </pattern>
    
    <pattern>
        <!-- profileId -->
        <rule context="hl7:QURX_IN990113NL/hl7:profileId">
            <extends rule="II"/>
            <assert role="error" test="@root='2.16.840.1.113883.2.4.3.11.1' and @extension='810'"
                >In de transmission wrapper moet het element profileId worden gevuld met de waarde '810'</assert>
        </rule>
        <rule context="hl7:QURX_IN990113NL/hl7:acceptAckCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='NE'">In de transmission wrapper moet het veld acceptAckCode worden gevuld met waarde 'NE'.</assert>
        </rule>
        <rule context="hl7:QURX_IN990113NL/hl7:attentionLine">
            <assert role="warning" test="not(.)">Het gebruik van attentionLine wordt nog niet gespecificeerd in deze interactie.</assert>
        </rule>
    </pattern>
    
    <!-- ControlAct Wrapper -->
    <pattern>
        <title>ControlAct Wrapper</title>
        <rule context="hl7:ControlActProcess">
            <assert role="error" test="@moodCode='EVN'">moodCode is niet gelijk aan EVN</assert>
        </rule>
        <!-- Controle zit in controlAct-wrapper.sch rrule
            context="hl7:ControlActProcess/hl7:authorOrPerformer/hl7:participant/hl7:AssignedDevice">
            <assert role="error" test="not(hl7:id/@root='2.16.528.1.1007.3.3')">Een apparaat
                mag geen URA id hebben.</assert>
            <assert role="error" test="hl7:id/@root='2.16.528.1.1007.3.2'">Een apparaat moet
                een UZI systeemnummer hebben.</assert>
        </rule-->
    </pattern>
    <!-- Payload -->
    <pattern>
        <title>Dispense List</title>
        <rule context="hl7:ControlActProcess/hl7:subject/hl7:MedicationDispenseList">
            <assert role="error" test="not(@classCode) or @classCode='LIST'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActClass.htm#LIST"
                >PORX_MT924100NL: @classCode moet indien aanwezig 'LIST' zijn</assert>
            <assert role="error" test="not(@moodCode) or @moodCode='RQO'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/ActMood.htm#EVN"
                >PORX_MT924100NL: @moodCode moet indien aanwezig 'EVN' zijn</assert>
        </rule>
        <rule context="hl7:ControlActProcess/hl7:subject/hl7:MedicationDispenseList/hl7:code">
            <extends rule="CV"/>
            <assert role="error" test="@codeSystem='2.16.840.1.113883.5.4' and @code='MEDLIST'"
                >PORX_MT924100NL: codeSystem moet '2.16.840.1.113883.5.4' zijn en @code 'MEDLIST'</assert>
        </rule>
        <rule context="hl7:subject/hl7:Patient">
            <assert role="error" test="not(@classCode) or @classCode='PAT'"
                >PORX_MT924100NL: @classCode moet indien aanwezig 'PAT' zijn</assert>
            <assert role="error" test="hl7:id[@root='2.16.840.1.113883.2.4.6.3' and @extension]"
                >PORX_MT924100NL: er moet tenminste een burgerservicenummer zijn ter identificatie</assert>
            <assert role="error" test="hl7:Person/hl7:name"
                >PORX_MT924100NL: patiëntnaam ontbreekt</assert>
            <assert role="error" test="hl7:Person/hl7:birthTime/@value"
                >PORX_MT924100NL: geboortedatum van patiënt ontbreekt</assert>
        </rule>
        <rule context="hl7:subject/hl7:Patient/hl7:id">
            <extends rule="II"/>
        </rule>
        <rule context="hl7:subject/hl7:Patient/hl7:addr">
            <extends rule="AD"/>
        </rule>
        <rule context="hl7:subject/hl7:Patient/hl7:telecom">
            <extends rule="TEL"/>
        </rule>
        <rule context="hl7:subject/hl7:Patient/hl7:statusCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='active'"
                >PORX_MT924100NL: <value-of select="local-name(..)"/>/statusCode moet 'active' zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Patient/hl7:Person">
            <assert role="error" test="hl7:name"
                >PORX_MT924100NL: patiëntnaam moet een waarde hebben</assert>
            <assert role="error" test="hl7:birthTime"
                >PORX_MT924100NL: birthTime moet een waarde hebben</assert>
        </rule>
        <rule context="hl7:subject/hl7:Patient/hl7:Person/hl7:id">
            <extends rule="II"/>
            <assert role="error" test="@root='2.16.840.1.113883.2.4.6.3'"
                >PORX_MT924100NL: als er een persoonsnummer wordt gebruikt moet dat het burgerservicenummer zijn</assert>
        </rule>
        <rule context="hl7:subject/hl7:Patient/hl7:Person/hl7:name">
            <extends rule="PN"/>
        </rule>
        <rule context="hl7:subject/hl7:Patient/hl7:Person/hl7:administrativeGenderCode">
            <extends rule="CE"/>
            <assert role="error" test="not(@codeSystem) or @codeSystem='2.16.840.1.113883.5.1'" see="http://www.hl7.org/v3ballot/html/infrastructure/vocabulary/AdministrativeGender.htm"
                >PORX_MT924100NL: geslacht moet komen uit codesysteem '2.16.840.1.113883.5.1'</assert>
        </rule>
        <rule context="hl7:subject/hl7:Patient/hl7:Person/hl7:birthTime">
            <extends rule="TS"/>
        </rule>
    </pattern>
    <pattern is-a="PORX_MT924000NL" id="MedicationDispenseEvent">
        <param name="element" value="hl7:ControlActProcess/hl7:subject/hl7:MedicationDispenseList/hl7:component/hl7:medicationDispenseEvent"/>
    </pattern>
    <!--
    <pattern>
        <title>Dispense Information</title>
        <rule context="hl7:MedicationDispenseEvent">
            <assert role="error" test="hl7:id/@root and hl7:id/@extension">id mist root of
                extension</assert>
            <report role="warning"
                test="not(substring(hl7:id/@root,1,20)='2.16.528.1.1007.3.3.')"
                >root OID van id is niet gebaseerd op URA</report>
            <assert role="error" test="hl7:statusCode/@code='completed'"
                >statuscode moet 'completed' zijn</assert>
            <assert role="error"
                test="hl7:effectiveTime/@value or (hl7:effectiveTime/hl7:low/@value and hl7:effectiveTime/hl7:high/@value)"
                >effectiveTime/low en effectiveTime/high moeten een waarde hebben</assert>
            <assert role="error" test="hl7:quantity/@nullFlavor='NA' or hl7:quantity/@value>0">quantity is niet groter dan
                0</assert>
            <assert role="error" test="hl7:quantity/@nullFlavor='NA' or hl7:quantity/hl7:translation">translation van quantity
                naar G-Standaard basiseenheden ontbreekt</assert>
            <report role="warning"
                test="hl7:quantity/@nullFlavor='NA' or hl7:quantity/@value=hl7:quantity/hl7:translation[1]/@value"
                >quantity in translation moet gelijk zijn aan UCUM quantity</report>
            <assert role="error" test="hl7:quantity/@nullFlavor='NA' or count(hl7:quantity/hl7:translation/@code[string-length(.)&gt;0])&gt;0"
                >quantity translation mist code attribuut</assert>
            <assert role="error"
                test="hl7:quantity/@nullFlavor='NA' or 
                (count(hl7:quantity/hl7:translation/@code[string-length(.)&gt;0])&gt;0 and count(hl7:quantity/hl7:translation/@displayName[string-length(.)&gt;0])&gt;0)"
                >quantity translation mist displayName bij code</assert>
            <assert role="error"
                test="hl7:quantity/@nullFlavor='NA' or 
                (hl7:quantity/hl7:translation/@code and hl7:quantity/hl7:translation/@codeSystem='2.16.840.1.113883.2.4.4.1.900.2')"
                >codeSystem OID van translation wijst niet naar tabel 2 uit
                thesaurus G-Standaard</assert>
            <assert role="error"
                test="(string-length(hl7:effectiveTime/hl7:low/@value)&gt;=12 and string-length(hl7:effectiveTime/hl7:high/@value)&gt;=12 and hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:effectiveTime/hl7:comp[string(@xsi:type)='IVL_TS']/hl7:low/@value) or hl7:expectedUseTime/hl7:low/@value"
                >expectedUseTime/low moet aanwezig zijn, of de effectiveTime low
                en high moeten op de minuut gespecificeerd zijn en de
                medicationadministrationRequest/effectiveTime moet een interval
                bevatten.</assert>
            <assert role="error"
                test="not(hl7:expectedUseTime) or hl7:expectedUseTime/hl7:low/@value >= hl7:effectiveTime/@value"
                >expectedUseTime/low is niet groter of gelijk aan effectiveTime</assert>
            <assert role="error"
                test="hl7:performer/hl7:assignedPerson/hl7:id/@nullFlavor='UNK' or 
                hl7:performer/hl7:assignedPerson/hl7:id/@root='2.16.528.1.1007.3.1' or 
                hl7:performer/hl7:assignedPerson/hl7:id/@root='2.16.840.1.113883.2.4.6.1'"
                >root OID van performer/AssignedPerson/id wijst 
                niet naar AGB-Zorgverleners of UZI register personen</assert>
            <assert role="error"
                test="hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id/@root='2.16.528.1.1007.3.3'"
                >root OID van performer/AssignedPerson/representedOrganization/id wijst niet
                naar UZI abonneeregister</assert>
            <assert role="error"
                test="hl7:responsibleParty/hl7:assignedCareProvider/hl7:id/@nullFlavor='UNK' or 
                hl7:responsibleParty/hl7:assignedCareProvider/hl7:id/@root='2.16.528.1.1007.3.1' or 
                hl7:responsibleParty/hl7:assignedCareProvider/hl7:id/@root='2.16.840.1.113883.2.4.6.1'"
                >root OID van responsibleParty/AssignedCareProvider/id wijst
                niet naar AGB-Zorgverleners of UZI register personen</assert>
            <assert role="error"
                test="hl7:responsibleParty/hl7:assignedCareProvider/hl7:code/@nullFlavor='UNK' or
                hl7:responsibleParty/hl7:assignedCareProvider/hl7:code/@codeSystem='2.16.840.1.113883.2.4.15.111'"
                >codeSystem OID van responsibleParty/AssignedCareProvider/code is niet juist</assert>
            <assert role="error"
                test="(hl7:responsibleParty/hl7:assignedCareProvider/hl7:code/@nullFlavor='UNK' and 
                hl7:responsibleParty/hl7:assignedCareProvider/hl7:code/@nullFlavor='UNK') or
                hl7:responsibleParty/hl7:assignedCareProvider/hl7:code/@code='17.000' or
                hl7:responsibleParty/hl7:assignedCareProvider/hl7:code/@code='17.060' or
                hl7:responsibleParty/hl7:assignedCareProvider/hl7:code/@code='01.004'"
                >responsibleParty/AssignedCareProvider/code is niet juist</assert>
            <assert role="error"
                test="hl7:responsibleParty/hl7:assignedCareProvider/hl7:representedOrganization/hl7:id/@root='2.16.528.1.1007.3.3'"
                >root OID van responsibleParty/AssignedCareProvider/representedOrganization/id wijst 
                niet naar UZI abonneeregister</assert>
            <assert role="error"
                test="hl7:performer/hl7:assignedPerson/hl7:representedOrganization/hl7:id/@extension = 
                hl7:responsibleParty/hl7:assignedCareProvider/hl7:representedOrganization/hl7:id/@extension"
                >UZI abonneenummer van performer en responsibleParty zijn verschillend</assert>
        </rule>
        <rule context="hl7:MedicationDispenseEvent/hl7:expectedUseTime">
            <report role="warning"
                test="not(hl7:high or ../hl7:product/hl7:dispensedMedication/hl7:therapeuticAgentOf/hl7:medicationAdministrationRequest/hl7:precondition)"
                >expectedUseTime/high element ontbreekt en er is geen precondition.</report>
        </rule>
    </pattern>
    <pattern>
        <title>Medication Info</title>
        <rule context="hl7:MedicationKind">
            <assert role="error"
                test="(string-length(hl7:code/@code)>0 and
                (hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.1' or 
                 hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.7' or
                 hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.8' or
                 hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.10')) or
                (hl7:code/@nullFlavor='OTH' and string-length(hl7:code/hl7:originalText)>0)"
                >geneesmiddel is geen GPK (2.16.840.1.113883.2.4.4.1), PRK (2.16.840.1.113883.2.4.4.10), 
                HPK (2.16.840.1.113883.2.4.4.7), of ZI_nummer (2.16.840.1.113883.2.4.4.8)</assert>
            <assert role="error"
                test="not(hl7:code/hl7:translation) or count(hl7:code/hl7:translation/@code[string-length(.)&gt;0])&gt;0"
                >code in translation van geneesmiddel ontbreekt</assert>
            <report role="warning" test="hl7:activeIngredient">activeIngredient nog niet gebruiken.</report>
            <assert role="error"
                test="not(hl7:code/hl7:translation) or 
                (hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.1' or 
                hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.7' or
                hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.8' or
                hl7:code/@codeSystem='2.16.840.1.113883.2.4.4.10')"
                >geneesmiddel in translation is geen GPK (2.16.840.1.113883.2.4.4.1), PRK (2.16.840.1.113883.2.4.4.10), 
                HPK (2.16.840.1.113883.2.4.4.7), of ZI_nummer (2.16.840.1.113883.2.4.4.8)</assert>
        </rule>
    </pattern>
    <pattern is-a="COCT_MT932000NL" id="Prescription">
        <param name="element" value="hl7:prescription"/>
    </pattern>
    <pattern>
        <title>Prescription Info</title>
        <rule context="hl7:prescription/hl7:author">
            <let name="performerRoot" value="../../../../../hl7:performer/hl7:assignedPerson/hl7:id/@root"/>
            <let name="performerExt" value="../../../../../hl7:performer/hl7:assignedPerson/hl7:id/@extension"/>
            <report role="warning" test="hl7:AssignedPerson/hl7:id[@root=$performerRoot and @extension=$performerExt]"
                >MedicationDispenseEvent/performer en presciption/author zijn gelijk. Alleen een apotheekhoudend huisarts mag zowel voorschrijven als afleveren.</report>
        </rule>
    </pattern>
    <pattern>
        <title>Administration Info</title>
        <rule context="hl7:medicationAdministrationRequest">
            <assert role="error" test="hl7:statusCode/@code='active'"
                >statusCode van medicationAdministrationRequest is niet gelijk
                aan 'active'</assert>
            <let name="xsiType" value="string(hl7:effectiveTime/@xsi:type)"/>
            <assert role="error"
                test="not(hl7:effectiveTime) or ($xsiType='IVL_TS' or
                $xsiType='PIVL_TS' or $xsiType='SXPR_TS')"
                >effectiveTime is niet van het type IVL_TS, PIVL_TS of
                SXPR_TS</assert>
            <assert role="error"
                test="not($xsiType='IVL_TS') or
                (hl7:effectiveTime/hl7:low/@value and hl7:effectiveTime/hl7:high/@value)"
                >effectiveTime is van het type IVL_TS, maar high of low value
                ontbreekt</assert>
            <assert role="error"
                test="not($xsiType='PIVL_TS') or
                (hl7:effectiveTime/hl7:period/@value and hl7:effectiveTime/hl7:period/@unit)"
                >effectiveTime is van het type PIVL_TS, maar value of unit
                ontbreekt in de period</assert>
            <assert role="error"
                test="not($xsiType='PIVL_TS') or
                (hl7:effectiveTime/hl7:period/@unit='h' or
                hl7:effectiveTime/hl7:period/@unit='d' or
                hl7:effectiveTime/hl7:period/@unit='wk' or
                hl7:effectiveTime/hl7:period/@unit='mo' or
                hl7:effectiveTime/hl7:period/@unit='a')"
                >effectiveTime is van het type PIVL_TS, maar de period unit is
                niet 'h', 'd', 'wk', 'mo' of 'a'</assert>
            <assert role="error"
                test="not($xsiType='PIVL_TS') or
                hl7:effectiveTime/hl7:period/@value > 0"
                >effectiveTime is van het type PIVL_TS, maar de period value is
                niet groter dan 0</assert>
            <assert role="error"
                test="not(hl7:routeCode) or hl7:routeCode/@codeSystem =
                '2.16.840.1.113883.2.4.4.9'"
                >codeSystem OID van routeCode is onjuist</assert>
            <assert role="error"
                test="not(hl7:routeCode) or string-length(hl7:routeCode/@code) > 0"
                >routeCode is niet aanwezig of leeg</assert>
            <assert role="error"
                test="not(hl7:doseQuantity) or hl7:doseQuantity/*/@value>0"
                >value van doseQuantity is niet groter dan 0</assert>
            <assert role="error"
                test="not(hl7:doseQuantity/@value) or
                (count(hl7:doseQuantity/*/hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2'])>0)"
                >G-Standaard (bestand 902) vertaling ontbreekt.</assert>
            <assert role="error"
                test="not(hl7:doseQuantity/*/hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2'
                and not(@code)])"
                >code in G-Standaard vertaling ontbreekt</assert>
            <assert role="error"
                test="not(hl7:doseQuantity/*/hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2'
                and not(@displayName)])"
                >displayName in G-Standaard vertaling ontbreekt</assert>
            <assert role="error"
                test="not(hl7:doseQuantity/*/hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.900.2'
                and not(@value=../@value)])"
                >value in G-Standaard vertaling is niet gelijk aan
                doseQuantity/@value</assert>
            <assert role="error"
                test="not(hl7:doseQuantity/*/hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361'
                and not(@displayName)])"
                >displayName in Tabel 25 vertaling ontbreekt</assert>
            <assert role="error"
                test="not(hl7:doseQuantity/*/hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361'
                and not(@code)])"
                >code in Tabel 25 vertaling ontbreekt</assert>
            <assert role="error"
                test="not(hl7:doseQuantity/*/hl7:translation[
                not(@codeSystem='2.16.840.1.113883.2.4.4.1.361' or
                @codeSystem='2.16.840.1.113883.2.4.4.1.900.2')])"
                >er is een vertaling, maar geen Tabel 25 of G-Standaard</assert>
            <assert role="error"
                test="not(hl7:doseQuantity/*/hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361'
                and @code='10' and
                not(@value=../@value div 15)])"
                >Tabel 25 code is '10', maar value in Tabel 25 vertaling is niet
                gelijk aan doseQuantity/@value / 15</assert>
            <assert role="error"
                test="not(hl7:doseQuantity/*/hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361'
                and @code='11' and
                not(@value=../@value div 8)])"
                >Tabel 25 code is '11', maar value in Tabel 25 vertaling is niet
                gelijk aan doseQuantity/@value / 8</assert>
            <assert role="error"
                test="not(hl7:doseQuantity/*/hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361'
                and @code='14' and
                not(@value=../@value div 3)])"
                >Tabel 25 code is '14', maar value in Tabel 25 vertaling is niet
                gelijk aan doseQuantity/@value / 3</assert>
            <assert role="error"
                test="not(hl7:doseQuantity/*/hl7:translation[@codeSystem='2.16.840.1.113883.2.4.4.1.361'
                and not(@code='10' or @code='11' or
                @code='14') and
                not(@value=../@value)])"
                >value in Tabel 25 vertaling is niet gelijk aan
                doseQuantity/@value</assert>
        </rule>
    </pattern>
    -->
</schema>
