<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
  <title>Schematronvalidatie van RCMR_IN000032NL - Find Document Metadata and Content Query Response</title>
  <ns uri="urn:hl7-org:v3" prefix="hl7"/>
  <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
  <include href="coreschematron/xml.sch"/>
  <include href="coreschematron/attentionLine.sch"/>
  
  <include href="coreschematron/transmission-wrapper.sch"/>
  <include href="coreschematron/controlAct-wrapper.sch"/>
  
  <pattern is-a="transmission-wrapper" id="RCMR_IN000032NL-wrapper">
    <param name="element" value="hl7:RCMR_IN000032NL"/>
  </pattern>
  
  <pattern is-a="controlAct-wrapper" id="RCMR_IN000032NL-controlAct">
    <param name="element" value="hl7:RCMR_IN000032NL/hl7:ControlActProcess"/>
  </pattern>
  
  <pattern is-a="attentionLine" id="RCMR_IN000032NL-attentionLine">
    <param name="messagePatientId" value="hl7:ControlActProcess/hl7:subject/hl7:ClinicalDocument/hl7:recordTarget/hl7:patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3']"/>
    <param name="attentionLineOptional" value="'true'"/>
  </pattern>
  
  <!-- ControlAct Wrapper -->
  <pattern>
    <title>ControlAct Wrapper</title>
    <rule context="hl7:ControlActProcess">
      <assert test="@moodCode='EVN'">moodCode is niet gelijk aan EVN</assert>
      <assert test="hl7:authorOrPerformer/@typeCode='AUT'">authorOrPerformer.typeCode is niet gelijk aan AUT</assert>
      <assert
        test="hl7:authorOrPerformer/hl7:participant/hl7:AssignedDevice/hl7:id/@root='2.16.840.1.113883.2.4.6.6'
                and hl7:authorOrPerformer/hl7:participant/hl7:AssignedDevice/hl7:id/@extension"
        >authorOrPerformer verzender is geen LSP of XIS</assert>
      <assert
        test="hl7:authorOrPerformer/hl7:participant/hl7:AssignedDevice/hl7:Organization/hl7:id/@root='2.16.528.1.1007.3.3'"
        >OID root van authorOrPerformer AssignedDevice.Organization.id wijst niet naar UZI register instellingen</assert>
    </rule>
  </pattern>

  <!-- ClinicalDocument -->
  <pattern>
    <title>ClinicalDocument</title>
    <rule context="hl7:ClinicalDocument">

      <assert test="hl7:id/@root and hl7:id/@extension">ClinicalDocument.id element mist root of extension</assert>

      <!-- het wordt hier ervan uitgegaan dat bij document queries altijd LOINC codes als typering gebruikt worden -->
      <assert test="hl7:code/@codeSystem='2.16.840.1.113883.6.1'">ClinicalDocument.code codeSystem OID is niet
        gelijk aan LOINC 2.16.840.1.113883.6.1</assert>

      <!-- text bevat het document in base 64 enc, omdat dit een content response is moet er altijd een document B64 aanwezig zijn -->
      <assert test="hl7:text/@mediaType='application/octet-stream'">ClinicalDocument.text mediaType is niet gelijk aan
        application/octet-stream</assert>
      <assert test="hl7:text/@representation='B64'">ClinicalDocument.text representation is niet gelijk aan B64 base 64</assert>
      <assert test="string-length(hl7:text)>0">ClinicalDocument.text bevat geen inhoud (document)</assert>

      <assert test="string-length(hl7:effectiveTime/@value)&gt;7">ClinicalDocument.effectiveTime is niet nauwkeurig genoeg</assert>

      <!-- setId en versionNumber, allebei aanwezig of allebei ontbreken -->
      <assert test="(hl7:setId and hl7:versionNumber) or (not((hl7:setId or hl7:versionNumber)))">ClinicalDocument elementen setId
        en versionNumber of allebei aanwezig of allebei niet</assert>

    </rule>
  </pattern>

  <!-- ClinicalDocument recordTarget -->
  <pattern>
    <title>ClinicalDocument.recordTarget</title>
    <rule context="hl7:ClinicalDocument/hl7:recordTarget">
      <assert test="count(hl7:patient/hl7:id[@root='2.16.840.1.113883.2.4.6.3'
    and @extension])>0">BSN
        ontbreekt in Patient</assert>
      <!--assert test="hl7:patient/hl7:Person/hl7:administrativeGenderCode/@code">administrativeGenderCode ontbreekt</assert-->
      <!--assert test="hl7:patient/hl7:Person/hl7:birthTime/@value">Geboortedatum ontbreekt</assert-->
    </rule>
  </pattern>

  <!-- ClinicalDocument author -->
  <pattern>
    <title>ClinicalDocument.author</title>
    <rule context="hl7:ClinicalDocument/hl7:author">
      <assert test="hl7:time/@value">author.time ontbreekt</assert>
      <assert test="string-length(hl7:time/@value)&gt;7">author.time is niet nauwkeurig genoeg</assert>
      <assert test="hl7:assignedAuthor/hl7:id/@root='2.16.528.1.1007.3.1'">OID root van assignedAuthor.id wijst
        niet naar UZI register personen</assert>
    </rule>
  </pattern>

  <!-- ClinicalDocument custodian -->
  <pattern>
    <title>ClinicalDocument.custodian</title>
    <rule context="hl7:ClinicalDocument/hl7:custodian">
      <assert test="hl7:assignedCustodian/hl7:representedOrganization/hl7:id/@root='2.16.528.1.1007.3.3'">OID
        root van assignedCustodian.representedOrganization.id wijst niet naar UZI register instellingen</assert>
    </rule>
  </pattern>

  <!-- ClinicalDocument legalAuthenticator -->
  <pattern>
    <title>ClinicalDocument.legalAuthenticator</title>
    <rule context="hl7:ClinicalDocument/hl7:legalAuthenticator">
      <assert test="hl7:assignedPerson/hl7:id/@root='2.16.528.1.1007.3.1'">OID root van assignedPerson.id wijst
        niet naar UZI register personen</assert>
      <assert test="string-length(hl7:assignedPerson/hl7:id/@extension)=9">OID extension van assignedPerson.id is
        geen 9 cijfers lang</assert>
      <assert test="hl7:assignedPerson/hl7:representedOrganization/hl7:id/@root='2.16.528.1.1007.3.3'">OID root van
        assignedPerson.representedOrganization.id wijst niet naar UZI register instellingen</assert>
      <assert test="string-length(hl7:assignedPerson/hl7:representedOrganization/hl7:id/@extension)=8">OID extension van
        assignedPerson.representedOrganization.id is geen 8 cijfers lang</assert>
    </rule>
  </pattern>
</schema>
