<?xml version="1.0" encoding="UTF-8"?>
<schema xmlns="http://purl.oclc.org/dsdl/schematron" queryBinding="xslt2">
    <title>Schematronvalidatie van REPC_IN000023NL - Patient General Conditions Query</title>
    <ns uri="urn:hl7-org:v3" prefix="hl7"/>
    <ns uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
    <include href="coreschematron/xml.sch"/>
    <include href="coreschematron/attentionLine.sch"/>
    
    <include href="coreschematron/transmission-wrapper.sch"/>
    <include href="coreschematron/controlAct-wrapper.sch"/>
    
    <pattern is-a="transmission-wrapper" id="REPC_IN000023NL-wrapper">
        <param name="element" value="hl7:REPC_IN000023NL"/>
    </pattern>
    
    <pattern is-a="controlAct-wrapper" id="REPC_IN000023NL-controlAct">
        <param name="element" value="hl7:REPC_IN000023NL/hl7:ControlActProcess"/>
    </pattern>
    
    <pattern>
        <!-- profileId -->
        <rule context="hl7:REPC_IN000023NL/hl7:profileId">
            <extends rule="II"/>
            <assert role="error" test="@root='2.16.840.1.113883.2.4.3.11.1' and @extension='810'"
                >In de transmission wrapper moet het element profileId worden gevuld met de waarde '810'</assert>
        </rule>
        <rule context="hl7:REPC_IN000023NL/hl7:acceptAckCode">
            <extends rule="CS"/>
            <assert role="error" test="@code='NE'">In de transmission wrapper moet het veld acceptAckCode worden gevuld met waarde 'NE'.</assert>
        </rule>
        <rule context="hl7:REPC_IN000023NL/hl7:attentionLine">
            <assert role="warning" test="not(.)">Het gebruik van attentionLine wordt nog niet gespecificeerd in deze interactie.</assert>
        </rule>
    </pattern>
    
    <!-- ControlAct Wrapper -->
    <pattern>
        <title>ControlAct Wrapper</title>
        <rule context="hl7:ControlActProcess">
            <assert role="error" test="hl7:authorOrPerformer/@typeCode='AUT'">typecode
                authorOrPerformer moet AUT zijn</assert>
            <assert role="error"
                test="hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:id/@root='2.16.528.1.1007.3.1'"
                >@root van AssignedPerson/id moet '2.16.528.1007.3.1' zijn</assert>
            <assert role="error"
                test="hl7:authorOrPerformer/hl7:participant/hl7:AssignedPerson/hl7:Organization/hl7:id/@root='2.16.528.1.1007.3.3'"
                >@root van Organization/id moet '2.16.528.1.1007.3.3' zijn</assert>
        </rule>
    </pattern>
    <!-- queryByParameter -->
    <pattern>
        <title>queryByParameter</title>
        <rule context="hl7:queryByParameter">
            <!--
            <assert role="error" test="hl7:queryId/@root and hl7:queryId/@extension">queryId moet @root en @extension hebben</assert>
            <report role="warning" test="not(substring(hl7:id/@root,1,28)='2.16.840.1.113883.2.4.6.6.1.' or substring(hl7:queryId/@root,1,20)='2.16.528.1.1007.3.3.')"
                >@root van queryId moet bij voorkeur zijn gebaseerd op URA</report>
            -->    
            <assert role="error"
                test="hl7:patientID/hl7:value/@root='2.16.840.1.113883.2.4.6.3'"
                >@root van patientID moet '2.16.840.1.113883.2.4.6.3' zijn</assert>
            <assert role="error"
                test="not(hl7:authorOrPerformerRole) or hl7:authorOrPerformerRole/hl7:value/@codeSystem='2.16.840.1.113883.2.4.15.111'"
                >@codesystem van authorOrPerformerRole moet '2.16.840.1.113883.2.4.15.111' zijn</assert>
            <assert role="error"
                test="not(hl7:actID)"
                >actId mag niet gebruikt worden.</assert>
            <assert role="error"
                test="not(hl7:availabilityTimeInterval)"
                >availabilityTimeInterval mag niet gebruikt worden.</assert>
        </rule>
    </pattern>
</schema>
