<?xml version="1.0" encoding="UTF-8"?>
<!--

Conversie eh XSLT
KH 12-01-2010 17-03-2010 22-07-2010 15-11-2010 07-12-2010 09-12-2010 02-02-2011
v257

EDIFACT XML WCIA tabel 25 DSG/FTX segmenten -> HL7 versie 3 bericht fragmenten
Saxon 8 gereed

-->
<xsl:stylesheet exclude-result-prefixes="xs" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns="urn:hl7-org:v3" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:xs="http://www.w3.org/2001/XMLSchema" version="2.0">

    <xsl:output encoding="UTF-8" indent="yes" method="xml" version="1.0"/>

    <!--
		Template to create the output for medicationAdministrationRequest
     -->
    <xsl:template name="OutputMedicationAdministrationRequest">
        <xsl:param name="DosageIdIsNumeric"/>
        <xsl:param name="DosageTranslate"/>
        
        <xsl:choose>
            <xsl:when test="contains(DSG[Dosage_qualifier = 'X']/Dosage_identification, '-') and (not(DSG[Dosage_qualifier = 'X']/Dosage_identification = '-'))">
                <!--
                    Als X component een range is, bijvoorbeeld "2-3 keer" worden er twee <medicationAdministrationRequest>s
                    gegenereerd, een met de lage waarde, en een met de (hoge waarde - lage waarde) plus een zo nodig conditie
                    
                    uitzondering 0-4 keer wordt dan toch maar een instructie met alleen 4 keer zo nodig
                -->
                <xsl:variable name="theXl">
                    <xsl:value-of select="translate(substring-before(DSG[Dosage_qualifier = 'X']/Dosage_identification,'-'), ',', '.')"/>
                </xsl:variable>
                <xsl:if test="string-length($theXl)&gt;0 and $theXl!='0'">
                    <xsl:call-template name="OutputMedicationAdministrationRequest2">
                        <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                        <xsl:with-param name="DosageTranslate" select="$DosageTranslate"/>
                        <xsl:with-param name="XRange" select="$theXl"/>
                        <xsl:with-param name="GenereerZoNodig" select="0"/>
                    </xsl:call-template>
                </xsl:if>
                <xsl:variable name="theXh">
                    <xsl:choose>
                        <xsl:when test="string-length($theXl)&gt;0">
                            <xsl:value-of select="number(translate(substring-after(DSG[Dosage_qualifier = 'X']/Dosage_identification,'-'), ',','.'))-number($theXl)"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="number(translate(substring-after(DSG[Dosage_qualifier = 'X']/Dosage_identification,'-'), ',','.'))"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:variable>
                <xsl:call-template name="OutputMedicationAdministrationRequest2">
                    <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                    <xsl:with-param name="DosageTranslate" select="$DosageTranslate"/>
                    <xsl:with-param name="XRange" select="$theXh"/>
                    <xsl:with-param name="GenereerZoNodig" select="1"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:variable name="theSpecB">
                    <!-- check of er B codes met gevolgen voor effectiveTime inzitten -->
                    <!-- tot nu toe zijn dit alleen de volgende codes -->
                    <xsl:for-each select="DSG[Dosage_qualifier = 'B']">
                        <xsl:if test="Dosage_identification='3W1WS' or Dosage_identification='1W3WH'">
                            <xsl:value-of select="Dosage_identification"/>
                        </xsl:if>
                    </xsl:for-each>
                </xsl:variable>
                <xsl:call-template name="OutputMedicationAdministrationRequest2">
                    <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                    <xsl:with-param name="DosageTranslate" select="$DosageTranslate"/>
                    <xsl:with-param name="XRange" select="$theSpecB"/>
                    <xsl:with-param name="GenereerZoNodig" select="0"/>
                </xsl:call-template>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <!--
        Template OutputMedicationAdministrationRequest2
    -->
    <xsl:template name="OutputMedicationAdministrationRequest2">
        <xsl:param name="DosageIdIsNumeric"/>
        <xsl:param name="DosageTranslate"/>
        <xsl:param name="XRange"/>
        <xsl:param name="GenereerZoNodig"/>
        <xsl:text>&#10;</xsl:text>
        <xsl:text>&#10;</xsl:text>
        <xsl:if test="count(DSG/Dosage_identification) or count(FTX[Text_subject_qualifier = 'DOS' or Text_subject_qualifier = 'PRE'])">
            <!-- als er DSG segmenten aanwezig zijn -->
            <therapeuticAgentOf xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
                <medicationAdministrationRequest>
                    <xsl:text>&#10;</xsl:text>
                    <xsl:comment>
                        <xsl:value-of select="DSG[Dosage_qualifier = 'X']/Dosage_identification"/>
                        <xsl:text>_</xsl:text>
                        <xsl:value-of select="DSG[Dosage_qualifier = 'T']/Dosage_identification"/>
                        <xsl:text>_</xsl:text>
                        <xsl:value-of select="DSG[Dosage_qualifier = 'Y']/Dosage_identification"/>
                        <xsl:text>_</xsl:text>
                        <xsl:value-of select="DSG[Dosage_qualifier = 'A']/Dosage_identification"/>
                        <xsl:text>_</xsl:text>
                        <xsl:for-each select="DSG[Dosage_qualifier = 'B']">
                            <xsl:text>_(</xsl:text>
                            <xsl:value-of select="./Dosage_identification"/>
                            <xsl:text/>
                            <xsl:text>_</xsl:text>
                            <xsl:value-of select="./Dosage"/>
                            <xsl:text>)</xsl:text>
                        </xsl:for-each>
                    </xsl:comment>
                    <xsl:text>&#10;</xsl:text>
                    <!-- RFF reference nummer als commentaar -->
                    <xsl:comment>
                        <xsl:value-of select="string('Reference Number: ')"/>
                        <xsl:value-of select="./RFF/Reference_number"/>
                    </xsl:comment>
                    <xsl:text>&#10;</xsl:text>
                    <!-- WCIA codering -->
                    <!-- als commentaar -->
                    <xsl:comment>
                        <xsl:for-each select="DSG">
                            <xsl:value-of select="./Dosage_qualifier"/>
                            <xsl:value-of select="string(':')"/>
                            <xsl:value-of select="./Dosage_identification"/>
                            <xsl:value-of select="string(':')"/>
                        </xsl:for-each>
                    </xsl:comment>
                    <xsl:text>&#10;</xsl:text>
                    <!-- id uitgeven, indien verplicht in de schema's -->
                    <!-- id nullFlavor="UNK"/-->
                    <!-- text samenstellen -->
                    <xsl:variable name="theText">
                        <!-- JLN teksten uitvoeren afhankelijk van $DosageTranslate -->
                        <xsl:if test="$DosageTranslate = 1">
                            <!--JLN xsl:for-each select="DSG-autogenerate-text-from-DSG-diabled"-->
                            <xsl:for-each select="DSG">
                                <xsl:choose>
                                    <xsl:when test="Dosage_qualifier = 'X'">
                                        <xsl:choose>
                                            <xsl:when test="./Dosage_identification='-'"/>
                                            <xsl:otherwise>
                                                <xsl:value-of select="./Dosage_identification"/>
                                                <xsl:value-of select="string('x ')"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:when>
                                    <xsl:when test="Dosage_qualifier = 'Y'">
                                        <xsl:value-of select="./Dosage_identification"/>
                                        <xsl:value-of select="string(' ')"/>
                                    </xsl:when>
                                    <xsl:when test="Dosage_qualifier = 'T'">
                                        <xsl:variable name="theDIB">
                                            <xsl:value-of select="./Dosage_identification"/>
                                        </xsl:variable>
                                        <xsl:variable name="theDIBTX">
                                            <xsl:choose>
                                                <xsl:when test="$DosageIdIsNumeric = 1">
                                                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25tijdn = $theDIB]/@t25tijdb)[1]"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25tijdm = $theDIB]/@t25tijdb)[1]"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:variable>
                                        <!-- JLN controle of de omschrijving is gevonden, ander Dosage overnemen -->
                                        <xsl:choose>
                                            <xsl:when test="$theDIBTX != ''">
                                                <xsl:value-of select="$theDIBTX"/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="Dosage"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:value-of select="string(' ')"/>
                                    </xsl:when>
                                    <xsl:when test="Dosage_qualifier = 'A'">
                                        <xsl:variable name="theDIB">
                                            <xsl:value-of select="./Dosage_identification"/>
                                        </xsl:variable>
                                        <xsl:variable name="theDIBTX">
                                            <xsl:choose>
                                                <xsl:when test="$DosageIdIsNumeric = 1">
                                                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25gan = $theDIB]/@t25gab)[1]"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25gam = $theDIB]/@t25gab)[1]"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:variable>
                                        <!-- JLN controle of de omschrijving is gevonden, anders Dosage overnemen -->
                                        <xsl:choose>
                                            <xsl:when test="$theDIBTX != ''">
                                                <xsl:value-of select="$theDIBTX"/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="Dosage"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                        <xsl:value-of select="string(' ')"/>
                                    </xsl:when>
                                    <xsl:when test="Dosage_qualifier = 'B'">
                                        <xsl:variable name="theDIB">
                                            <xsl:value-of select="./Dosage_identification"/>
                                        </xsl:variable>
                                        <xsl:variable name="theDIBMN">
                                            <!--JLN de memocode xsl:value-of select="document('codes25.xml')/*/code[@t25etikm = $theDIB]/@t25etikn"/-->
                                            <xsl:choose>
                                                <xsl:when test="$DosageIdIsNumeric = 1">
                                                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25etikn = $theDIB]/@t25etikm)[1]"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25etikm = $theDIB]/@t25etikm)[1]"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                            <!-- JLN -->
                                        </xsl:variable>
                                        <xsl:variable name="theDIBTX">
                                            <xsl:choose>
                                                <xsl:when test="$DosageIdIsNumeric = 1">
                                                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25etikn = $theDIB]/@t25etikb)[1]"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25etikm = $theDIB]/@t25etikb)[1]"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:variable>
                                        <!-- alleen aan tekst toevoegen als de B code niet in de codetabel kan worden gevonden -->
                                        <!--<xsl:if test="$theDIBMN=''">-->
                                        <!-- JLN als de B code niet is gevonden dan is $theDIBTX dus ook leeg -->
                                        <!-- JLN xsl:value-of select="$theDIBTX"/-->
                                        <!--</xsl:if>-->

                                        <!-- KH 20101116: on no FTX, all B-codes are represented in the text! -->
                                        <xsl:value-of select="string('/ ')"/>
                                        <xsl:value-of select="Dosage"/>
                                        <xsl:value-of select="string(' ')"/>

                                    </xsl:when>
                                    <xsl:otherwise/>
                                </xsl:choose>
                            </xsl:for-each>
                            <xsl:value-of select="string('~ ')"/>
                        </xsl:if>
                        <!-- aanvullende tekst -->
                        <xsl:for-each select="FTX[Text_subject_qualifier = 'DOS' or Text_subject_qualifier = 'PRE']">
                            <xsl:if test="Free_text_1 != '' ">
                                <!--xsl:value-of select="string(' ')"/-->
                                <xsl:value-of select="./Free_text_1"/>
                                <xsl:value-of select="string('~')"/>
                            </xsl:if>
                            <xsl:if test="Free_text_2 != '' ">
                                <xsl:value-of select="string(' ')"/>
                                <xsl:value-of select="./Free_text_2"/>
                                <xsl:value-of select="string('~')"/>
                            </xsl:if>
                            <xsl:if test="Free_text_3 != '' ">
                                <xsl:value-of select="string(' ')"/>
                                <xsl:value-of select="./Free_text_3"/>
                                <xsl:value-of select="string('~')"/>
                            </xsl:if>
                            <xsl:if test="Free_text_4 != '' ">
                                <xsl:value-of select="string(' ')"/>
                                <xsl:value-of select="./Free_text_4"/>
                                <xsl:value-of select="string('~')"/>
                            </xsl:if>
                            <xsl:if test="Free_text_5 != '' ">
                                <xsl:value-of select="string(' ')"/>
                                <xsl:value-of select="./Free_text_5"/>
                                <xsl:value-of select="string('~')"/>
                            </xsl:if>
                        </xsl:for-each>
                        <!--xsl:if test="DSG[current()+1]">
              <xsl:value-of select="string('~ ')"/>
            </xsl:if-->
                    </xsl:variable>
                    <!-- text alleen uitgeven als er niet alleen blanks en ~ bevat -->
                    <!--qqa>
                        <xsl:value-of select="$theText"/>
                    </qqa-->
                    <xsl:if test="normalize-space(translate($theText, '~','')) != ''">
                        <xsl:variable name="theText2">
                            <xsl:choose>
                                <!-- als alleen een ~ aan het eind staat niet mee uitgeven -->
                                <xsl:when test="substring(normalize-space($theText),string-length(normalize-space($theText)),1)='~'">
                                    <xsl:value-of select="normalize-space(substring(normalize-space($theText),1,string-length(normalize-space($theText))-1))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="normalize-space($theText)"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        <text mediaType="text/plain">
                            <xsl:value-of select="$theText2"/>
                        </text>
                    </xsl:if>
                    <statusCode code="active"/>
                    <xsl:if test="count(DSG)">
                        <xsl:choose>
                            <!-- check of b codes met gevolgen voor effectiveTime moeten worden vertaald -->
                            <!-- in XRange staan deze B codes als dit het geval is -->
                            <xsl:when test="$XRange='3W1WS'">
                                <!-- effectiveTime voor B codes 3W1WS = gedurende 3 weken, daarna 1 week stoppen -->
                                <effectiveTime xsi:type="SXPR_TS">
                                    <xsl:choose>
                                        <xsl:when test="DTM[Date_time_period_qualifier='2' or Date_time_period_qualifier='36']">
                                            <comp xsi:type="IVL_TS">
                                                <xsl:call-template name="OutputExpectedUseInterval">
                                                    <xsl:with-param name="context" select="."/>
                                                </xsl:call-template>
                                            </comp>
                                            <comp xsi:type="PIVL_TS" operator="A">
                                                <period value="1" unit="d"/>
                                            </comp>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <comp xsi:type="PIVL_TS">
                                                <period value="1" unit="d"/>
                                            </comp>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    <comp xsi:type="PIVL_TS" operator="A">
                                        <phase>
                                            <width value="21" unit="d"/>
                                        </phase>
                                        <period value="28" unit="d"/>
                                    </comp>
                                </effectiveTime>
                            </xsl:when>
                            <xsl:when test="$XRange='1W3WH'">
                                <!-- effectiveTime voor B codes 1W3WH = gedurende 1 week; na 3 weken herhalen -->
                                <effectiveTime xsi:type="SXPR_TS">
                                    <xsl:choose>
                                        <xsl:when test="DTM[Date_time_period_qualifier='2' or Date_time_period_qualifier='36']">
                                            <comp xsi:type="IVL_TS">
                                                <xsl:call-template name="OutputExpectedUseInterval">
                                                    <xsl:with-param name="context" select="."/>
                                                </xsl:call-template>
                                            </comp>
                                            <comp xsi:type="PIVL_TS" operator="A">
                                                <period value="1" unit="d"/>
                                            </comp>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <comp xsi:type="PIVL_TS">
                                                <period value="1" unit="d"/>
                                            </comp>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    <comp xsi:type="PIVL_TS" operator="A">
                                        <phase>
                                            <width value="7" unit="d"/>
                                        </phase>
                                        <period value="28" unit="d"/>
                                    </comp>
                                </effectiveTime>
                            </xsl:when>
                            <xsl:otherwise>
                                <!-- geef T DSG uit -->
                                <xsl:apply-templates select="DSG[Dosage_qualifier = 'T']">
                                    <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                                    <xsl:with-param name="XRange" select="$XRange"/>
                                </xsl:apply-templates>
                            </xsl:otherwise>
                        </xsl:choose>
                        <xsl:choose>
                            <xsl:when test="count(DSG[Dosage_qualifier = 'A'])">
                                <xsl:apply-templates select="DSG[Dosage_qualifier = 'A']">
                                    <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                                </xsl:apply-templates>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:apply-templates select="DSG[Dosage_qualifier = 'Y']">
                                    <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                                </xsl:apply-templates>
                            </xsl:otherwise>
                        </xsl:choose>

                        <!--
                            B codes afhandelen
                            voor bepaalde b-codes (volgens de code lookup tabel) vertaald
                            - als precondition (PRECOND)
                            - als maxDoseQuantity (MAXQUAN)
                            - of in alle andere gevallen als medicationAdministrationInstruction (SUPPORT)
                        -->
                        <xsl:for-each select="DSG[Dosage_qualifier = 'B']">
                            <xsl:variable name="theDI">
                                <xsl:value-of select="./Dosage_identification"/>
                            </xsl:variable>
                            <xsl:variable name="theDX">
                                <xsl:value-of select="./Dosage"/>
                            </xsl:variable>
                            <xsl:variable name="theCat">
                                <xsl:choose>
                                    <xsl:when test="string-length((document('codes25.xml')/*/bcode[@code = $theDI or @mnemonic=$theDI]/@cat)[1])>0">
                                        <xsl:value-of select="(document('codes25.xml')/*/bcode[@code = $theDI or @mnemonic=$theDI]/@cat)[1]"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:text>SUPPORT</xsl:text>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:variable>
                            <!-- commentaar uitgeven -->
                            <xsl:comment>
                                <xsl:text>B-code: </xsl:text>
                                <xsl:value-of select="$theDI"/>
                                <xsl:text> : </xsl:text>
                                <xsl:value-of select="$theDX"/>
                                <xsl:text> = </xsl:text>
                                <xsl:value-of select="$theCat"/>
                            </xsl:comment>
                            <xsl:call-template name="DSGB">
                                <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                                <xsl:with-param name="bcodes">
                                    <xsl:value-of select="$theCat"/>
                                </xsl:with-param>
                                <xsl:with-param name="theDI" select="$theDI"/>
                                <xsl:with-param name="theDX" select="$theDX"/>
                            </xsl:call-template>
                        </xsl:for-each>

                    </xsl:if>

                    <!-- als GenereerZoNodig=1 (aanroep parameter), dan genereer nog een zo nodig instructie indien nog niet gedaan -->
                    <xsl:if test="$GenereerZoNodig=1 and (count(DSG[Dosage_qualifier = 'B']/Dosage_identification[text()='ZN' or text()='1137'])=0)">
                        <xsl:comment>
                            <xsl:text>B-code: ZN : Zo nodig = PRECOND (2nd MAR variable frequency)</xsl:text>
                        </xsl:comment>
                        <precondition>
                            <observationEventCriterion>
                                <code code="1137" codeSystem="2.16.840.1.113883.2.4.4.5" displayName="zo nodig"/>
                            </observationEventCriterion>
                        </precondition>
                    </xsl:if>

                </medicationAdministrationRequest>
            </therapeuticAgentOf>
        </xsl:if>
    </xsl:template>

    <!--
        Template voor DSG
    -->
    <xsl:template match="DSG">
        <xsl:param name="DosageIdIsNumeric"/>
        <xsl:param name="XRange"/>
        
        <!-- frequentie en tijdseenheid -->
        <xsl:if test="Dosage_qualifier = 'T'">
            <xsl:choose>
                <!-- Als -ttYYYYYaa (X == '-'), dan pas afhandelen bij DSG[Dosage_qualifier='A'] -->
                <xsl:when test="../DSG[Dosage_qualifier = 'X']/Dosage_identification/text()='-' and not (Dosage_identification = 'O' or Dosage_identification = '22')">
                    <xsl:if test="../DTM[Date_time_period_qualifier='2' or Date_time_period_qualifier='36']">
                        <effectiveTime xsi:type="IVL_TS">
                            <xsl:call-template name="OutputExpectedUseInterval">
                                <xsl:with-param name="context" select=".."/>
                            </xsl:call-template>
                        </effectiveTime>
                    </xsl:if>
                </xsl:when>
                <!-- Als -XttYYYYYaa (X == 'n'), dan pas afhandelen bij DSG[Dosage_qualifier='A'], behalve "om de dag" -->
                
                <xsl:when test="substring(../DSG[Dosage_qualifier = 'X']/Dosage_identification/text(),1,1)='-' and not (Dosage_identification = 'O' or Dosage_identification = '22')"/>
                
                <xsl:when test="Dosage_identification != '0' and Dosage_identification != '99' and Dosage_identification != '~'">
                    <effectiveTime>
                        <xsl:choose>
                            <xsl:when test="Dosage_identification = 'O' or Dosage_identification = '22' ">
                                <!-- om de dag -->
                                <xsl:attribute name="xsi:type">SXPR_TS</xsl:attribute>
                                <xsl:choose>
                                    <xsl:when test="../DTM[Date_time_period_qualifier='2' or Date_time_period_qualifier='36']">
                                        <comp xsi:type="IVL_TS">
                                            <xsl:call-template name="OutputExpectedUseInterval">
                                                <xsl:with-param name="context" select=".."/>
                                            </xsl:call-template>
                                        </comp>
                                        <comp xsi:type="PIVL_TS" operator="A">
                                            <period value="1" unit="d"/>
                                        </comp>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <comp xsi:type="PIVL_TS">
                                            <period value="1" unit="d"/>
                                        </comp>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <comp xsi:type="PIVL_TS" operator="A">
                                    <phase>
                                        <width value="1" unit="d"/>
                                    </phase>
                                    <period value="2" unit="d"/>
                                </comp>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:variable name="theDI">
                                    <xsl:value-of select="./Dosage_identification"/>
                                </xsl:variable>
                                <xsl:variable name="theDX">
                                    <xsl:choose>
                                        <!-- neem aan dat X=1 :: X leeg is of DSG[X] ontbreekt -->
                                        <xsl:when test="../DSG[Dosage_qualifier = 'X']/Dosage_identification/text()=''">
                                            <xsl:value-of select="1"/>
                                        </xsl:when>
                                        <xsl:when test="count(../DSG[Dosage_qualifier = 'X'])=0">
                                            <xsl:value-of select="1"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:choose>
                                                <xsl:when test="$XRange=''">
                                                    <xsl:value-of select="translate(../DSG[Dosage_qualifier = 'X']/Dosage_identification, ',', '.')"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="$XRange"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:variable>
                                <xsl:choose>
                                    <xsl:when test="../DTM[Date_time_period_qualifier='2' or Date_time_period_qualifier='36']">
                                        <xsl:attribute name="xsi:type">SXPR_TS</xsl:attribute>
                                        <comp xsi:type="IVL_TS">
                                            <xsl:call-template name="OutputExpectedUseInterval">
                                                <xsl:with-param name="context" select=".."/>
                                            </xsl:call-template>
                                        </comp>
                                        <comp xsi:type="PIVL_TS" operator="A">
                                            <period>
                                                <xsl:choose>
                                                    <xsl:when test="$DosageIdIsNumeric = 0">
                                                        <xsl:attribute name="value">
                                                            <xsl:value-of select="round(10000 * (document('codes25.xml')/*/code[@t25tijdm = $theDI][1]/@HL7tijdv div $theDX)) div 10000"/>
                                                        </xsl:attribute>
                                                        <xsl:attribute name="unit">
                                                            <xsl:value-of select="document('codes25.xml')/*/code[@t25tijdm = $theDI][1]/@HL7tijdu"/>
                                                        </xsl:attribute>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:attribute name="value">
                                                            <xsl:value-of select="round(10000 * (document('codes25.xml')/*/code[@t25tijdn = $theDI][1]/@HL7tijdv div $theDX)) div 10000"/>
                                                        </xsl:attribute>
                                                        <xsl:attribute name="unit">
                                                            <xsl:value-of select="document('codes25.xml')/*/code[@t25tijdn = $theDI][1]/@HL7tijdu"/>
                                                        </xsl:attribute>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </period>
                                        </comp>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="xsi:type">PIVL_TS</xsl:attribute>
                                        <period>
                                            <xsl:choose>
                                                <xsl:when test="$DosageIdIsNumeric = 0">
                                                    <xsl:attribute name="value">
                                                        <xsl:value-of select="round(10000 * (document('codes25.xml')/*/code[@t25tijdm = $theDI][1]/@HL7tijdv div $theDX)) div 10000"/>
                                                    </xsl:attribute>
                                                    <xsl:attribute name="unit">
                                                        <xsl:value-of select="document('codes25.xml')/*/code[@t25tijdm = $theDI][1]/@HL7tijdu"/>
                                                    </xsl:attribute>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:attribute name="value">
                                                        <xsl:value-of select="round(10000 * (document('codes25.xml')/*/code[@t25tijdn = $theDI][1]/@HL7tijdv div $theDX)) div 10000"/>
                                                    </xsl:attribute>
                                                    <xsl:attribute name="unit">
                                                        <xsl:value-of select="document('codes25.xml')/*/code[@t25tijdn = $theDI][1]/@HL7tijdu"/>
                                                    </xsl:attribute>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </period>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:otherwise>
                        </xsl:choose>
                    </effectiveTime>
                </xsl:when>
                <!--xsl:otherwise>
                    <xsl:if test="../DTM[Date_time_period_qualifier='2' or Date_time_period_qualifier='36']">
                        <effectiveTime xsi:type="IVL_TS">
                            <xsl:call-template name="OutputExpectedUseInterval">
                                <xsl:with-param name="context" select=".."/>
                            </xsl:call-template>
                        </effectiveTime>
                    </xsl:if>
                </xsl:otherwise-->
            </xsl:choose>
        </xsl:if>
        <!-- doseerhoeveelheid in vorm YA -->
        <xsl:if test="Dosage_qualifier = 'A' or Dosage_qualifier = 'Y'">
            <xsl:variable name="HL7yau">
                <xsl:choose>
                    <xsl:when test="$DosageIdIsNumeric = 0">
                        <xsl:value-of select="document('codes25.xml')/*/code[@t25gam = current()/Dosage_identification][1]/@HL7yau"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="document('codes25.xml')/*/code[@t25gan = current()/Dosage_identification][1]/@HL7yau"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <xsl:variable name="HL7yav">
                <xsl:choose>
                    <xsl:when test="$DosageIdIsNumeric = 0">
                        <xsl:value-of select="document('codes25.xml')/*/code[@t25gam = current()/Dosage_identification][1]/@HL7yav"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="document('codes25.xml')/*/code[@t25gan = current()/Dosage_identification][1]/@HL7yav"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>

            <xsl:choose>
                <xsl:when test="../DSG[Dosage_qualifier = 'Y']/Dosage_identification= '-'">
                    <!-- do nothing here -->
                </xsl:when>
                <xsl:when test="contains(../DSG[Dosage_qualifier = 'Y']/Dosage_identification, '-')">
                    <xsl:variable name="theYl">
                        <xsl:variable name="theYPre">
                            <xsl:value-of select="translate(substring-before(../DSG[Dosage_qualifier = 'Y']/Dosage_identification,'-'), ',','.')"/>
                        </xsl:variable>
                        <xsl:choose>
                            <xsl:when test="contains($theYPre, '/')">
                                <xsl:variable name="theYc">
                                    <xsl:value-of select="translate(substring-before($theYPre,'/'), ',','.')"/>
                                </xsl:variable>
                                <xsl:variable name="theYd">
                                    <xsl:value-of select="translate(substring-after($theYPre,'/'), ',','.')"/>
                                </xsl:variable>
                                <xsl:choose>
                                    <xsl:when test="($HL7yav * ($theYc div $theYd)) &lt; 1">
                                        <!-- correctie voor product kleiner 1 -> door ronden van 1/n op hele getal -->
                                        <xsl:value-of select="round(10000 * ($HL7yav * ($theYc div $theYd))) div 10000"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <!-- in alle anderen gevallen gaat het zo goed -->
                                        <xsl:value-of select="round(100000 div ($HL7yav * ($theYc div $theYd)) div 100) div 1000"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$theYPre"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:variable>
                    <xsl:variable name="theYh">
                        <xsl:variable name="theYPre">
                            <xsl:value-of select="translate(substring-after(../DSG[Dosage_qualifier = 'Y']/Dosage_identification,'-'), ',','.')"/>
                        </xsl:variable>
                        <xsl:choose>
                            <xsl:when test="contains($theYPre, '/')">
                                <xsl:variable name="theYc">
                                    <xsl:value-of select="translate(substring-before($theYPre,'/'), ',','.')"/>
                                </xsl:variable>
                                <xsl:variable name="theYd">
                                    <xsl:value-of select="translate(substring-after($theYPre,'/'), ',','.')"/>
                                </xsl:variable>
                                <xsl:choose>
                                    <xsl:when test="($HL7yav * ($theYc div $theYd)) &lt; 1">
                                        <!-- correctie voor product kleiner 1 -> door ronden van 1/n op hele getal -->
                                        <xsl:value-of select="round(10000 * ($HL7yav * ($theYc div $theYd))) div 10000"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <!-- in alle anderen gevallen gaat het zo goed -->
                                        <xsl:value-of select="round(100000 div ($HL7yav * ($theYc div $theYd)) div 100) div 1000"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="$theYPre"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:variable>
                    <xsl:if test="../DSG[Dosage_qualifier = 'X']/Dosage_identification!='-'">
                        <doseQuantity>
                            <xsl:if test="string-length($theYl)&gt;0">
                                <low>
                                    <xsl:choose>
                                        <xsl:when test="$HL7yau != '' ">
                                            <xsl:attribute name="value">
                                                <xsl:value-of select="$HL7yav * $theYl"/>
                                            </xsl:attribute>
                                            <xsl:attribute name="unit">
                                                <xsl:value-of select="$HL7yau"/>
                                            </xsl:attribute>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:attribute name="value">
                                                <xsl:value-of select="1 * $theYl"/>
                                            </xsl:attribute>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    <xsl:call-template name="DSGAtranslation">
                                        <xsl:with-param name="value25" select="$theYl"/>
                                        <xsl:with-param name="valuehl7">
                                            <xsl:choose>
                                                <xsl:when test="$HL7yau != '' ">
                                                    <xsl:value-of select="$HL7yav * $theYl"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="1 * $theYl"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:with-param>
                                        <xsl:with-param name="unithl7" select="$HL7yau"/>
                                        <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                                    </xsl:call-template>
                                </low>
                            </xsl:if>
                            <xsl:if test="string-length($theYh)&gt;0">
                                <high>
                                    <xsl:choose>
                                        <xsl:when test="$HL7yau != '' ">
                                            <xsl:attribute name="value">
                                                <xsl:value-of select="$HL7yav * $theYh"/>
                                            </xsl:attribute>
                                            <xsl:attribute name="unit">
                                                <xsl:value-of select="$HL7yau"/>
                                            </xsl:attribute>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:attribute name="value">
                                                <xsl:value-of select="1 * $theYh"/>
                                            </xsl:attribute>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                    <xsl:call-template name="DSGAtranslation">
                                        <xsl:with-param name="value25" select="$theYh"/>
                                        <xsl:with-param name="valuehl7">
                                            <xsl:choose>
                                                <xsl:when test="$HL7yau != '' ">
                                                    <xsl:value-of select="$HL7yav * $theYh"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="1 * $theYh"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:with-param>
                                        <xsl:with-param name="unithl7" select="$HL7yau"/>
                                        <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                                    </xsl:call-template>
                                </high>
                            </xsl:if>
                        </doseQuantity>
                    </xsl:if>
                    <!-- Max dosering per tijdseenheid, of zo iets -->
                    <xsl:if test="../DSG[Dosage_qualifier = 'X']/Dosage_identification/text()='-'">
                        <xsl:variable name="theDI">
                            <xsl:value-of select="../DSG[Dosage_qualifier = 'T']/Dosage_identification"/>
                        </xsl:variable>
                        <doseCheckQuantity>
                            <!-- Output yA -->
                            <numerator xsi:type="IVL_PQ">
                                <xsl:if test="string-length($theYl)">
                                    <low>
                                        <xsl:attribute name="value">
                                            <xsl:value-of select="$theYl"/>
                                        </xsl:attribute>
                                        <xsl:choose>
                                            <xsl:when test="$HL7yau != ''">
                                                <xsl:attribute name="unit">
                                                    <xsl:value-of select="$HL7yau"/>
                                                </xsl:attribute>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:attribute name="unit">
                                                    <xsl:value-of select="1"/>
                                                </xsl:attribute>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </low>
                                </xsl:if>
                                <xsl:if test="string-length($theYh)">
                                    <high>
                                        <xsl:attribute name="value">
                                            <xsl:value-of select="$theYh"/>
                                        </xsl:attribute>
                                        <xsl:choose>
                                            <xsl:when test="$HL7yau != ''">
                                                <xsl:attribute name="unit">
                                                    <xsl:value-of select="$HL7yau"/>
                                                </xsl:attribute>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:attribute name="unit">
                                                    <xsl:value-of select="1"/>
                                                </xsl:attribute>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </high>
                                </xsl:if>
                            </numerator>
                            <!-- Output -T -->
                            <denominator xsi:type="PQ" value="1">
                                <xsl:choose>
                                    <xsl:when test="$DosageIdIsNumeric = 0">
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="document('codes25.xml')/*/code[@t25tijdm = $theDI][1]/@HL7tijdu"/>
                                        </xsl:attribute>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="document('codes25.xml')/*/code[@t25tijdn = $theDI][1]/@HL7tijdu"/>
                                        </xsl:attribute>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </denominator>
                        </doseCheckQuantity>
                    </xsl:if>
                </xsl:when>
                <xsl:when test="contains(../DSG[Dosage_qualifier = 'Y']/Dosage_identification, '/')">
                    <xsl:variable name="theYavProd">
                        <xsl:variable name="theYc">
                            <xsl:value-of select="translate(substring-before(../DSG[Dosage_qualifier = 'Y']/Dosage_identification,'/'), ',','.')"/>
                        </xsl:variable>
                        <xsl:variable name="theYd">
                            <xsl:value-of select="translate(substring-after(../DSG[Dosage_qualifier = 'Y']/Dosage_identification,'/'), ',','.')"/>
                        </xsl:variable>
                        <xsl:choose>
                            <xsl:when test="($HL7yav * ($theYc div $theYd)) &lt; 1">
                                <!-- correctie voor product kleiner 1 -> door ronden van 1/n op hele getal -->
                                <xsl:value-of select="round(10000 * ($HL7yav * ($theYc div $theYd))) div 10000"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <!-- in alle anderen gevallen gaat het zo goed -->
                                <xsl:value-of select="round(100000 div ($HL7yav * ($theYc div $theYd)) div 100) div 1000"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:variable>
                    <xsl:if test="../DSG[Dosage_qualifier = 'X']/Dosage_identification!='-'">
                        <doseQuantity>
                            <center>
                                <xsl:choose>
                                    <xsl:when test="$HL7yau != '' ">
                                        <xsl:attribute name="value">
                                            <xsl:value-of select="$theYavProd"/>
                                        </xsl:attribute>
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="$HL7yau"/>
                                        </xsl:attribute>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="value">
                                            <xsl:value-of select="$theYavProd"/>
                                        </xsl:attribute>
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="1"/>
                                        </xsl:attribute>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:call-template name="DSGAtranslation">
                                    <xsl:with-param name="value25" select="../DSG[Dosage_qualifier = 'Y']/Dosage_identification"/>
                                    <xsl:with-param name="valuehl7" select="$theYavProd"/>
                                    <xsl:with-param name="unithl7" select="$HL7yau"/>
                                    <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                                </xsl:call-template>
                            </center>
                        </doseQuantity>
                    </xsl:if>
                    <!-- Max dosering per tijdseenheid -->
                    <xsl:if test="../DSG[Dosage_qualifier = 'X']/Dosage_identification/text()='-'">
                        <xsl:variable name="theDI">
                            <xsl:value-of select="../DSG[Dosage_qualifier = 'T']/Dosage_identification"/>
                        </xsl:variable>
                        <doseCheckQuantity>
                            <!-- Output yA -->
                            <numerator xsi:type="PQ">
                                <xsl:attribute name="value">
                                    <xsl:value-of select="$theYavProd"/>
                                </xsl:attribute>
                                <xsl:choose>
                                    <xsl:when test="$HL7yau != ''">
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="$HL7yau"/>
                                        </xsl:attribute>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="1"/>
                                        </xsl:attribute>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:call-template name="DSGAtranslation">
                                    <xsl:with-param name="value25" select="../DSG[Dosage_qualifier = 'Y']/Dosage_identification"/>
                                    <xsl:with-param name="valuehl7" select="$theYavProd"/>
                                    <xsl:with-param name="unithl7">
                                        <xsl:choose>
                                            <xsl:when test="$HL7yau != ''">
                                                <xsl:value-of select="$HL7yau"/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="1"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:with-param>
                                    <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                                </xsl:call-template>
                            </numerator>
                            <!-- Output -T -->
                            <denominator xsi:type="PQ" value="1">
                                <xsl:choose>
                                    <xsl:when test="$DosageIdIsNumeric = 0">
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="document('codes25.xml')/*/code[@t25tijdm = $theDI][1]/@HL7tijdu"/>
                                        </xsl:attribute>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="document('codes25.xml')/*/code[@t25tijdn = $theDI][1]/@HL7tijdu"/>
                                        </xsl:attribute>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </denominator>
                        </doseCheckQuantity>
                    </xsl:if>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:variable name="theY">
                        <xsl:value-of select="translate(../DSG[Dosage_qualifier = 'Y']/Dosage_identification, ',', '.')"/>
                    </xsl:variable>
                    <xsl:if test="../DSG[Dosage_qualifier = 'X']/Dosage_identification!='-'">
                        <doseQuantity>
                            <center>
                                <xsl:choose>
                                    <xsl:when test="$HL7yau != '' ">
                                        <xsl:attribute name="value">
                                            <xsl:value-of select="$HL7yav * $theY"/>
                                        </xsl:attribute>
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="$HL7yau"/>
                                        </xsl:attribute>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="value">
                                            <xsl:choose>
                                                <xsl:when test="../DSG[Dosage_qualifier = 'Y']/Dosage_identification">
                                                    <xsl:value-of select="1 * $theY"/>
                                                </xsl:when>
                                                <xsl:otherwise>
                                                    <xsl:value-of select="1"/>
                                                </xsl:otherwise>
                                            </xsl:choose>
                                        </xsl:attribute>
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="1"/>
                                        </xsl:attribute>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:call-template name="DSGAtranslation">
                                    <xsl:with-param name="value25" select="../DSG[Dosage_qualifier = 'Y']/Dosage_identification"/>
                                    <xsl:with-param name="valuehl7">
                                        <xsl:choose>
                                            <xsl:when test="$HL7yau != '' ">
                                                <xsl:value-of select="$HL7yav * $theY"/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:choose>
                                                    <xsl:when test="../DSG[Dosage_qualifier = 'Y']/Dosage_identification">
                                                        <xsl:value-of select="1 * $theY"/>
                                                    </xsl:when>
                                                    <xsl:otherwise>
                                                        <xsl:value-of select="1"/>
                                                    </xsl:otherwise>
                                                </xsl:choose>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:with-param>
                                    <xsl:with-param name="unithl7" select="$HL7yau"/>
                                    <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                                </xsl:call-template>
                            </center>
                        </doseQuantity>
                    </xsl:if>
                    <!-- Max dosering per tijdseenheid -->
                    <xsl:if test="../DSG[Dosage_qualifier = 'X']/Dosage_identification/text()='-'">
                        <xsl:variable name="theDI">
                            <xsl:value-of select="../DSG[Dosage_qualifier = 'T']/Dosage_identification/text()"/>
                        </xsl:variable>
                        <doseCheckQuantity>
                            <!-- Output yA -->
                            <numerator xsi:type="PQ">
                                <xsl:attribute name="value">
                                    <xsl:value-of select="$theY"/>
                                </xsl:attribute>
                                <xsl:choose>
                                    <xsl:when test="$HL7yau != ''">
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="$HL7yau"/>
                                        </xsl:attribute>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="unit">
                                            <xsl:value-of select="1"/>
                                        </xsl:attribute>
                                    </xsl:otherwise>
                                </xsl:choose>
                                <xsl:call-template name="DSGAtranslation">
                                    <xsl:with-param name="value25" select="../DSG[Dosage_qualifier = 'Y']/Dosage_identification"/>
                                    <xsl:with-param name="valuehl7" select="$theY"/>
                                    <xsl:with-param name="unithl7">
                                        <xsl:choose>
                                            <xsl:when test="$HL7yau != ''">
                                                <xsl:value-of select="$HL7yau"/>
                                            </xsl:when>
                                            <xsl:otherwise>
                                                <xsl:value-of select="1"/>
                                            </xsl:otherwise>
                                        </xsl:choose>
                                    </xsl:with-param>
                                    <xsl:with-param name="DosageIdIsNumeric" select="$DosageIdIsNumeric"/>
                                </xsl:call-template>
                            </numerator>
                            <!-- Output -T -->
                            <denominator xsi:type="PQ">
                                <xsl:attribute name="value" select="document('codes25.xml')/*/code[@t25tijdm = $theDI][1]/@HL7tijdv"/>
                                <xsl:choose>
                                    <xsl:when test="$DosageIdIsNumeric = 0">
                                        <xsl:attribute name="unit" select="document('codes25.xml')/*/code[@t25tijdm = $theDI][1]/@HL7tijdu"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:attribute name="unit" select="document('codes25.xml')/*/code[@t25tijdn = $theDI][1]/@HL7tijdu"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </denominator>
                        </doseCheckQuantity>
                    </xsl:if>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:template>
    <!--

     template voor DSG B codes

    -->
    <xsl:template name="DSGB">
        <xsl:param name="DosageIdIsNumeric"/>
        <xsl:param name="bcodes"/>
        <xsl:param name="theDI"/>
        <xsl:param name="theDX"/>
        <!-- B codes -->
        <xsl:if test="Dosage_qualifier = 'B'">
            <!-- Altijd de memocode uitvoeren, opslaan in theDIcode -->
            <xsl:variable name="theDIcode">
                <xsl:choose>
                    <xsl:when test="$DosageIdIsNumeric = 0">
                        <xsl:value-of select="$theDI"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="(document('codes25.xml')/*/code[@t25etikn = $theDI]/@t25etikm)[1]"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <!-- Dosage tekst vinden als ie er nog niet is -->
            <!-- JLN niets uitvoeren als de omschrijving niet gevonden kan worden -->
            <xsl:variable name="theBtext">
                <xsl:value-of select="(document('codes25.xml')/*/code[@t25etikm = $theDIcode]/@t25etikb)[1]"/>
            </xsl:variable>
            <!-- JLN  -->
            
            <xsl:choose>
                <!-- B codes randvoorwaarden voor toediening, zo nodig enz -->
                <xsl:when test="$bcodes = 'SUPPORT' and ($theDIcode!='' or $theDX!='') and $theBtext != '' ">
                    <support2>
                        <medicationAdministrationInstruction>
                            <code>
                                <!-- set the numeric value of the tabel 25 code -->
                                <xsl:attribute name="code" select="(document('codes25.xml')/*/code[@t25etikm = $theDIcode]/@t25etikn)[1]"/>
                                <!-- set the code system of the numeric values -->
                                <xsl:attribute name="codeSystem" select="'2.16.840.1.113883.2.4.4.5'"/>
                                <!-- displayName toevoegen -->
                                <xsl:attribute name="displayName" select="$theBtext"/>
                            </code>
                        </medicationAdministrationInstruction>
                    </support2>
                </xsl:when>
                <!-- B codes, maximale doseerhoeveelheid -->
                <xsl:when test="$bcodes = 'MAXQUAN'">
                    <maxDoseQuantity>
                        <xsl:choose>
                            <xsl:when test="$theDIcode = 'MX4PD' ">
                                <numerator value="4" unit="1"/>
                                <denominator xsi:type="PQ" value="1" unit="d"/>
                            </xsl:when>
                            <xsl:when test="$theDIcode = 'MX8PW' ">
                                <numerator value="8" unit="1"/>
                                <denominator xsi:type="PQ" value="1" unit="wk"/>
                            </xsl:when>
                            <xsl:when test="$theDIcode = 'MX2PD' ">
                                <numerator value="2" unit="1"/>
                                <denominator xsi:type="PQ" value="1" unit="d"/>
                            </xsl:when>
                            <xsl:when test="$theDIcode = 'MX4PW' ">
                                <numerator value="4" unit="1"/>
                                <denominator xsi:type="PQ" value="1" unit="wk"/>
                            </xsl:when>
                            <xsl:when test="$theDIcode = 'MX10W' ">
                                <numerator value="10" unit="1"/>
                                <denominator xsi:type="PQ" value="1" unit="wk"/>
                            </xsl:when>
                            <xsl:when test="$theDIcode = 'MX5PW' ">
                                <numerator value="5" unit="1"/>
                                <denominator xsi:type="PQ" value="1" unit="wk"/>
                            </xsl:when>
                            <xsl:when test="$theDIcode = 'MXE' ">
                                <numerator value="6" unit="mg"/>
                                <denominator xsi:type="PQ" value="1" unit="d"/>
                            </xsl:when>
                            <xsl:when test="$theDIcode = 'MX8PD' ">
                                <numerator value="8" unit="1"/>
                                <denominator xsi:type="PQ" value="1" unit="d"/>
                            </xsl:when>
                            <xsl:when test="$theDIcode = 'MX12D' ">
                                <numerator value="12" unit="1"/>
                                <denominator xsi:type="PQ" value="1" unit="d"/>
                            </xsl:when>
                            <xsl:otherwise/>
                        </xsl:choose>
                    </maxDoseQuantity>
                </xsl:when>
                <!-- B codes, precondition -->
                <xsl:when test="$bcodes = 'PRECOND'">
                    <precondition>
                        <observationEventCriterion>
                            <code>
                                <!-- set the numeric value of the tabel 25 code -->
                                <xsl:attribute name="code" select="(document('codes25.xml')/*/code[@t25etikm = $theDIcode]/@t25etikn)[1]"/>
                                <!-- set the code system of the numeric values -->
                                <xsl:attribute name="codeSystem" select="'2.16.840.1.113883.2.4.4.5'"/>
                                <!-- displayName toevoegen -->
                                <xsl:attribute name="displayName" select="$theBtext"/>
                            </code>
                        </observationEventCriterion>
                    </precondition>
                </xsl:when>
                <xsl:otherwise>
                    <!-- this should not happen but if no B-code can be translated, convey it at least as free text in originalText with no code :-( -->
                    <support2>
                        <medicationAdministrationInstruction>
                            <code nullFlavor="OTH">
                                <originalText><xsl:value-of select="$theDI"/><xsl:text>: </xsl:text><xsl:value-of select="$theDX"/></originalText>
                            </code>
                        </medicationAdministrationInstruction>
                    </support2>
                </xsl:otherwise>
            </xsl:choose>
            
            
            
            
            
        </xsl:if>
    </xsl:template>

    <!--
        doseereenheden translation elementen toevoegen
    -->
    <xsl:template name="DSGAtranslation">
        <xsl:param name="value25"/>
        <xsl:param name="valuehl7"/>
        <xsl:param name="unithl7"/>
        <xsl:param name="DosageIdIsNumeric"/>
        <!-- G-Standaard thesaurus tabel 002 als translation toevoegen als er een vertalign/mapping is -->
        <xsl:variable name="transU2">
            <xsl:choose>
                <xsl:when test="$unithl7!=''">
                    <xsl:value-of select="(document('codes25.xml')/*/code[@hl7c = $unithl7]/@th002n)[1]"/>
                </xsl:when>
                <xsl:when test="current()/Dosage_identification!=''">
                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25gam = current()/Dosage_identification]/@th002n)[1]"/>
                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25gan = current()/Dosage_identification]/@th002n)[1]"/>
                </xsl:when>
            </xsl:choose>
        </xsl:variable>
        <!--debugDSGtrans value25="{$value25}" valuehl7="{$valuehl7}" unithl7="{$unithl7}" transU2="{$transU2}" DI="{current()/Dosage_identification}"/-->
        <xsl:if test="$transU2!='' and ../DSG[Dosage_qualifier = 'A']/Dosage_identification!='' and $valuehl7!=''">
            <translation>
                <xsl:attribute name="value">
                    <xsl:value-of select="$valuehl7"/>
                </xsl:attribute>
                <xsl:attribute name="code">
                    <xsl:value-of select="$transU2"/>
                </xsl:attribute>
                <xsl:attribute name="codeSystem">
                    <xsl:value-of select="string('2.16.840.1.113883.2.4.4.1.900.2')"/>
                </xsl:attribute>
                <xsl:attribute name="displayName">
                    <xsl:value-of select="(document('codes25.xml')/*/code[@th002n = $transU2]/@th002o)[1]"/>
                </xsl:attribute>
            </translation>
        </xsl:if>
        <!-- numerieke/mnemonic A component tabel 25 (zoals in de EDIFACT gebruikt) maar alleen als er geen fracties zijn aangegeven -->
        <xsl:if
            test="(../DSG[Dosage_qualifier = 'A']/Dosage_identification!='') and       (not(contains(../DSG[Dosage_qualifier =
      'Y']/Dosage_identification, '/'))) and (not(contains($value25, '-'))) and ($value25!='')">
            <translation>
                <xsl:attribute name="value">
                    <xsl:value-of select="translate($value25, ',', '.')"/>
                </xsl:attribute>
                <xsl:attribute name="code">
                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25gam = current()/Dosage_identification]/@t25gan)[1]"/>
                    <xsl:value-of select="(document('codes25.xml')/*/code[@t25gan = current()/Dosage_identification]/@t25gan)[1]"/>
                </xsl:attribute>
                <xsl:attribute name="codeSystem">
                    <xsl:value-of select="string('2.16.840.1.113883.2.4.4.1.361')"/>
                </xsl:attribute>
                <xsl:attribute name="displayName">
                    <xsl:value-of select="current()/Dosage"/>
                </xsl:attribute>
            </translation>
        </xsl:if>
    </xsl:template>

    <!--
        DTM+2 (Delivery Date/Verstrekkingsdatum) en DTM+36 (Expiry Date/Einddatum)
        Parameter context should be set to G0011 node
    -->
    <xsl:template name="OutputExpectedUseInterval">
        <xsl:param name="context"/>
        <xsl:variable name="lowDate" select="$context/DTM[Date_time_period_qualifier='2']/Date_time"/>
        <xsl:variable name="highDate" select="$context/DTM[Date_time_period_qualifier='36']/Date_time"/>
        <xsl:variable name="lowParsedDate">
            <xsl:variable name="dateTemp" select="$context/DTM[Date_time_period_qualifier='2']/Date_time"/>
            <xsl:value-of
                select="concat(
                substring($dateTemp, 1, 4), '-',
                substring($dateTemp, 5, 2), '-',
                substring($dateTemp, 7, 2)
                )"/>
        </xsl:variable>
        <xsl:variable name="highParsedDate">
            <xsl:variable name="dateTemp" select="$context/DTM[Date_time_period_qualifier='36']/Date_time"/>
            <xsl:value-of
                select="concat(
                substring($dateTemp, 1, 4), '-',
                substring($dateTemp, 5, 2), '-',
                substring($dateTemp, 7, 2)
                )"/>
        </xsl:variable>
        <xsl:comment>
            <xsl:if test="$lowDate!=''">
                <xsl:text>Verstrekkingsdatum: </xsl:text>
                <xsl:value-of select="format-date(xs:date($lowParsedDate),'[Y0001]-[M01]-[D01]', 'en', (), ())"/>
            </xsl:if>
            <xsl:if test="$lowDate!='' and $highDate!=''">
                <xsl:text> / </xsl:text>
            </xsl:if>
            <xsl:if test="$highDate!=''">
                <xsl:text>Einddatum: </xsl:text>
                <xsl:value-of select="format-date(xs:date($highParsedDate), '[Y0001]-[M01]-[D01]', 'en', (), ())"/>
            </xsl:if>
        </xsl:comment>
        <xsl:choose>
            <xsl:when test="$lowDate and $lowDate!='' and $highDate and $highDate!=''">
                <width>
                    <xsl:attribute name="value">
                        <!-- Note: days-from-duration is specifiek XSLT 2.0 -->
                        <xsl:value-of select="days-from-duration(xs:date($highParsedDate) - xs:date($lowParsedDate) + xs:dayTimeDuration('P1D'))"/>
                    </xsl:attribute>
                    <xsl:attribute name="unit">
                        <xsl:value-of select="'d'"/>
                    </xsl:attribute>
                </width>
            </xsl:when>
            <xsl:when test="$lowDate and $lowDate!=''">
                <low>
                    <xsl:attribute name="value">
                        <xsl:value-of select="concat($lowDate,'0000')"/>
                    </xsl:attribute>
                </low>
            </xsl:when>
            <xsl:when test="$highDate and $highDate!=''">
                <high>
                    <xsl:attribute name="value">
                        <xsl:value-of select="concat($highDate,'2359')"/>
                    </xsl:attribute>
                </high>
            </xsl:when>
        </xsl:choose>
    </xsl:template>
</xsl:stylesheet>
