<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xmlns:xd="http://www.oxygenxml.com/ns/doc/xsl"
    xmlns:hl7="urn:hl7-org:v3"
    xmlns:SOAP-ENV="http://schemas.xmlsoap.org/soap/envelope/"
    xmlns:date="http://exslt.org/dates-and-times"
    xmlns:exsl="http://exslt.org/common"
    xmlns="urn:hl7-org:v3"
    exclude-result-prefixes="xsl xs xsi xd hl7 date SOAP-ENV exsl"
    version="1.0">
    
    <xd:doc scope="stylesheet">
        <xd:desc>
            <xd:p><xd:b>Note to self:</xd:b> search for key words FIXME and TODO for things that MUST be dealt with before making status FINAL</xd:p>
            <xd:p><xd:b>FIXME:</xd:b> ContraIndications and ObservationIntolerances MUST NOT be copied for g_outputInteractionId = QUPC_IN443230NL</xd:p>
            <xd:p><xd:b>Author:</xd:b> ahenket (AH)/gmeijboom (GM) - Copyright &#169; 2012 by Nictiz</xd:p>
            <xd:p><xd:b>Version:</xd:b> 0.8.7 - <xd:b>Status:</xd:b> DRAFT</xd:p>
            <xd:p><xd:b>Purpose:</xd:b> provide a mapping for <xd:b>QUPC_IN990002NL</xd:b> to one of <xd:b>QUPC_IN443230NL</xd:b>, <xd:b>QUPC_IN443231NL</xd:b>, <xd:b>QUPC_IN443232NL</xd:b>, and for one of <xd:b>QUPC_IN443130NL</xd:b>, <xd:b>QUPC_IN443131NL</xd:b>, <xd:b>QUPC_IN443132NL</xd:b> to <xd:b>QUPC_IN990001NL</xd:b></xd:p>
            <xd:p><xd:b>Prerequisites:</xd:b> <xd:ul>
                <xd:li>any XSLT 1.0 capable transformation engine that includes support for EXSL (http://www.exsl.org). Tested with Saxon 6.5.5 and Xalan-J</xd:li>
                <xd:li>XML Schema valid instance of interaction QUPC_IN443130NL, <xd:i>or</xd:i></xd:li>
                <xd:li>XML Schema valid instance of interaction QUPC_IN443131NL, <xd:i>or</xd:i></xd:li>
                <xd:li>XML Schema valid instance of interaction QUPC_IN443132NL, <xd:i>or</xd:i></xd:li>
                <xd:li>XML Schema valid instance of interaction QUPC_IN990002NL, <xd:i>or</xd:i></xd:li>
                <xd:li>XML Schema valid instance of interaction MCCI_IN200101 containing no interactions, or XML Schema valid instances of QUPC_IN990002NL</xd:li>
            </xd:ul></xd:p>
            <xd:p><xd:b>Example call:</xd:b> <xd:pre>java -jar saxon.jar inputFile.xml PrimaryCareProvision2CareProvision.xsl -o outputFile.xml g_outputInteractionId=QUPC_IN443230NL g_tsToday=20120919125023</xd:pre></xd:p>
            <xd:p><xd:b>Example call:</xd:b> <xd:pre>java -jar xalan.jar -IN inputFile.xml -XSL PrimaryCareProvision2CareProvision.xsl -OUT outputFile.xml -PARAM g_outputInteractionId QUPC_IN443230NL g_tsToday=20120919125023</xd:pre></xd:p>
            <xd:p><xd:b>Underlying specification:</xd:b> AORTA_7PriCa_Mapping_CP_HAZ.xls version 1.0</xd:p>
            <xd:p>The output document contains a one of several types of CareProvisions or a PS-query. Each one needs a (slightly) different mapping. It is left up to the caller of this transformation 
                to tell us through the parameter '<xd:ref name="g_outputInteractionId" type="parameter">g_outputInteractionId</xd:ref>' which output document is expected.</xd:p>
            <xd:p>Specific filtering is applied on what gets transformed into the output based on the output interactionId. The filtering works as follows: <xd:ul>
                <xd:li><xd:b><xd:i>Opvragen Professionele samenvatting</xd:i></xd:b>. g_outputInteractionId = <xd:i>ignored, but mandatory</xd:i> <xd:ul>
                    <xd:li>No specific filtering, but only the parameter patientId can be transformed into the output</xd:li>
                </xd:ul></xd:li>
                <!-- NOTE: "Geen levenstestament en codicil" - are not encoded in the input PS -->
                <!-- NOTE: "Geen reanimatiebeleid, levenstestament en codicil"  - are not encoded in the input PS -->
                <!-- NOTE: Correspondence and Ook bekend bij are not encoded in the input PS -->
                <xd:li><xd:b><xd:i>Professionele Samenvatting Meldkamer (Meldkamer-PS)</xd:i></xd:b>. g_outputInteractionId = QUPC_IN443230NL <xd:ul>
                    <xd:li>EpisodeOfCondition - Open episodes - Get PrimaryCareProvision/component7/EpisodeOfCondition[not(statusCode='completed' or effectiveTime/high)]</xd:li>
                    <xd:li>Contact - Datum contact t/m 10 dg geleden - Get PrimaryCareProvision/component1/encounter[$today-effectiveTime/low/@value &lt;= 10000000]</xd:li>
                    <xd:li>Journaalregel - Behorend bij de geselecteerde contacten - Get every JournalEntry under copied encounter</xd:li>
                    <xd:li>Diagnose - Behorend bij de geselecteerde contacten - Get every ObservationDx under copied encounter</xd:li>
                    <xd:li>Uitslag (meting, bepaling) - Datum meting t/m 10 dg geleden - Get PrimaryCareProvision/component2/observation[$today-effectiveTime/low/@value &lt;= 10000000]</xd:li>
                    <xd:li>Overdrachtgegevens - Alles - Get PrimaryCareProvision, PrimaryCareProvision/pertinentInformation</xd:li>
                    <xd:li>Correspondentie - Datum brief t/m 10 dg geleden - not possible</xd:li>
                    <xd:li>Belaste familieanamnese - Alles - not possible</xd:li>
                    <xd:li>Ook bekend bij - Datum brief tot 2 jaar geleden - not possible</xd:li>
                </xd:ul>
                </xd:li>
                <xd:li><xd:b><xd:i>Professionele Samenvatting Ambulance (Ambulance-PS)</xd:i></xd:b>. g_outputInteractionId = QUPC_IN443231NL <xd:ul>
                    <xd:li>EpisodeOfCondition - Open episodes - Get PrimaryCareProvision/component7/EpisodeOfCondition[not(statusCode='completed' or effectiveTime/high)]</xd:li>
                    <xd:li>Contact - Datum contact t/m 10 dg geleden - Get PrimaryCareProvision/component1/encounter[$today-effectiveTime/low/@value &lt;= 10000000]</xd:li>
                    <xd:li>Journaalregel - Behorend bij de geselecteerde contacten - Get every JournalEntry under copied encounter</xd:li>
                    <xd:li>Diagnose - Behorend bij de geselecteerde contacten - Get every ObservationDx under copied encounter</xd:li>
                    <xd:li>Uitslag (meting, bepaling) - Datum meting t/m 10 dg geleden - Get PrimaryCareProvision/component2/observation[$today-effectiveTime/low/@value &lt;= 10000000]</xd:li>
                    <xd:li>Overdrachtgegevens - Alles - Get PrimaryCareProvision, PrimaryCareProvision/pertinentInformation</xd:li>
                    <xd:li>Correspondentie - Datum brief t/m 10 dg geleden - not possible</xd:li>
                    <xd:li>Belaste familieanamnese - Alles - not possible</xd:li>
                    <xd:li>Ook bekend bij - not permitted</xd:li>
                </xd:ul>
                </xd:li>
                <xd:li><xd:b><xd:i>Professionele Samenvatting Spoedeisende Hulp (SEH-PS)</xd:i></xd:b>. g_outputInteractionId = QUPC_IN443232NL <xd:ul>
                    <xd:li>EpisodeOfCondition - Open episodes - Get PrimaryCareProvision/component7/EpisodeOfCondition[not(statusCode='completed' or effectiveTime/high)]</xd:li>
                    <xd:li>Contact - Datum contact t/m 10 dg geleden - Get PrimaryCareProvision/component1/encounter[$today-effectiveTime/low/@value &lt;= 10000000]</xd:li>
                    <xd:li>Journaalregel - Behorend bij de geselecteerde contacten - Get every JournalEntry under copied encounter</xd:li>
                    <xd:li>Diagnose - Behorend bij de geselecteerde contacten - Get every ObservationDx under copied encounter</xd:li>
                    <xd:li>Uitslag (meting, bepaling) - Datum meting t/m 10 dg geleden - Get PrimaryCareProvision/component2/observation[$today-effectiveTime/low/@value &lt;= 10000000]</xd:li>
                    <xd:li>Overdrachtgegevens - Alles - Get PrimaryCareProvision, PrimaryCareProvision/pertinentInformation</xd:li>
                    <xd:li>Correspondentie - Datum brief t/m 10 dg geleden - not possible</xd:li>
                    <xd:li>Belaste familieanamnese - Alles - not possible</xd:li>
                    <xd:li>Ook bekend bij - not permitted</xd:li>
                </xd:ul>
                </xd:li>
            </xd:ul></xd:p>
            <xd:p><xd:b>History:</xd:b>
                <xd:ul>
                    <xd:li><xd:b>2012-09-19</xd:b> AH - version 0.8.7<xd:ul>
                        <xd:li>Overall: merge of CSC version 0.8.5 with Nictiz version 0.8.6. Purpose is not to have a disjunct between the versions anymore</xd:li>
                        <xd:li>Change: output will not have an XML declaration anymore (omit-xml-declaration="yes")</xd:li>
                        <xd:li>Change: all references to XML Schema and Schematron have been removed. These don't belong in production. These were for debugging purposes and had no message impact</xd:li>
                        <xd:li>Change: all xsl:comments have been removed and a comment was added that Xalan-C does not support xsl:comment with nested xsl statements. These were for debugging purposes and had no message impact</xd:li>
                        <xd:li>Change: added REQUIRED parameter <xd:ref name="g_tsToday" type="parameter">g_tsToday</xd:ref> that MUST hold the current date/time as YYYYMMddhhmmss. This circumvents the need to call exslt functions for getting todays date as this is not supported in Xalan-C.</xd:li>
                    </xd:ul></xd:li>
                    <xd:li><xd:b>2012-06-05</xd:b> AH - version 0.8.6<xd:ul>
                        <xd:li>Change: copy ObservationIntolerance/statusCode only if it has @code. A number of examples were found without @code</xd:li>
                        <xd:li>Change: copy [episodeOfCondition|ContraIndication|ObservationIntolerance|observation]/text only if it has text(). A number of examples were found without content</xd:li>
                        <xd:li>Change: copy [annotation|episodeOfCondition|ContraIndication|ObservationIntolerance|observation|ObservationDx]/effectiveTime only if it has content (.//@nullFlavor or .//@value). A number of examples were found without content</xd:li>
                    </xd:ul></xd:li>
                    <xd:li><xd:b>2012-06-04</xd:b> AH/GM - version 0.8.5<xd:ul>
                        <xd:li>Change: added transformation of ContraIndication and ObservationIntolerance</xd:li>
                        <xd:li>Bugfix: attributes on ObservationDx where copied in context of ObservationDx/code</xd:li>
                    </xd:ul></xd:li>
                    <xd:li><xd:b>2012-05-31</xd:b> AH - version 0.8.1<xd:ul>
                        <xd:li>Change: fixed all FIXMEs and TODOs with regards to transformation. This led to one change in the handling of EpisodeOfCondition. EpisodeOfCondition/text is now mapped as well</xd:li>
                        <xd:li>Bugfix: ActReferences were not copied, regardless of whether or not the target was copied. This was due the way that the variable copyIndex was handed over from template to template. This should have been plain and without type casting.</xd:li>
                        <xd:li>Change: xsi:types are now patched in a more secure fashion. Always first copy all attributes, then write xsi:type explicitly</xd:li>
                    </xd:ul></xd:li>
                    <xd:li><xd:b>2012-05-24</xd:b> AH - version 0.8<xd:ul>
                        <xd:li>Change: Rewrite to XSLT 1.0. Tested with Xalan-J and Saxon 6.5.5. Since XSLT 1.0 does not support any date functions natively, the use of EXSL was required (see: http://www.exslt.org). This enables date calculations based on 'today' needed in the filtering of events that occurred more than 10 days ago. The second thing that was needed to that same end was the esxl:node-set() function as XSLT 1.0 does not natively support casting to nodeset from a variable. See variables copyIndex, <xd:ref name="tsDate" type="variable">tsDate</xd:ref>, <xd:ref name="tsTime" type="variable">tsTime</xd:ref>,and <xd:ref name="logDate" type="variable">logDate</xd:ref> for examples of where these function are used</xd:li>
                    </xd:ul></xd:li>
                    <xd:li><xd:b>2012-04-24</xd:b> AH - version 0.7.1<xd:ul>
                        <xd:li>Second round of steep testing based on 218 XML Schema valid, qualification test messages. All changes were based on variations found in those. This round the filtering was removed so (almost all data was copied giving much more to test against)</xd:li>
                        <xd:li>Bugfix: <xd:ref name="ProfessionalSummary" type="template">QUPC_IN990002NL</xd:ref>, component2 Activities were always copied instead of based on effectiveTime due to an incorrect XPath</xd:li>
                        <xd:li>Change: <xd:ref name="ProfessionalSummary" type="template">QUPC_IN990002NL</xd:ref>, added traceability comments on component2 Activities to see which were skipped</xd:li>
                        <xd:li>Change: <xd:ref name="Encounter" type="template">Encounter</xd:ref>, most common input errors in Encounter.code are now fixed in the transformation, see new template <xd:ref name="EncounterCode" type="template">EncounterCode</xd:ref> for details</xd:li>
                        <xd:li>Change: <xd:ref name="Encounter" type="template">Encounter</xd:ref>, most common input errors in Encounter.effectiveTime are now fixed in the transformation, see <xd:ref name="effectiveTime">effectiveTime</xd:ref> for details</xd:li>
                        <xd:li>Change: <xd:ref name="ActReference" type="template">ActReference</xd:ref>, qualification testing on the input has not been very strong, so we need to distrust whatever is present in @classCode/@moodCode and determine that ourselves based on the object the ActReference refers to</xd:li>
                        <xd:li>Change: <xd:ref name="Activityobservation" type="template">observation</xd:ref>, added fixme on observation.id. Most input doesn't have this, but output requires it. Suggestion: fix output spec to allow null</xd:li>
                        <xd:li>Change: <xd:ref name="effectiveTime" type="template">effectiveTime</xd:ref>, now also fixes equal low/high with date+hour and date+hour+minute</xd:li>
                        <xd:li>Change: extended, rearranged documentation</xd:li>
                    </xd:ul></xd:li>
                    <xd:li><xd:b>2012-04-24</xd:b> AH - version 0.7<xd:ul>
                        <xd:li>Steep testing based on 218 XML Schema valid, qualification test messages. Most changes were based on variations found in those. Filtering was active.</xd:li>
                        <xd:li>Bugfix: <xd:ref name="ProfessionalSummary" type="template">QUPC_IN990002NL</xd:ref>, added support for ControlActProcess/reason, and made ControlActProcess/subject optional</xd:li>
                        <xd:li>Bugfix: <xd:ref name="PrimaryCareProvision" type="template">PrimaryCareProvision</xd:ref>, switched order of PrimaryCareProvision/author, and PrimaryCareProvision/perfomer</xd:li>
                        <xd:li>Bugfix: <xd:ref name="PrimaryCareProvision" type="template">PrimaryCareProvision</xd:ref>, only copy episodeOfCondition if it has a diagnosis with at least a code and effectiveTime to avoid XML Schema problem in output</xd:li>
                        <xd:li>Bugfix: <xd:ref name="R_AssignedEntityUniversal" type="template">R_AssignedEntityUniversal</xd:ref> if contents of a supposedly Universal element is Identified after all, use appropriate templateId</xd:li>
                        <xd:li>Bugfix: <xd:ref name="pertinentAnnotationObsEvent" type="template">pertinentAnnotationObsEvent</xd:ref> effectiveTime needed explicit @xsi:type="IVL_TS". Call from <xd:ref name="PrimaryCareProvision">PrimaryCareProvision</xd:ref> and <xd:ref name="EpisodeOfCondition">EpisodeOfCondition</xd:ref> </xd:li>
                        <xd:li>Bugfix: <xd:ref name="ActivityObservationDx" type="template">ObservationDx</xd:ref> Some vendors took our older examples literally and forgot @codeSystem in ObservationDx/code. Fixed that input mistake for output.</xd:li>
                        <xd:li>Bugfix: <xd:ref name="ActivityObservationDx" type="template">ObservationDx</xd:ref> Changed author mapping to go to AssignedEntity instead of AssignedPerson.</xd:li>
                        <xd:li>Removed support for Activities/act since it was not in the PS-spec yet and so no testing was possible</xd:li>
                        <xd:li>Only copy JournalEntry and ObservationDx when available via component2 (not in scope of an encounter) and less than 10 days old</xd:li>
                        <xd:li>New: <xd:ref name="effectiveTime">effectiveTime</xd:ref>, created separate template to fix certain variations of low==high</xd:li>
                    </xd:ul></xd:li>
                    <xd:li><xd:b>2012-04-22</xd:b> AH - version 0.6.5<xd:ul>
                        <xd:li>Added support to transforming the query interactions QUPC_IN443130NL, QUPC_IN443131NL, QUPC_IN443132NL to QUPC_IN990001NL.</xd:li>
                    </xd:ul></xd:li>
                    <xd:li><xd:b>2012-04-22</xd:b> AH - version 0.6<xd:ul>
                        <xd:li>Implemented first version of filtering. Feature complete except for questions around CareStatement/act and what to do with component2/*. Filter just filters component1/encounter</xd:li>
                        <xd:li>Fixed and simplified AssignedEntity/AssignedPerson support</xd:li>
                        <xd:li>Fixed actReference support</xd:li>
                        <xd:li>Extended documentation, but not finished</xd:li>
                        <xd:li>Added rudimentary traceability information to let you know where a certain piece of info came from</xd:li>
                    </xd:ul></xd:li>
                    <xd:li><xd:b>2012-04-20</xd:b> AH - version 0.5.2<xd:ul>
                        <xd:li>Extended documentation</xd:li>
                    </xd:ul></xd:li>
                    <xd:li><xd:b>2012-04-18</xd:b> AH - version 0.5.1<xd:ul>
                        <xd:li>Added minimal disclaimer with reference to LGPL and copyright</xd:li>
                    </xd:ul>
                    </xd:li>
                    <xd:li><xd:b>2012-04-18</xd:b> AH - version 0.5<xd:ul>
                        <xd:li>Initial version. Tested with all available example files in xml-WDH</xd:li>
                        <xd:li>Known issue - filters per output document not implemented yet</xd:li>
                    </xd:ul></xd:li>
                </xd:ul>
            </xd:p>
            <xd:p><xd:b>Disclaimer:</xd:b></xd:p>
            <xd:p><xd:i>This program is free software; you can redistribute it and/or modify it under the terms of the
                GNU Lesser General Public License as published by the Free Software Foundation; either version
                2.1 of the License, or (at your option) any later version.</xd:i></xd:p>
            <xd:p><xd:i>This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
                without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
                See the GNU Lesser General Public License for more details.</xd:i></xd:p>
            <xd:p><xd:i>The full text of the license is available at http://www.gnu.org/copyleft/lesser.html</xd:i></xd:p>
        </xd:desc>
    </xd:doc>
    
    <xd:doc>
        <xd:desc>
            <xd:p><xd:b>g_outputInteractionId</xd:b> is a REQUIRED parameter. The output interaction of this XSL, the parameter <xd:ref name="g_outputTemplateId" type="parameter">g_outputTemplateId</xd:ref> and some of the contents depend on the value of this parameter.</xd:p>
            <xd:p>The choices are:
                <xd:ul>
                    <xd:li><xd:i>Professionele Samenvatting Meldkamer (Meldkamer-PS)</xd:i>. g_outputInteractionId = QUPC_IN443230NL (g_outputTemplateId = 2.16.840.1.113883.2.4.6.10.40.30)</xd:li>
                    <xd:li><xd:i>Professionele Samenvatting Ambulance (Ambulance-PS)</xd:i>. g_outputInteractionId = QUPC_IN443231NL (g_outputTemplateId = 2.16.840.1.113883.2.4.6.10.40.31)</xd:li>
                    <xd:li><xd:i>Professionele Samenvatting Spoedeisende Hulp (SEH-PS)</xd:i>. g_outputInteractionId = QUPC_IN443232NL (g_outputTemplateId = 2.16.840.1.113883.2.4.6.10.40.32)</xd:li>
                </xd:ul></xd:p>
        </xd:desc>
    </xd:doc>
    <!--NOTE: Uncomment next line to test -->
    <!--xsl:param name="g_outputInteractionId" select="'QUPC_IN443230NL'"/-->
    <xsl:param name="g_outputInteractionId"/>
    
    <xd:doc>
        <xd:desc>
            <xd:p><xd:b>g_outputTemplateId</xd:b> is an OPTIONAL parameter. See <xd:ref name="g_outputInteractionId" type="parameter">g_outputInteractionId</xd:ref> for supported values</xd:p>
            <xd:p>TemplateId that should be generated by this transformation, defaults for known interactionIds but may be overridden. Generally this should NOT be necessary.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:param name="g_outputTemplateId">
        <xsl:choose>
            <xsl:when test="$g_outputInteractionId='QUPC_IN443230NL'">
                <xsl:value-of select="'2.16.840.1.113883.2.4.6.10.40.30'"/>
            </xsl:when>
            <xsl:when test="$g_outputInteractionId='QUPC_IN443231NL'">
                <xsl:value-of select="'2.16.840.1.113883.2.4.6.10.40.31'"/>
            </xsl:when>
            <xsl:when test="$g_outputInteractionId='QUPC_IN443232NL'">
                <xsl:value-of select="'2.16.840.1.113883.2.4.6.10.40.32'"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:message terminate="yes">Unsupported interactionId through parameter 'g_outputInteractionId': <xsl:value-of select="$g_outputInteractionId"/></xsl:message>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:param>
    
    <xd:doc>
        <xd:desc>
            <xd:p><xd:b>g_tsToday</xd:b> is a REQUIRED parameter. It MUST contain the current date/time as a timestamp in the format YYYYMMddhhmmss. This date is used to do date filtering against. Most filtering is done based on "not more than 10 days ago". See also <xd:ref name="tenDaysAgo" type="variable">tenDaysAgo</xd:ref></xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:param name="g_tsToday"/>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Output will be XML and indented for readability and encoded in UTF-8</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:output indent="yes" method="xml" encoding="UTF-8" omit-xml-declaration="yes"/>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Picks the date part from the timestamp</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:variable name="tsDate" select="substring($g_tsToday,1,8)"/>
    <xd:doc>
        <xd:desc>
            <xd:p>Picks the time part from the timestamp</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:variable name="tsTime" select="substring($g_tsToday,9,6)"/>
    <xd:doc>
        <xd:desc>
            <xd:p>Picks up the full date as integer</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:variable name="tsToday" select="number(concat($tsDate,$tsTime))"/>
    
    <xd:doc>
        <xd:desc>
            <xd:p>tenDaysAgo sets the number that marks a difference of 10 days when you subtract two timestamps, e.g. <xd:ref name="tsToday">tsToday</xd:ref> -  encounter effectiveTime.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:variable name="tenDaysAgo" select="number('10000000')"/>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Version for this stylesheet, to be used for reference only</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:variable name="g_version" select="'0.8.7'"/>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Date of conversion by this stylesheet, to be used for reference only</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:variable name="logDate" select="concat(substring($tsDate,7,2),'-',substring($tsDate,5,2),'-',substring($tsDate,1,4),' ',substring($tsDate,9,2),':',substring($tsDate,11,2),':',substring($tsDate,13,2))"/>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Main entrance point for this transformation. Terminates with message upon unsupported input.</xd:p>
            <xd:p>Only supports <xd:ref name="BatchResponseWrapper" type="template">MCCI_IN200101</xd:ref> (Batch Response - empty or containing QUPC_IN990002NL), <xd:ref name="ProfessionalSummary" type="template">QUPC_IN990002NL</xd:ref> (Professional Summary), or <xd:ref name="ProfessionalSummaryQuery" type="template">'QUPC_IN443130NL', 'QUPC_IN443131NL', or 'QUPC_IN443132NL'</xd:ref> (Professional Summary Query) </xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="/">
        <!-- Check parameter values -->
        <xsl:call-template name="sanityCheck"/>
        
        <!-- NOTE: comments with contained variables not supported by Xalan-C -->
        <!--xsl:comment> Converted from <xsl:value-of select="local-name(hl7:*)"/> by PrimaryCareProvision2CareProvision.xsl <xsl:value-of select="$g_version"/> at <xsl:value-of select="$logDate"/> </xsl:comment-->
        <xsl:choose>
            <!-- TODO: find out if support for batches is needed at all. Added support for convenience here -->
            <xsl:when test="/hl7:MCCI_IN200101[hl7:QUPC_IN990002NL or not(following-sibling::hl7:sender)]">
                <xsl:message>[info] Supported interaction. Found '<xsl:value-of select="name(*[1])"/>', transforming into '<xsl:value-of select="name(*[1])"/>' with date string '<xsl:value-of select="$tsToday"/>'</xsl:message>
                <xsl:apply-templates select="/hl7:MCCI_IN200101"/>
            </xsl:when>
            <xsl:when test="/hl7:QUPC_IN990002NL">
                <xsl:message>[info] Supported interaction. Found '<xsl:value-of select="name(*[1])"/>', transforming into '<xsl:value-of select="$g_outputInteractionId"/>' with date string '<xsl:value-of select="$tsToday"/>'</xsl:message>
                <xsl:apply-templates select="/hl7:QUPC_IN990002NL"/>
            </xsl:when>
            <xsl:when test="/hl7:QUPC_IN443130NL | /hl7:QUPC_IN443131NL | /hl7:QUPC_IN443132NL">
                <xsl:message>[info] Supported interaction. Found '<xsl:value-of select="name(*[1])"/>', transforming into 'QUPC_IN990001NL' with date string '<xsl:value-of select="$tsToday"/>'</xsl:message>
                <xsl:apply-templates select="/hl7:QUPC_IN443130NL | /hl7:QUPC_IN443131NL | /hl7:QUPC_IN443132NL"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:message terminate="yes">[error] Unsupported interaction. Found '<xsl:value-of select="name(*[1])"/>', but need 'MCCI_IN200101' containing 'QUPC_IN990002NL', or plain 'QUPC_IN990002NL', or one of 'QUPC_IN443130NL', 'QUPC_IN443131NL', 'QUPC_IN443132NL'</xsl:message>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Template for element MCCI_IN200101 which is the batch response wrapper. Copies from MCCI_IN200101 to MCCI_IN200101.</xd:p>
            <xd:p>Operation: copies all elements specific to the batch response wrapper as-is, except the root element, versionCode, and interactionId. The latter are fixed to avoid version conflicts. After copying the wrapper elements, the interaction QUPC_IN990002NL (if available) is handed to the <xd:ref name="ProfessionalSummary" type="template">applicable template</xd:ref>.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:MCCI_IN200101" name="BatchResponseWrapper">
        <!-- NOTE: do not leave active Schematron/XML Schema references in production -->
        <!--xsl:processing-instruction name="nictiz">status="test"</xsl:processing-instruction-->
        <!--xsl:processing-instruction name="oxygen">SCHSchema="../schematron/haz-pqr-mk-r.sch"</xsl:processing-instruction-->
        <!--xsl:processing-instruction name="oxygen">SCHSchema="../schematron/MCCI_IN200101.sch"</xsl:processing-instruction-->
        <!--xsl:element name="MCCI_IN200101" namespace="urn:hl7-org:v3" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="urn:hl7-org:v3 ../schemas/MCCI_IN200101.xsd"-->
        <xsl:element name="MCCI_IN200101" namespace="urn:hl7-org:v3" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:creationTime" mode="copy"/>
            <versionCode code="NICTIZEd2005-Okt"/>
            <interactionId extension="MCCI_IN200101" root="2.16.840.1.113883.1.6"/>
            <xsl:apply-templates select="hl7:profileId" mode="copy"/>
            <xsl:apply-templates select="hl7:transmissionQuantity" mode="copy"/>
            <xsl:apply-templates select="hl7:acknowledgement" mode="copy"/>
            <xsl:apply-templates select="hl7:receiver" mode="copy"/>
            <xsl:apply-templates select="hl7:sender" mode="copy"/>
            <xsl:apply-templates select="hl7:QUPC_IN990002NL"/>
        </xsl:element>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Template for element 'QUPC_IN443130NL', 'QUPC_IN443131NL', 'QUPC_IN443132NL' which is the professional summary query interaction. Copies to QUPC_IN990001NL, ignoring the interaction specified in the parameter <xd:ref>g_outputInteractionId</xd:ref> This template always called directly.</xd:p>
            <xd:p>Operation: copies all wrapper elements specific to the interaction as-is, except the root element, versionCode, interactionId, profileId, processingCode, processingModeCode, and acceptAckCode. The latter are fixed to avoid version conflicts.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:QUPC_IN443130NL | hl7:QUPC_IN443131NL | hl7:QUPC_IN443132NL" name="ProfessionalSummaryQuery">
        <!-- NOTE: do not leave active Schematron/XML Schema references in production -->
        <!--xsl:processing-instruction name="nictiz">status="test"</xsl:processing-instruction-->
        <!--xsl:processing-instruction name="oxygen">SCHSchema="../schematron/QUPC_IN990001NL.sch"</xsl:processing-instruction-->
        <xsl:element name="QUPC_IN990001NL" namespace="urn:hl7-org:v3" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
            <!--xsl:element name="{$g_outputInteractionId}" namespace="urn:hl7-org:v3" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"-->
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:creationTime" mode="copy"/>
            <versionCode code="NICTIZEd2005-Okt"/>
            <interactionId extension="QUPC_IN990001NL" root="2.16.840.1.113883.1.6"/>
            <profileId root="2.16.840.1.113883.2.4.3.11.1" extension="810"/>
            <processingCode code="P"/>
            <processingModeCode code="T"/>
            <acceptAckCode code="NE"/>
            <xsl:apply-templates select="hl7:receiver" mode="copy"/>
            <xsl:apply-templates select="hl7:sender" mode="copy"/>
            <ControlActProcess moodCode="EVN">
                <!-- NOT mapping ControlActProcess/code -->
                <!-- NOT mapping ControlActProcess/effectiveTime -->
                <authorOrPerformer typeCode="AUT">
                    <participant>
                        <AssignedPerson>
                            <xsl:apply-templates select="(hl7:ControlActProcess/hl7:authorOrPerformer//hl7:*[hl7:id])[1]/hl7:*" mode="copy"/>
                        </AssignedPerson>
                    </participant>
                </authorOrPerformer>
                <overseer typeCode="RESP">
                    <assignedEntity>
                        <xsl:apply-templates select="(hl7:ControlActProcess/hl7:overseer//hl7:*[hl7:id])[1]/hl7:*" mode="copy"/>        
                    </assignedEntity>
                </overseer>
                <queryByParameter>
                    <xsl:apply-templates select="hl7:ControlActProcess/hl7:queryByParameter/hl7:templateId" mode="copy"/>
                    <xsl:apply-templates select="hl7:ControlActProcess/hl7:queryByParameter/hl7:queryId" mode="copy"/>
                    <xsl:apply-templates select="hl7:ControlActProcess/hl7:queryByParameter/hl7:statusCode" mode="copy"/>
                    <xsl:apply-templates select="hl7:ControlActProcess/hl7:queryByParameter/hl7:responseElementGroupId" mode="copy"/>
                    <!-- TODO: need to do Batch query conversion here or is that done outside this XSLT? -->
                    <xsl:apply-templates select="hl7:ControlActProcess/hl7:queryByParameter/hl7:responseModalityCode" mode="copy"/>
                    <xsl:apply-templates select="hl7:ControlActProcess/hl7:queryByParameter/hl7:responsePriorityCode" mode="copy"/>
                    <xsl:apply-templates select="hl7:ControlActProcess/hl7:queryByParameter/hl7:initialQuantity" mode="copy"/>
                    <xsl:apply-templates select="hl7:ControlActProcess/hl7:queryByParameter/hl7:initialQuantityCode" mode="copy"/>
                    <xsl:apply-templates select="hl7:ControlActProcess/hl7:queryByParameter/hl7:executionAndDeliveryTime" mode="copy"/>
                    <!-- Query parameters: only patientId is allowed -->
                    <xsl:apply-templates select="hl7:ControlActProcess/hl7:queryByParameter/hl7:parameterList/hl7:patientId" mode="copy"/>
                </queryByParameter>
            </ControlActProcess>
        </xsl:element>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Template for element QUPC_IN990002NL which is the professional summary response interaction. Copies QUPC_IN990002NL to the interaction specified in the parameter <xd:ref>g_outputInteractionId</xd:ref> This template called either directly, or via the <xd:ref name="BatchResponseWrapper" type="template">MCCI_IN200101</xd:ref> batch response template.</xd:p>
            <xd:p>Operation: copies all wrapper elements specific to the interaction as-is, except the root element, versionCode, interactionId, profileId, processingCode, processingModeCode, and acceptAckCode. The latter are fixed to avoid version conflicts.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:QUPC_IN990002NL" name="ProfessionalSummary">
        <!-- NOTE: do not leave active Schematron/XML Schema references in production -->
        <!--xsl:processing-instruction name="nictiz">status="test"</xsl:processing-instruction-->
        <!--xsl:processing-instruction name="oxygen">SCHSchema="../schematron/haz-pqr-mk-r.sch"</xsl:processing-instruction-->
        <xsl:element name="{$g_outputInteractionId}" namespace="urn:hl7-org:v3" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
        <!--xsl:element name="{$g_outputInteractionId}" namespace="urn:hl7-org:v3" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" xsi:schemaLocation="urn:hl7-org:v3 ../schemas/{$g_outputInteractionId}.xsd"-->
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:creationTime" mode="copy"/>
            <versionCode code="NICTIZEd2005-Okt"/>
            <interactionId extension="{$g_outputInteractionId}" root="2.16.840.1.113883.1.6"/>
            <profileId root="2.16.840.1.113883.2.4.3.11.1" extension="810"/>
            <processingCode code="P"/>
            <processingModeCode code="T"/>
            <acceptAckCode code="NE"/>
            <xsl:apply-templates select="hl7:acknowledgement" mode="copy"/>
            <xsl:apply-templates select="hl7:receiver" mode="copy"/>
            <xsl:apply-templates select="hl7:sender" mode="copy"/>
            <ControlActProcess moodCode="EVN">
                <xsl:apply-templates select="hl7:ControlActProcess/hl7:authorOrPerformer" mode="copy"/>
                <!-- Technically the overseer would never be present... -->
                <xsl:apply-templates select="hl7:ControlActProcess/hl7:overseer" mode="copy"/>
                <xsl:if test="hl7:ControlActProcess/hl7:subject">
                    <subject typeCode="SUBJ">
                        <xsl:apply-templates select="hl7:ControlActProcess/hl7:subject/hl7:PrimaryCareProvision"/>
                    </subject>
                </xsl:if>
                <xsl:apply-templates select="hl7:ControlActProcess/hl7:reasonOf" mode="copy"/>
                <xsl:apply-templates select="hl7:ControlActProcess/hl7:queryAck" mode="copy"/>
            </ControlActProcess>
        </xsl:element>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Template for element PrimaryCareProvision which is the professional summary payload. Copies PrimaryCareProvision element to CareProvisionEvent element, based on output template <xd:ref name="g_outputTemplateId" type="parameter">g_outputTemplateId</xd:ref></xd:p>
            <xd:p>Operation: <xd:ul>
                <xd:li>First builds an index of ids for encounters with their activities and separate activities. This index is used to filter on</xd:li>
                <xd:li>fixed templateId <xd:i><xd:ref name="g_outputTemplateId" type="parameter">g_outputTemplateId</xd:ref></xd:i></xd:li>
                <xd:li>PrimaryCareProvision/id - any as-is</xd:li>
                <xd:li><xd:i>PrimaryCareProvision/text - no mapping.</xd:i></xd:li>
                <xd:li>PrimaryCareProvision/statusCode - any as-is</xd:li>
                <xd:li>PrimaryCareProvision/effectiveTime - any as-is</xd:li>
                <xd:li><xd:i>PrimaryCareProvision/confidentialityCode - no mapping.</xd:i></xd:li>
                <xd:li>PrimaryCareProvision/subject - copy any as recordTarget via <xd:ref name="R_PatientNLUniversal" type="template">R_PatientNL Universal</xd:ref></xd:li>
                <xd:li>PrimaryCareProvision/author - copy any as author via <xd:ref name="R_AssignedEntityUniversal" type="template">R_AssignedEntity Universal</xd:ref>. Add time, modeCode, signatureCode with @nullFlavor="NI" to satisfy output requirements</xd:li>
                <xd:li>PrimaryCareProvision/performer - copy any as performer via <xd:ref name="R_AssignedEntityUniversal" type="template">R_AssignedEntity Universal</xd:ref>.</xd:li>
                <xd:li><xd:i>PrimaryCareProvision/custodian - no mapping.</xd:i></xd:li>
                <xd:li><xd:i>PrimaryCareProvision/dataEnterer - no mapping.</xd:i></xd:li>
                <xd:li>PrimaryCareProvision/component7 - copy any as reason via <xd:ref name="EpisodeOfCondition" type="template">EpisodeOfCondition</xd:ref>. <xd:ul>
                    <xd:li><xd:i>PrimaryCareProvision/component7 - no sequenceNumber</xd:i></xd:li>
                </xd:ul></xd:li>
                <xd:li>PrimaryCareProvision/pertinentInformation - copy any as pertinentInformation3 via <xd:ref name="pertinentAnnotationObsEvent" type="template">pertinentAnnotationObsEvent</xd:ref>.</xd:li>
                <xd:li>PrimaryCareProvision/component1 - copy any whose id is contained in copyIndex as pertinentInformation3 via <xd:ref name="Encounter" type="template">Encounter</xd:ref>.</xd:li>
                <xd:li>PrimaryCareProvision/component2 - copy any whose id is contained in copyIndex as pertinentInformation3. <xd:ul>
                    <xd:li>PrimaryCareProvision/component2/JournalEntry whose id is contained in copyIndex via <xd:ref name="ActivityJournalEntry" type="template">JournalEntry</xd:ref>.</xd:li>
                    <xd:li>PrimaryCareProvision/component2/observation whose id is contained in copyIndex via <xd:ref name="Activityobservation" type="template">observation</xd:ref>.</xd:li>
                    <xd:li>PrimaryCareProvision/component2/ObservationDx whose id is contained in copyIndex via <xd:ref name="ActivityObservationDx" type="template">ObservationDx</xd:ref>.</xd:li>
                    <xd:li><xd:i>PrimaryCareProvision/component2/act - no mapping.</xd:i></xd:li>
                    <xd:li><xd:i>PrimaryCareProvision/component2/MedicationDispenseEvent - no mapping.</xd:i></xd:li>
                    <xd:li><xd:i>PrimaryCareProvision/component2/Prescription - no mapping.</xd:i></xd:li>
                    <xd:li><xd:i>PrimaryCareProvision/component2/ProcedureEvent - no mapping.</xd:i></xd:li>
                </xd:ul></xd:li>
                <xd:li><xd:i>PrimaryCareProvision/component3/contraIndication - copy any.</xd:i></xd:li>
                <xd:li><xd:i>PrimaryCareProvision/component4/observationIntolerances - copy any.</xd:i></xd:li>
            </xd:ul>
            </xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:PrimaryCareProvision" name="PrimaryCareProvision">
        <!-- Holds an index of identifiers for specific elements that should be copied -->
        <xsl:variable name="copyIndex">
            <x>
                <!-- First get activities under encounters -->
                <xsl:choose>
                    <!-- handle supported interactions in a special way. Currently all interactions get the same encounters from no longer than 10 days ago.
                        If this is to be different in the future, then the xs:when needs to be split up per interaction. -->
                    <xsl:when test="$g_outputInteractionId='QUPC_IN443230NL' or $g_outputInteractionId='QUPC_IN443231NL' or $g_outputInteractionId='QUPC_IN443232NL'">
                        <xsl:for-each select=".//hl7:component1/hl7:encounter">
                            <xsl:variable name="effVal">
                                <xsl:choose>
                                    <xsl:when test="hl7:effectiveTime/@value">
                                        <xsl:value-of select="number(substring(concat(hl7:effectiveTime/@value,'00000000000000'),1,14))"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="number('0')"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:variable>
                            <xsl:variable name="effValLow">
                                <xsl:choose>
                                    <xsl:when test="hl7:effectiveTime/hl7:low/@value">
                                        <xsl:value-of select="number(substring(concat(hl7:effectiveTime/hl7:low/@value,'00000000000000'),1,14))"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="number('0')"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:variable>
                            <xsl:variable name="effValHigh">
                                <xsl:choose>
                                    <xsl:when test="hl7:effectiveTime/hl7:high/@value">
                                        <xsl:value-of select="number(substring(concat(hl7:effectiveTime/hl7:high/@value,'00000000000000'),1,14))"/>
                                    </xsl:when>
                                    <xsl:otherwise>
                                        <xsl:value-of select="number('0')"/>
                                    </xsl:otherwise>
                                </xsl:choose>
                            </xsl:variable>
                            <xsl:if test="number($tsToday)-$effVal &lt;= $tenDaysAgo or number($tsToday)-$effValLow &lt;= $tenDaysAgo or number($tsToday)-$effValHigh &lt;= $tenDaysAgo">
                                <xsl:apply-templates select="hl7:id" mode="copy"/>
                                <xsub type="encounter">
                                    <xsl:apply-templates select="hl7:component/hl7:*[hl7:JournalEntry or hl7:observation or hl7:ObservationDx]/hl7:id" mode="copy"/>    
                                </xsub>
                            </xsl:if>
                        </xsl:for-each>
                    </xsl:when>
                    <!-- otherwise copy all encounters...may need to reverse this by not copying any encounter...
                            note that if a new interactions needs to be supported, you probably need an extra xsl:when -->
                    <xsl:otherwise>
                        <xsl:apply-templates select=".//hl7:component1/hl7:encounter/hl7:id" mode="copy"/>
                        <xsub type="encounter-activity">
                            <xsl:apply-templates select="hl7:component/hl7:*/hl7:id" mode="copy"/>    
                        </xsub>
                    </xsl:otherwise>
                </xsl:choose>
                <!-- Next get activities not under encounters -->
                <xsub type="activity">
                    <xsl:choose>
                        <!-- handle supported interactions in a special way. Currently all interactions get the same acts/observations from no longer than 10 days ago.
                            If this is to be different in the future, then the xs:when needs to be split up per interaction. 
                            NOTE: Act is not currently in the PS specification. It is planned to be supported with two different types and two different periods
                            1. Correspondance up to 10 days ago
                            2. Also known at up to 2 years ago
                        -->
                        <xsl:when test="$g_outputInteractionId='QUPC_IN443230NL' or $g_outputInteractionId='QUPC_IN443231NL' or $g_outputInteractionId='QUPC_IN443232NL'">
                            <xsl:for-each select=".//hl7:component2/hl7:JournalEntry | .//hl7:component2/hl7:ObservationDx | .//hl7:component2/hl7:observation">
                                <xsl:variable name="effVal">
                                    <xsl:choose>
                                        <xsl:when test="hl7:effectiveTime/@value">
                                            <xsl:value-of select="number(substring(concat(hl7:effectiveTime/@value,'00000000000000'),1,14))"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="number('0')"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:variable>
                                <xsl:variable name="effValLow">
                                    <xsl:choose>
                                        <xsl:when test="hl7:effectiveTime/hl7:low/@value">
                                            <xsl:value-of select="number(substring(concat(hl7:effectiveTime/hl7:low/@value,'00000000000000'),1,14))"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="number('0')"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:variable>
                                <xsl:variable name="effValHigh">
                                    <xsl:choose>
                                        <xsl:when test="hl7:effectiveTime/hl7:high/@value">
                                            <xsl:value-of select="number(substring(concat(hl7:effectiveTime/hl7:high/@value,'00000000000000'),1,14))"/>
                                        </xsl:when>
                                        <xsl:otherwise>
                                            <xsl:value-of select="number('0')"/>
                                        </xsl:otherwise>
                                    </xsl:choose>
                                </xsl:variable>
                                <xsl:if test="number($tsToday)-$effVal &lt;= $tenDaysAgo or number($tsToday)-$effValLow &lt;= $tenDaysAgo or number($tsToday)-$effValHigh &lt;= $tenDaysAgo">
                                    <xsl:apply-templates select="hl7:id" mode="copy"/>
                                </xsl:if>
                            </xsl:for-each>
                        </xsl:when>
                        <!-- otherwise copy all observations...may need to reverse this by not copying any observation...
                                note that if a new interactions needs to be supported, you probably need an extra xsl:when -->
                        <xsl:otherwise>
                            <xsl:apply-templates select=".//hl7:component2/hl7:observation/hl7:id" mode="copy"/>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsub>
            </x>
        </xsl:variable>
        
        <CareProvisionEvent classCode="PCPR" moodCode="EVN">
            <templateId root="{$g_outputTemplateId}"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:statusCode" mode="copy"/>
            <xsl:apply-templates select="hl7:effectiveTime"/>
            <!-- participations -->
            <xsl:for-each select="hl7:subject">
                <recordTarget typeCode="RCT" contextControlCode="OP">
                    <xsl:apply-templates select="hl7:Patient"/>
                </recordTarget>
            </xsl:for-each>
            <xsl:for-each select="hl7:performer">
                <performer typeCode="PRF" contextControlCode="OP">
                    <assignedParty classCode="ASSIGNED">
                        <xsl:apply-templates select="hl7:AssignedEntity" mode="R_AssignedEntity"/>
                    </assignedParty>
                </performer>
            </xsl:for-each>
            <xsl:for-each select="hl7:author">
                <author typeCode="AUT" contextControlCode="OP">
                    <time nullFlavor="NI"/>
                    <modeCode nullFlavor="NI"/>
                    <signatureCode nullFlavor="NI"/>
                    <assignedParty classCode="ASSIGNED">
                        <xsl:apply-templates select="hl7:AssignedEntity" mode="R_AssignedEntity"/>
                    </assignedParty>
                </author>
            </xsl:for-each>
            <!-- NOT mapping PrimaryCareProvision/custodian -->
            <!-- NOT mapping PrimaryCareProvision/dataEnterer -->
            <!-- actrelationships -->
            <!-- EpisodeOfConditions must have at least description in hl7:text or a diagnosis with and code and effectiveTime, otherwise get XML Schema invalid output, and a problem without some form of diagnosis does not make sense -->
            <xsl:for-each select="hl7:component7[hl7:episodeOfCondition/hl7:text | hl7:episodeOfCondition/hl7:reason/hl7:ObservationDx[hl7:code/@code and hl7:effectiveTime//@value]]">
                <!-- NOTE: comments with contained variables not supported by Xalan-C -->
                <!--xsl:comment> source: component7/edisodeOfCondition </xsl:comment-->
                <reason typeCode="RSON" contextConductionInd="true">
                    <!--sequenceNumber value="1"/-->
                    <xsl:apply-templates select="hl7:episodeOfCondition">
                        <xsl:with-param name="copyIndex" select="$copyIndex"/>
                    </xsl:apply-templates>
                </reason>
            </xsl:for-each>
            <!-- Encounters -->
            <xsl:for-each select="hl7:component1">
                <xsl:variable name="encIdRoot" select="(hl7:encounter/hl7:id)[1]/@root"/>
                <xsl:variable name="encIdExt" select="(hl7:encounter/hl7:id)[1]/@extension"/>
                <xsl:if test="exsl:node-set($copyIndex)//hl7:id[@root=$encIdRoot and (not(@extension) or @extension=$encIdExt)]">
                    <!-- NOTE: comments with contained variables not supported by Xalan-C -->
                    <!--xsl:comment> source: component1/encounter </xsl:comment-->
                    <pertinentInformation3 typeCode="PERT" contextConductionInd="true">
                        <xsl:apply-templates select="hl7:encounter"/>
                    </pertinentInformation3>
                </xsl:if>
            </xsl:for-each>
            <!-- Activities -->
            <!-- NOT mapping act -->
            <!-- NOT mapping Prescription -->
            <!-- NOT mapping MedicationDispenseEvent -->
            <!-- NOT mapping ProcedureEvent -->
            <xsl:for-each select="hl7:component2">
                <xsl:choose>
                    <xsl:when test="hl7:JournalEntry or hl7:ObservationDx or hl7:observation">
                        <xsl:variable name="effVal">
                            <xsl:choose>
                                <xsl:when test="hl7:*/hl7:effectiveTime/@value">
                                    <xsl:value-of select="number(substring(concat(hl7:*/hl7:effectiveTime/@value,'00000000000000'),1,14))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="number('0')"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        <xsl:variable name="effValLow">
                            <xsl:choose>
                                <xsl:when test="hl7:*/hl7:effectiveTime/hl7:low/@value">
                                    <xsl:value-of select="number(substring(concat(hl7:*/hl7:effectiveTime/hl7:low/@value,'00000000000000'),1,14))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="number('0')"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        <xsl:variable name="effValHigh">
                            <xsl:choose>
                                <xsl:when test="hl7:*/hl7:effectiveTime/hl7:high/@value">
                                    <xsl:value-of select="number(substring(concat(hl7:*/hl7:effectiveTime/hl7:high/@value,'00000000000000'),1,14))"/>
                                </xsl:when>
                                <xsl:otherwise>
                                    <xsl:value-of select="number('0')"/>
                                </xsl:otherwise>
                            </xsl:choose>
                        </xsl:variable>
                        <xsl:choose>
                            <xsl:when test="number($tsToday)-$effVal &lt;= $tenDaysAgo or number($tsToday)-$effValLow &lt;= $tenDaysAgo or number($tsToday)-$effValHigh &lt;= $tenDaysAgo">
                            <!-- NOTE: comments with contained variables not supported by Xalan-C -->
                            <!--xsl:comment> source: component2/Activities choicebox </xsl:comment-->
                            <pertinentInformation3 typeCode="PERT" contextConductionInd="true">
                                <xsl:apply-templates select="hl7:observation" mode="Activity"/>
                                <xsl:apply-templates select="hl7:JournalEntry"/>
                                <xsl:apply-templates select="hl7:ObservationDx"/>
                            </pertinentInformation3>
                        </xsl:when>
                            <xsl:otherwise>
                                <!-- TODO: debug only: remove this, because it may give the recipient too much info -->
                                <!-- NOTE: comments with contained variables not supported by Xalan-C -->
                                <!--xsl:comment> source: skipped component2/<xsl:value-of select="local-name(hl7:*[1])"/> because it was older than agreed upon </xsl:comment-->
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>
                        <!-- TODO: debug only: remove this, because it may give the recipient too much info -->
                        <!-- NOTE: comments with contained variables not supported by Xalan-C -->
                        <!--xsl:comment> source: skipped component2/<xsl:value-of select="local-name(hl7:*[1])"/> because it was not a supported output activity </xsl:comment-->
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>
            <!-- ContraIndications -->
            <xsl:for-each select="hl7:component3">
                <pertinentInformation3 typeCode="PERT" contextConductionInd="true">
                    <xsl:apply-templates select="hl7:ContraIndication"/>
                </pertinentInformation3>
            </xsl:for-each>
            <!-- ObservationIntolerances -->
            <xsl:for-each select="hl7:component4">
                <pertinentInformation3 typeCode="PERT" contextConductionInd="true">
                    <xsl:apply-templates select="hl7:ObservationIntolerance"/>
                </pertinentInformation3>
            </xsl:for-each>
            <!-- Annotations -->
            <xsl:for-each select="hl7:pertinentInformation">
                <!-- NOTE: comments with contained variables not supported by Xalan-C -->
                <!--xsl:comment> source: pertinentInformation (Annotation) </xsl:comment-->
                <pertinentInformation3 typeCode="PERT" contextConductionInd="true">
                    <xsl:apply-templates select="hl7:pertinentAnnotationObsEvent"/>
                </pertinentInformation3>
            </xsl:for-each>
        </CareProvisionEvent>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Template for element subject/Patient containing R_PatientNL Universal (COCT_MT050000NL). Copies Patient element to patient element based on output template 2.16.840.1.113883.2.4.6.10.70.18.</xd:p>
            <xd:p>Operation: <xd:ul>
                <xd:li>fixed templateId '2.16.840.1.113883.2.4.6.10.70.18'</xd:li>
                <xd:li>Patient/id - any as-is</xd:li>
                <xd:li>Patient/addr - any as-is</xd:li>
                <xd:li>Patient/telecom - any as-is</xd:li>
                <xd:li>Patient/statusCode - any as-is</xd:li>
                <xd:li><xd:i>Patient/effectiveTime - no mapping</xd:i></xd:li>
                <xd:li><xd:i>Patient/confidentialityCode - no mapping</xd:i></xd:li>
                <xd:li>Patient/Person - if present as-is to patientPerson <xd:ul>
                    <xd:li>fixed templateId '2.16.840.1.113883.2.4.6.10.70.19'</xd:li>
                    <xd:li>Person/name - any as-is</xd:li>
                    <xd:li>Person/administrativeGenderCode - any as-is</xd:li>
                    <xd:li>Person/birthTime - any as-is</xd:li>
                </xd:ul></xd:li>
                <xd:li>Patient/Organization - if present as-is to providerOrganization <xd:ul>
                    <xd:li>Organization/id - any as-is or with nullFlavor="NI" or none are present</xd:li>
                    <xd:li>Organization/code - any as-is</xd:li>
                </xd:ul></xd:li>
            </xd:ul>
            </xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:subject/hl7:Patient" name="R_PatientNLUniversal">
        <patient classCode="PAT">
            <templateId root="2.16.840.1.113883.2.4.6.10.70.18"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:addr" mode="copy"/>
            <xsl:apply-templates select="hl7:telecom" mode="copy"/>
            <xsl:apply-templates select="hl7:statusCode" mode="copy"/>
            <!-- NOT mapping effectiveTime -->
            <!-- NOT mapping confidentialityCode -->
            <xsl:if test="hl7:Person">
                <patientPerson classCode="PSN" determinerCode="INSTANCE">
                    <templateId root="2.16.840.1.113883.2.4.6.10.70.19"/>
                    <xsl:apply-templates select="hl7:Person/hl7:name" mode="copy"/>
                    <xsl:apply-templates select="hl7:Person/hl7:administrativeGenderCode" mode="copy"/>
                    <xsl:apply-templates select="hl7:Person/hl7:birthTime" mode="copy"/>
                </patientPerson>
            </xsl:if>
            <xsl:if test="hl7:Organization">
                <providerOrganization classCode="ORG" determinerCode="INSTANCE">
                    <xsl:if test="not(hl7:Organization/hl7:id)">
                        <id nullFlavor="NI"/>
                    </xsl:if>
                    <xsl:apply-templates select="hl7:Organization/hl7:id" mode="copy"/>
                    <xsl:apply-templates select="hl7:Organization/hl7:code" mode="copy"/>
                </providerOrganization>
            </xsl:if>
        </patient>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Template for element subject/Patient containing R_PatientNL Identified (COCT_MT050001NL). Copies Patient element to patient element based on output template 2.16.840.1.113883.2.4.6.10.70.23.</xd:p>
            <xd:p>Operation: <xd:ul>
                <xd:li>fixed templateId '2.16.840.1.113883.2.4.6.10.70.23'</xd:li>
                <xd:li>Patient/id - any as-is</xd:li>
            </xd:ul>
            </xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:Patient" mode="R_PatientNLIdentified" name="R_PatientNLIdentified">
        <patient classCode="PAT">
            <templateId root="2.16.840.1.113883.2.4.6.10.70.23"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
        </patient>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Template for elements AssignedEntity (R_AssignedEntityNL_PO Universal (COCT_MT090000NL2)), assignedEntity1 (R_AssignedEntity Universal (COCT_MT090000)), and AssignedPerson (R_AssignedPerson Universal (COCT_MT090100)). Copies sub elements to elements based on output template 2.16.840.1.113883.2.4.6.10.70.20.</xd:p>
            <xd:p>Background: in the XML Schemas COCT_MT090000.xsd and COCT_MT090000NL2.xsd there is an error which is true for many of the schemas generated around that same time. 
                It has a mandatory element Organization, which should have been an optional element representedOrganization. This element is supposed to hold 
                the -Scoping Organization- for the main AssignedEntity. The AssignedEntity itself might be a person or an organization, and the name should 
                go into respectively into the -Playing Entity- assignedPerson or assignedOrganization.</xd:p>
            <xd:p>However: since Organization is a mandatory element in the Schema, if an implementer needed to implement an organization as AssignedEntity he did 
                not have a scoping Organization for it, and would put the name for the -playing- entity behind AssignedEntity in the Organization element to satisfy 
                the XML Schema. It would even occur that AssignedEntity/code, addr, telecom, statusCode where placed in Organization. We would loose that information in that case. 
                To fix this error in this mapping so we don't impose the same problem onto the result document, but taking into account that some 
                implementers might implemented both assignedPerson/assignedOrganization AND Organization (which is the right way to implement legal by the way) we 
                will handle as follows: <xd:ul>
                    <xd:li>if AssignedEntity/code, addr, telecom, or statusCode is missing, but Organization/id matches AssignedEntity/id, then map Organization/code, addr, telecom, statusCode to AssignedEntity</xd:li>
                    <xd:li>if both assignedPerson/assignedOrganization and Organization are present: map both.</xd:li>
                    <xd:li>if assignedPerson/assignedOrganization are not present and just Organization is present: map Organization into assignedOrganization</xd:li>
                </xd:ul>
            </xd:p>
            <xd:p>Operation: <xd:ul>
                <xd:li>fixed templateId '2.16.840.1.113883.2.4.6.10.70.20'</xd:li>
                <xd:li>AssignedEntity/id - any as-is</xd:li>
                <xd:li>AssignedEntity/code - any as-is, if missing and AssignedEntity/id=AssignedEntity/Organization/id, then copy AssignedEntity/Organization/code</xd:li>
                <xd:li>AssignedEntity/addr - any as-is, if missing and AssignedEntity/id=AssignedEntity/Organization/id, then copy AssignedEntity/Organization/addr</xd:li>
                <xd:li>AssignedEntity/telecom - any as-is, if missing and AssignedEntity/id=AssignedEntity/Organization/id, then copy AssignedEntity/Organization/telecom</xd:li>
                <xd:li>AssignedEntity/statusCode - any as-is, if missing and AssignedEntity/id=AssignedEntity/Organization/id, then copy AssignedEntity/Organization/statusCode</xd:li>
                <xd:li><xd:i>AssignedEntity/effectiveTime - no mapping</xd:i></xd:li>
                <xd:li><xd:i>AssignedEntity/certificateText - no mapping</xd:i></xd:li>
                <xd:li>AssignedEntity/assignedPerson / AssignedEntity/assignedOrganization - one of: <xd:ul>
                    <xd:li>assignedPerson/name - if present any as-is</xd:li>
                    <xd:li>assignedOrganization/name - if present any as-is</xd:li>
                    <xd:li>AssignedEntity/Organization/name - if both assignedPerson and assignedOrganization are missing and if present any as-is</xd:li> 
                </xd:ul></xd:li>
                <xd:li>AssignedEntity/Organization - if present and not already copied before, and if not just contains id/@nullFlavor, as-is to representedOrganization <xd:ul>
                    <xd:li>Organization/id - any as-is or with nullFlavor="NI" or none are present</xd:li>
                    <xd:li>Organization/code - any as-is</xd:li>
                    <xd:li>Organization/code - any as-is</xd:li>
                    <xd:li>Organization/name - any as-is</xd:li>
                    <xd:li>Organization/desc - any as-is</xd:li>
                    <xd:li>Organization/statusCode - any as-is</xd:li>
                    <xd:li>Organization/telecom - any as-is</xd:li>
                    <xd:li>Organization/addr - any as-is</xd:li>
                    <xd:li>Organization/part - any as-is via <xd:ref name="OrganizationPart">OrganizationPart</xd:ref></xd:li>
                    <xd:li>Organization/part-of - any as-is via <xd:ref name="OrganizationPartOf">OrganizationPartOf</xd:ref></xd:li>
                </xd:ul></xd:li>
            </xd:ul>
            </xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:AssignedEntity | hl7:assignedEntity1 | hl7:AssignedPerson" mode="R_AssignedEntity" name="R_AssignedEntityUniversal">
        <xsl:variable name="aeIdRoot" select="hl7:id[1]/@root"/>
        <xsl:variable name="aeIdExt" select="hl7:id[1]/@extension"/>
        <xsl:choose>
            <xsl:when test="hl7:assignedPerson or hl7:assignedOrganization or hl7:Organization/hl7:id[@root=$aeIdRoot and @extension=$aeIdExt]">
                <!-- if there is a name use Universal template -->
                <templateId root="2.16.840.1.113883.2.4.6.10.70.20"/>
            </xsl:when>
            <xsl:otherwise>
                <!-- otherwise use Identified template -->
                <templateId root="2.16.840.1.113883.2.4.6.10.70.21"/>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:apply-templates select="hl7:id" mode="copy"/>
        <!-- copy local element before checking Organization -->
        <xsl:choose>
            <xsl:when test="hl7:code">
                <xsl:apply-templates select="hl7:code" mode="copy"/>        
            </xsl:when>
            <xsl:when test="hl7:Organization/hl7:id[@root=$aeIdRoot and @extension=$aeIdExt]">
                <xsl:apply-templates select="hl7:Organization/hl7:code" mode="copy"/>
            </xsl:when>
        </xsl:choose>
        <!-- copy local element before checking Organization -->
        <xsl:choose>
            <xsl:when test="hl7:addr">
                <xsl:apply-templates select="hl7:addr" mode="copy"/>        
            </xsl:when>
            <xsl:when test="hl7:Organization/hl7:id[@root=$aeIdRoot and @extension=$aeIdExt]">
                <xsl:apply-templates select="hl7:Organization/hl7:addr" mode="copy"/>
            </xsl:when>
        </xsl:choose>
        <!-- copy local element before checking Organization -->
        <xsl:choose>
            <xsl:when test="hl7:telecom">
                <xsl:apply-templates select="hl7:telecom" mode="copy"/>        
            </xsl:when>
            <xsl:when test="hl7:Organization/hl7:id[@root=$aeIdRoot and @extension=$aeIdExt]">
                <xsl:apply-templates select="hl7:Organization/hl7:telecom" mode="copy"/>
            </xsl:when>
        </xsl:choose>
        <!-- copy local element before checking Organization -->
        <xsl:choose>
            <xsl:when test="hl7:statusCode">
                <xsl:apply-templates select="hl7:statusCode" mode="copy"/>        
            </xsl:when>
            <xsl:when test="hl7:Organization/hl7:id[@root=$aeIdRoot and @extension=$aeIdExt]">
                <xsl:apply-templates select="hl7:Organization/hl7:statusCode" mode="copy"/>
            </xsl:when>
        </xsl:choose>
        <!-- copy local element before checking Organization -->
        <xsl:choose>
            <xsl:when test="hl7:assignedPerson">
                <assignedPerson classCode="PSN" determinerCode="INSTANCE">
                    <xsl:apply-templates select="hl7:assignedPerson/hl7:name" mode="copy"/>
                </assignedPerson>
            </xsl:when>
            <xsl:when test="hl7:assignedOrganization">
                <assignedOrganization classCode="ORG" determinerCode="INSTANCE">
                    <xsl:apply-templates select="hl7:assignedOrganization/hl7:name" mode="copy"/>
                </assignedOrganization>
            </xsl:when>
            <xsl:when test="hl7:Organization/hl7:id[@root=$aeIdRoot and @extension=$aeIdExt]">
                <assignedOrganization classCode="ORG" determinerCode="INSTANCE">
                    <xsl:apply-templates select="hl7:Organization/hl7:name" mode="copy"/>
                </assignedOrganization>
            </xsl:when>
        </xsl:choose>
        <!-- copy Organization only if not already copied into assignedParty and/or assignedOrganization (representedOrganization is optional in output) -->
        <xsl:if test="hl7:assignedPerson or hl7:assignedOrganization or not(hl7:Organization/hl7:id[@root=$aeIdRoot and @extension=$aeIdExt])">
                <!-- copy Organization if not just id/@nullFlavor. -->
                <xsl:if test="not(hl7:Organization/hl7:id/@nullFlavor) and count(hl7:Organization/hl7:*) &gt;1">
                    <representedOrganization classCode="ORG" determinerCode="INSTANCE">
                        <xsl:apply-templates select="hl7:Organization/hl7:id" mode="copy"/>
                        <xsl:apply-templates select="hl7:Organization/hl7:code" mode="copy"/>
                        <xsl:apply-templates select="hl7:Organization/hl7:name" mode="copy"/>
                        <xsl:apply-templates select="hl7:Organization/hl7:desc" mode="copy"/>
                        <xsl:apply-templates select="hl7:Organization/hl7:statusCode" mode="copy"/>
                        <xsl:apply-templates select="hl7:Organization/hl7:telecom" mode="copy"/>
                        <xsl:apply-templates select="hl7:Organization/hl7:addr" mode="copy"/>
                        <xsl:apply-templates select="hl7:Organization/hl7:part" mode="OrganizationPart"/>
                        <xsl:apply-templates select="hl7:Organization/hl7:part-of" mode="OrganizationPart"/>
                    </representedOrganization>
                </xsl:if>
            </xsl:if>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Template for element Organization/part from E_Organization Universal. Copies part element to part, needs to convert two child element names, recurses into itself if needed, and binds with <xd:ref name="OrganizationPartOf" type="template">OrganizationPartOf</xd:ref></xd:p>
            <xd:p>Operation: <xd:ul>
                <xd:li>part/id - any as-is</xd:li>
                <xd:li>part/code - any as-is</xd:li>
                <xd:li>part/statusCode - any as-is</xd:li>
                <xd:li>part/effectiveTime - any as-is</xd:li>
                <xd:li>partOrganization - as-is 
                        <xd:ul>
                            <xd:li>partOrganization/id - any as-is</xd:li>
                            <xd:li>partOrganization/code - any as-is</xd:li>
                            <xd:li>partOrganization/name - any as-is</xd:li>
                            <xd:li>partOrganization/desc - any as-is</xd:li>
                            <xd:li>partOrganization/statusCode - any as-is</xd:li>
                            <xd:li>partOrganization/telecom - any as-is</xd:li>
                            <xd:li>partOrganization/addr - any as-is</xd:li>
                            <xd:li>partOrganization/part - any by rescursing</xd:li>
                            <xd:li>partOrganization/part-of - any via output template <xd:ref name="OrganizationPartOf" type="template">OrganizationPartOf</xd:ref></xd:li>
                        </xd:ul></xd:li>
            </xd:ul>
            </xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:part" mode="OrganizationPart" name="OrganizationPart">
        <organizationContains classCode="PART">
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:code" mode="copy"/>
            <xsl:apply-templates select="hl7:statusCode" mode="copy"/>
            <xsl:apply-templates select="hl7:effectiveTime" mode="copy"/>
            <partOrganization classCode="ORG" determinerCode="INSTANCE">
                <xsl:apply-templates select="hl7:partOrganization/hl7:id" mode="copy"/>
                <xsl:apply-templates select="hl7:partOrganization/hl7:code" mode="copy"/>
                <xsl:apply-templates select="hl7:partOrganization/hl7:name" mode="copy"/>
                <xsl:apply-templates select="hl7:partOrganization/hl7:desc" mode="copy"/>
                <xsl:apply-templates select="hl7:partOrganization/hl7:statusCode" mode="copy"/>
                <xsl:apply-templates select="hl7:partOrganization/hl7:telecom" mode="copy"/>
                <xsl:apply-templates select="hl7:partOrganization/hl7:addr" mode="copy"/>
                <!-- recurse -->
                <xsl:apply-templates select="hl7:partOrganization/hl7:part" mode="OrganizationPart"/>
                <xsl:apply-templates select="hl7:partOrganization/hl7:part-of" mode="OrganizationPart"/>
            </partOrganization>
        </organizationContains>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Template for element Organization/part-of from E_Organization Universal. Copies part-of element to part-of, needs to convert two child element names, recurses into itself if needed, and binds with <xd:ref name="OrganizationPart" type="template">OrganizationPart</xd:ref></xd:p>
            <xd:p>Operation: <xd:ul>
                <xd:li>part/id - any as-is</xd:li>
                <xd:li>part/code - any as-is</xd:li>
                <xd:li>part/statusCode - any as-is</xd:li>
                <xd:li>part/effectiveTime - any as-is</xd:li>
                <xd:li>wholeOrganization - as-is 
                        <xd:ul>
                            <xd:li>wholeOrganization/id - any as-is</xd:li>
                            <xd:li>wholeOrganization/code - any as-is</xd:li>
                            <xd:li>wholeOrganization/name - any as-is</xd:li>
                            <xd:li>wholeOrganization/desc - any as-is</xd:li>
                            <xd:li>wholeOrganization/statusCode - any as-is</xd:li>
                            <xd:li>wholeOrganization/telecom - any as-is</xd:li>
                            <xd:li>wholeOrganization/addr - any as-is</xd:li>
                            <xd:li>wholeOrganization/part - any by rescursing</xd:li>
                            <xd:li>wholeOrganization/part-of - any via output template <xd:ref name="OrganizationPartOf" type="template">OrganizationPartOf</xd:ref></xd:li>
                        </xd:ul></xd:li>
            </xd:ul>
            </xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:part-of" mode="OrganizationPart" name="OrganizationPartOf">
        <asOrganizationPartOf classCode="PART">
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:code" mode="copy"/>
            <xsl:apply-templates select="hl7:statusCode" mode="copy"/>
            <xsl:apply-templates select="hl7:effectiveTime" mode="copy"/>
            <wholeOrganization classCode="ORG" determinerCode="INSTANCE">
                <xsl:apply-templates select="hl7:wholeOrganization/hl7:id" mode="copy"/>
                <xsl:apply-templates select="hl7:wholeOrganization/hl7:code" mode="copy"/>
                <xsl:apply-templates select="hl7:wholeOrganization/hl7:name" mode="copy"/>
                <xsl:apply-templates select="hl7:wholeOrganization/hl7:desc" mode="copy"/>
                <xsl:apply-templates select="hl7:wholeOrganization/hl7:statusCode" mode="copy"/>
                <xsl:apply-templates select="hl7:wholeOrganization/hl7:telecom" mode="copy"/>
                <xsl:apply-templates select="hl7:wholeOrganization/hl7:addr" mode="copy"/>
                <xsl:apply-templates select="hl7:wholeOrganization/hl7:part" mode="OrganizationPart"/>
                <!-- recurse -->
                <xsl:apply-templates select="hl7:wholeOrganization/hl7:part-of" mode="OrganizationPart"/>
            </wholeOrganization>
        </asOrganizationPartOf>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copies any participation which ties into R_AssignedPersonIdentified</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:AssignedPerson" mode="R_AssignedPersonIdentified">
        <xsl:variable name="aeIdRoot" select="hl7:id[1]/@root"/>
        <xsl:variable name="aeIdExt" select="hl7:id[1]/@extension"/>
        <assignedPerson classCode="ASSIGNED">
            <templateId root="2.16.840.1.113883.2.4.6.10.70.21"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:code" mode="copy"/>
            <xsl:choose>
                <xsl:when test="//hl7:*[hl7:id[@root=$aeIdRoot and @extension=$aeIdExt]]/hl7:assignedPerson/hl7:name[not(@nullFlavor)]">
                    <assignedPerson classCode="PSN" determinerCode="INSTANCE">
                        <xsl:apply-templates select="(//hl7:*[hl7:id[@root=$aeIdRoot and @extension=$aeIdExt]]/hl7:assignedPerson/hl7:name[not(@nullFlavor)])[1]" mode="copy"/>
                    </assignedPerson>
                </xsl:when>
                <xsl:otherwise>
                    <assignedPerson classCode="PSN" determinerCode="INSTANCE" xsi:nil="true" nullFlavor="NI"/>
                </xsl:otherwise>
            </xsl:choose>
        </assignedPerson>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copies any participation which ties into R_AssignedPersonIdentified2AssignedEntity</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:AssignedPerson" mode="R_AssignedPersonIdentified2AssignedEntity">
        <xsl:variable name="aeIdRoot" select="hl7:id[1]/@root"/>
        <xsl:variable name="aeIdExt" select="hl7:id[1]/@extension"/>
        <assignedEntity classCode="ASSIGNED">
            <templateId root="2.16.840.1.113883.2.4.6.10.70.21"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:code" mode="copy"/>
        </assignedEntity>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copies PrimaryCareProvision/pertinentInformation that contains annotations</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:PrimaryCareProvision/hl7:pertinentInformation/hl7:pertinentAnnotationObsEvent" name="pertinentAnnotationObsEvent">
        <observation classCode="OBS" moodCode="EVN">
            <templateId root="2.16.840.1.113883.2.4.6.10.70.1"/>
            <xsl:choose>
                <xsl:when test="hl7:code">
                    <xsl:apply-templates select="hl7:code" mode="copy"/>
                </xsl:when>
                <xsl:otherwise>
                    <code code="WNN" codeSystem="2.16.840.1.113883.5.4" displayName="Waarneemnotitie"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:if test="hl7:effectiveTime[.//@value or .//@nullFlavor]">
                <effectiveTime>
                    <xsl:copy-of select="hl7:effectiveTime/@*"/>
                    <xsl:attribute name="xsi:type">
                        <xsl:value-of select="'IVL_TS'"/>
                    </xsl:attribute>
                    <xsl:apply-templates select="hl7:effectiveTime/node()" mode="copy"/>
                </effectiveTime>
            </xsl:if>
            <value xsi:type="ST">
                <xsl:apply-templates select="hl7:text/node()" mode="copy"/>
            </value>
            <xsl:for-each select="hl7:author">
                <author typeCode="AUT" contextControlCode="OP">
                    <assignedEntity classCode="ASSIGNED">
                        <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedEntity"/>
                    </assignedEntity>
                </author>
            </xsl:for-each>
        </observation>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copies PrimaryCareProvision/component1 which ties into encounters</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:PrimaryCareProvision/hl7:component1/hl7:encounter" name="Encounter">
        <encounter classCode="ENC" moodCode="EVN">
            <templateId root="2.16.840.1.113883.2.4.6.10.70.3"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:code" mode="EncounterCode"/>
            <xsl:apply-templates select="hl7:effectiveTime">
                <xsl:with-param name="xsiType" select="'IVL_TS'"/>
            </xsl:apply-templates>
            <!-- NOT mapping encounter/custodian -->
            <!-- NOT mapping encounter/dataEnterer -->
            <xsl:for-each select="hl7:performer">
                <performer typeCode="PRF" contextControlCode="OP">
                    <assignedEntity classCode="ASSIGNED">
                        <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedEntity"/>
                    </assignedEntity>
                </performer>
            </xsl:for-each>
            <xsl:for-each select="hl7:author">
                <author typeCode="AUT" contextControlCode="OP">
                    <assignedEntity classCode="ASSIGNED">
                        <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedEntity"/>
                    </assignedEntity>
                </author>
            </xsl:for-each>
            <!-- NOT mapping act -->
            <!-- NOT mapping Prescription -->
            <!-- NOT mapping MedicationDispenseEvent -->
            <!-- NOT mapping ProcedureEvent -->
            <xsl:for-each select="hl7:component[hl7:JournalEntry or hl7:observation or hl7:ObservationDx]">
                <outboundRelationship typeCode="COMP" contextConductionInd="true">
                    <xsl:apply-templates select="hl7:sequenceNumber" mode="copy"/>
                    <xsl:apply-templates select="hl7:JournalEntry"/>
                    <xsl:apply-templates select="hl7:observation" mode="Activity"/>
                    <xsl:apply-templates select="hl7:ObservationDx"/>
                </outboundRelationship>
            </xsl:for-each>
        </encounter>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copies PrimaryCareProvision/component7 which ties into episode of conditions</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:PrimaryCareProvision/hl7:component7//hl7:episodeOfCondition" name="EpisodeOfCondition">
        <xsl:param name="copyIndex"/>
        <concern classCode="CONC" moodCode="EVN">
            <!-- templateId for episode -->
            <templateId root="2.16.840.1.113883.2.4.6.10.70.15"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:statusCode" mode="copy"/>
            <xsl:apply-templates select="hl7:effectiveTime[.//@value or .//@nullFlavor]"/>
            <xsl:for-each select="hl7:author">
                <author typeCode="AUT" contextControlCode="OP">
                    <time nullFlavor="NI"/>
                    <signatureCode nullFlavor="NI"/>
                    <signatureText nullFlavor="NI"/>
                    <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedPersonIdentified"/>
                </author>
            </xsl:for-each>
            <!-- Special handling of textual EpisodeOfCondition -->
            <xsl:apply-templates select="hl7:text[string-length(normalize-space(text()))&gt;0]" mode="EpisodeOfConditionName"/>
            <xsl:for-each select="hl7:reason[hl7:ObservationDx/hl7:code/@code and hl7:ObservationDx/hl7:effectiveTime//@value]">
                <subject2 typeCode="SUBJ" contextConductionInd="true">
                    <xsl:apply-templates select="hl7:ObservationDx"/>
                </subject2>
            </xsl:for-each>
            <xsl:apply-templates select="hl7:component2/hl7:episodOfCare/hl7:component/hl7:actReference">
                <xsl:with-param name="copyIndex" select="$copyIndex"/>
            </xsl:apply-templates>
            <!-- recurse -->
            <xsl:for-each select="hl7:component1">
                <component typeCode="COMP" contextConductionInd="true">
                    <xsl:apply-templates select="hl7:episodeOfCondition">
                        <xsl:with-param name="copyIndex" select="$copyIndex"/>
                    </xsl:apply-templates>
                </component>
            </xsl:for-each>
        </concern>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copy the EpisodeOfCondition/text into subject2/observation/value</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:text" mode="EpisodeOfConditionName">
      <subject2 typeCode="SUBJ" contextConductionInd="true">
        <observation classCode="OBS" moodCode="EVN">
          <templateId root="2.16.840.1.113883.2.4.6.10.70.25"/>
          <code code="DX" codeSystem="2.16.840.1.113883.5.4"/>
          <value xsi:type="ST">
            <xsl:value-of select="text()"/>
          </value>
        </observation>
      </subject2>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copies actReference, if target is in output. Target is in output if target existed in the first place and 
                is part of an encounter activity that gets copied, or is part of a non-encounter bound activity. The answer
                to these conditions means that the id must be in the parameter copyIndex.</xd:p>
                <xd:p>We're determining/patching the correct @classCode and @moodCode on actReference ourselves because qualification testing 
                in the past has been to loose to rely on.</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:episodOfCare/hl7:component/hl7:actReference" name="ActReference">
        <xsl:param name="copyIndex"/>
        <xsl:variable name="arIdRoot" select="hl7:id[1]/@root"/>
        <xsl:variable name="arIdExt" select="hl7:id[1]/@extension"/>
        <xsl:variable name="elTargetName" select="local-name((ancestor::hl7:PrimaryCareProvision//hl7:*[not(local-name(.)='actReference')][hl7:id[@root=$arIdRoot and @extension=$arIdExt]])[1])"/>
        <!-- refClass checks for names regardless of whether they are copied in the whole. That doesn't do any harm and saves maintenance  -->
        <xsl:variable name="refClass">
            <xsl:choose>
                <xsl:when test="$elTargetName='JournalEntry' or $elTargetName='ObservationDx' or $elTargetName='observation' or $elTargetName='Observation'">
                    <xsl:value-of select="'OBS'"/>
                </xsl:when>
                <xsl:when test="$elTargetName='ProcedureEvent'">
                    <xsl:value-of select="'PROC'"/>
                </xsl:when>
                <xsl:when test="$elTargetName='Referral'">
                    <xsl:value-of select="'PCPR'"/>
                </xsl:when>
                <xsl:when test="$elTargetName='MedicationDispenseEvent'">
                    <xsl:value-of select="'SPLY'"/>
                </xsl:when>
                <xsl:when test="$elTargetName='Prescription'">
                    <xsl:value-of select="'SBADM'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="''"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="refMood">
            <xsl:choose>
                <xsl:when test="$elTargetName='Prescription'">
                    <xsl:value-of select="'RQO'"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="'EVN'"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="exsl:node-set($copyIndex)//hl7:id[@root=$arIdRoot and (not(@extension) or @extension=$arIdExt)]">
                <reference typeCode="REFR" contextConductionInd="false">
                    <actReference>
                        <xsl:attribute name="classCode">
                            <xsl:value-of select="$refClass"/>
                        </xsl:attribute>
                        <xsl:attribute name="moodCode">
                            <xsl:value-of select="$refMood"/>
                        </xsl:attribute>
                        <templateId root="2.16.840.1.113883.2.4.6.10.70.16"/>
                        <xsl:apply-templates select="hl7:id" mode="copy"/>
                    </actReference>
                </reference>
            </xsl:when>
            <xsl:otherwise>
                <!-- NOTE: comments with contained variables not supported by Xalan-C -->
                <!--xsl:comment> source: skipped ActReference (target: <xsl:value-of select="$elTargetName"/>) &lt;id root="<xsl:value-of select="$arIdRoot"/>" extension="<xsl:value-of select="$arIdExt"/>"/&gt; </xsl:comment-->
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copies ContraIndication containing a contra indication</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:ContraIndication" name="ContraIndication">
        <!-- NOTE: comments with contained variables not supported by Xalan-C -->
        <!--xsl:comment> source: <xsl:value-of select="concat(local-name(../..),'/',local-name(..),'/',local-name(.))"/> </xsl:comment-->
        <observation classCode="OBS" moodCode="EVN">
            <xsl:copy-of select="@negationInd"/>
            <templateId root="2.16.840.1.113883.2.4.6.10.70.27"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:choose>
                <!-- There have examples without @codeSystem. This should never occur in production, but patching anyway just in case -->
                <xsl:when test="hl7:code[not(@codeSystem) and (@code='CI' or @code='DERCI')]">
                    <code>
                        <xsl:attribute name="codeSystem">
                            <xsl:value-of select="'2.16.840.1.113883.5.4'"/>
                        </xsl:attribute>
                        <xsl:copy-of select="hl7:code/@*"/>
                    </code>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="hl7:code" mode="copy"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:apply-templates select="hl7:text[string-length(normalize-space(text()))&gt;0]" mode="copy"/>
            <xsl:if test="hl7:effectiveTime[.//@value or .//@nullFlavor]">
                <effectiveTime>
                    <xsl:copy-of select="hl7:effectiveTime/@*"/>
                    <xsl:attribute name="xsi:type">
                        <xsl:value-of select="'IVL_TS'"/>
                    </xsl:attribute>
                    <xsl:apply-templates select="hl7:effectiveTime/node()" mode="copy"/>
                </effectiveTime>
            </xsl:if>
            <xsl:choose>
                <xsl:when test="hl7:value">
                    <value>
                        <xsl:copy-of select="hl7:value/@*"/>
                        <xsl:attribute name="xsi:type">
                            <xsl:value-of select="'CE'"/>
                        </xsl:attribute>
                        <xsl:apply-templates select="hl7:value/node()" mode="copy"/>
                    </value>
                </xsl:when>
                <xsl:otherwise>
                    <value xsi:type="CE" nullFlavor="UNK"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:for-each select="hl7:author">
                <author typeCode="AUT" contextControlCode="ON">
                    <!-- NOTE: time is mandatory in output, but optional in input, Now getting the century part of diagnosis itself, which is pretty meaningless, but validates -->
                    <xsl:choose>
                        <xsl:when test="hl7:time/@value">
                            <xsl:apply-templates select="hl7:time" mode="copy"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <time value="{substring((parent::hl7:ObservationDx/hl7:effectiveTime//@value)[1],1,2)}"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedPersonIdentified2AssignedEntity"/>
                </author>
            </xsl:for-each>
        </observation>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copies ObservationIntolerance containing an Observation Intolerance</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:ObservationIntolerance" name="ObservationIntolerance">
        <!-- NOTE: comments with contained variables not supported by Xalan-C -->
        <!--xsl:comment> source: <xsl:value-of select="concat(local-name(../..),'/',local-name(..),'/',local-name(.))"/> </xsl:comment-->
        <observation classCode="OBS" moodCode="EVN">
            <xsl:copy-of select="@negationInd"/>
            <templateId root="2.16.840.1.113883.2.4.6.10.70.26"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:choose>
                <!-- There have examples without @codeSystem. This should never occur in production, but patching anyway just in case -->
                <xsl:when test="hl7:code[not(@codeSystem) and (@code='DINT' or @code='INTLRNC')]">
                    <code>
                        <xsl:attribute name="codeSystem">
                            <xsl:value-of select="'2.16.840.1.113883.5.4'"/>
                        </xsl:attribute>
                        <xsl:copy-of select="hl7:code/@*"/>
                    </code>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="hl7:code" mode="copy"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:apply-templates select="hl7:text[string-length(normalize-space(text()))&gt;0]" mode="copy"/>
            <xsl:apply-templates select="hl7:statusCode[@code]" mode="copy"/>
            <xsl:if test="hl7:effectiveTime[.//@value or .//@nullFlavor]">
                <effectiveTime>
                    <xsl:copy-of select="hl7:effectiveTime/@*"/>
                    <xsl:attribute name="xsi:type">
                        <xsl:value-of select="'IVL_TS'"/>
                    </xsl:attribute>
                    <xsl:apply-templates select="hl7:effectiveTime/node()" mode="copy"/>
                </effectiveTime>
            </xsl:if>
            <xsl:choose>
                <xsl:when test="hl7:value">
                    <value>
                        <xsl:copy-of select="hl7:value/@*"/>
                        <xsl:attribute name="xsi:type">
                            <xsl:value-of select="'CE'"/>
                        </xsl:attribute>
                        <xsl:apply-templates select="hl7:value/node()" mode="copy"/>
                    </value>
                </xsl:when>
                <xsl:otherwise>
                    <value xsi:type="CE" nullFlavor="UNK"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:for-each select="hl7:author">
                <author typeCode="AUT" contextControlCode="ON">
                    <!-- NOTE: time is mandatory in output, but optional in input, Now getting the century part of diagnosis itself, which is pretty meaningless, but validates -->
                    <xsl:choose>
                        <xsl:when test="hl7:time/@value">
                            <xsl:apply-templates select="hl7:time" mode="copy"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <time value="{substring((parent::hl7:ObservationDx/hl7:effectiveTime//@value)[1],1,2)}"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedPersonIdentified2AssignedEntity"/>
                </author>
            </xsl:for-each>
        </observation>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>NOTE: Not using for now ... not yet in PS spec. Copies act containing a document?</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:act" mode="Activity" name="ActivityAct">
        <!-- NOTE: comments with contained variables not supported by Xalan-C -->
        <!--xsl:comment> source: <xsl:value-of select="concat(local-name(../..),'/',local-name(..),'/',local-name(.))"/> </xsl:comment-->
        <act classCode="DOCCLIN" moodCode="EVN">
            <templateId root="2.16.840.1.113883.2.4.6.10.70.9"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:code" mode="copy"/>
            <xsl:apply-templates select="hl7:effectiveTime" mode="copy"/>
            <xsl:apply-templates select="hl7:text" mode="copy"/>
            <!-- NOT mapping encounter/dataEnterer -->
            <xsl:for-each select="hl7:performer">
                <performer typeCode="PRF" contextControlCode="OP">
                    <assignedEntity classCode="ASSIGNED">
                        <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedEntity"/>
                    </assignedEntity>
                </performer>
            </xsl:for-each>
            <xsl:for-each select="hl7:author">
                <author typeCode="AUT" contextControlCode="OP">
                    <assignedEntity classCode="ASSIGNED">
                        <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedEntity"/>
                    </assignedEntity>
                </author>
            </xsl:for-each>
            <xsl:for-each select="hl7:sourceOf[hl7:act]">
                <outboundRelationship typeCode="SUMM" contextConductionInd="true">
                    <xsl:apply-templates select="hl7:sourceOf/hl7:act" mode="ActivitySub"/>
                </outboundRelationship>
            </xsl:for-each>
        </act>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>NOTE: Not using for now ... not yet in PS spec. Copies act containing a document</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:act" mode="ActivitySub" name="ActivityActSub">
        <!-- NOTE: comments with contained variables not supported by Xalan-C -->
        <!--xsl:comment> source: <xsl:value-of select="concat(local-name(../..),'/',local-name(..),'/',local-name(.))"/> </xsl:comment-->
        <act classCode="DOCCLIN" moodCode="EVN">
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:code" mode="copy"/>
            <xsl:apply-templates select="hl7:effectiveTime" mode="copy"/>
            <xsl:apply-templates select="hl7:text" mode="copy"/>
            <!-- NOT mapping encounter/dataEnterer -->
            <xsl:for-each select="hl7:performer">
                <performer typeCode="PRF" contextControlCode="OP">
                    <assignedEntity classCode="ASSIGNED">
                        <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedEntity"/>
                    </assignedEntity>
                </performer>
            </xsl:for-each>
            <xsl:for-each select="hl7:author">
                <author typeCode="AUT" contextControlCode="OP">
                    <assignedEntity classCode="ASSIGNED">
                        <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedEntity"/>
                    </assignedEntity>
                </author>
            </xsl:for-each>
            <!-- recurse -->
            <xsl:for-each select="hl7:sourceOf[hl7:act]">
                <outboundRelationship typeCode="SUMM" contextConductionInd="true">
                    <xsl:apply-templates select="hl7:sourceOf/hl7:act" mode="ActivitySub"/>
                </outboundRelationship>
            </xsl:for-each>
        </act>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copies JournalEntry containing a journal entry</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:JournalEntry" name="ActivityJournalEntry">
        <!-- NOTE: comments with contained variables not supported by Xalan-C -->
        <!--xsl:comment> source: <xsl:value-of select="concat(local-name(../..),'/',local-name(..),'/',local-name(.))"/> </xsl:comment-->
        <observation classCode="OBS" moodCode="EVN">
            <templateId root="2.16.840.1.113883.2.4.6.10.70.4"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:apply-templates select="hl7:code" mode="copy"/>
            <xsl:apply-templates select="hl7:effectiveTime" mode="copy"/>
            <xsl:if test="hl7:value">
                <value>
                    <xsl:copy-of select="hl7:value/@*"/>
                    <xsl:attribute name="xsi:type">
                        <xsl:value-of select="'ED'"/>
                    </xsl:attribute>
                    <xsl:apply-templates select="hl7:value/node()" mode="copy"/>
                </value>
            </xsl:if>
            <!-- NOT mapping encounter/dataEnterer -->
            <xsl:for-each select="hl7:performer">
                <performer typeCode="PRF" contextControlCode="ON">
                    <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedPersonIdentified2AssignedEntity"/>
                </performer>
            </xsl:for-each>
            <xsl:for-each select="hl7:author">
                <author typeCode="AUT" contextControlCode="ON">
                    <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedPersonIdentified2AssignedEntity"/>
                </author>
            </xsl:for-each>
        </observation>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copies observation containing a lab result</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:observation" mode="Activity" name="Activityobservation">
        <!-- NOTE: comments with contained variables not supported by Xalan-C -->
        <!--xsl:comment> source: <xsl:value-of select="concat(local-name(../..),'/',local-name(..),'/',local-name(.))"/> </xsl:comment-->
        <observation classCode="OBS" moodCode="EVN">
            <templateId root="2.16.840.1.113883.2.4.6.10.70.6"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <!-- NOTE: Found input instances with xsi:type="CE". Patching those to match both input/output spec of CD -->
            <xsl:for-each select="hl7:code">
                <code>
                    <xsl:copy-of select="@*"/>
                    <xsl:attribute name="xsi:type">
                        <xsl:value-of select="'CD'"/>
                    </xsl:attribute>
                    <xsl:apply-templates select="hl7:*" mode="copy"/>
                </code>
            </xsl:for-each>
            <xsl:apply-templates select="hl7:text[string-length(normalize-space(text()))&gt;0]" mode="copy"/>
            <xsl:apply-templates select="hl7:effectiveTime[.//@value or .//@nullFlavor]" mode="copy"/>
            <xsl:apply-templates select="hl7:value" mode="copy"/>
            <xsl:apply-templates select="hl7:interpretationCode" mode="copy"/>
            <xsl:apply-templates select="hl7:referenceRange" mode="copy"/>
            <!-- NOT mapping observation/dataEnterer -->
            <!-- NOT mapping observation/performer -->
            <xsl:for-each select="hl7:author/hl7:assignedEntity1">
                <author typeCode="AUT" contextControlCode="OP">
                    <time nullFlavor="NI"/>
                    <modeCode nullFlavor="NI"/>
                    <signatureCode nullFlavor="NI"/>
                    <assignedEntity classCode="ASSIGNED">
                        <xsl:apply-templates select="." mode="R_AssignedEntity"/>
                    </assignedEntity>
                </author>
            </xsl:for-each>
        </observation>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Copies ObservationDx containing a diagnosis</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:ObservationDx" name="ActivityObservationDx">
        <!-- NOTE: comments with contained variables not supported by Xalan-C -->
        <!--xsl:comment> source: <xsl:value-of select="concat(local-name(../..),'/',local-name(..),'/',local-name(.))"/> </xsl:comment-->
        <observation classCode="OBS" moodCode="EVN">
            <templateId root="2.16.840.1.113883.2.4.6.10.70.5"/>
            <xsl:apply-templates select="hl7:id" mode="copy"/>
            <xsl:choose>
                <!-- There have examples without @codeSystem. This should never occur in production, but patching anyway just in case -->
                <xsl:when test="hl7:code[not(@codeSystem) and (@code='ADMDX' or @code='DISDX')]">
                    <code>
                        <xsl:attribute name="codeSystem">
                            <xsl:value-of select="'2.16.840.1.113883.5.4'"/>
                        </xsl:attribute>
                        <xsl:copy-of select="hl7:code/@*"/>
                    </code>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="hl7:code" mode="copy"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:if test="hl7:value/@displayName">
                <text><xsl:value-of select="hl7:value/@displayName"/></text>
            </xsl:if>
            <xsl:if test="hl7:effectiveTime[.//@value or .//@nullFlavor]">
                <effectiveTime>
                    <xsl:copy-of select="hl7:effectiveTime/@*"/>
                    <xsl:attribute name="xsi:type">
                        <xsl:value-of select="'IVL_TS'"/>
                    </xsl:attribute>
                    <xsl:apply-templates select="hl7:effectiveTime/node()" mode="copy"/>
                </effectiveTime>
            </xsl:if>
            <xsl:choose>
                <xsl:when test="hl7:value">
                    <value>
                        <xsl:copy-of select="hl7:value/@*"/>
                        <xsl:attribute name="xsi:type">
                            <xsl:value-of select="'CE'"/>
                        </xsl:attribute>
                        <xsl:apply-templates select="hl7:value/node()" mode="copy"/>
                    </value>
                </xsl:when>
                <xsl:otherwise>
                    <value xsi:type="CE" nullFlavor="UNK"/>
                </xsl:otherwise>
            </xsl:choose>
            <xsl:for-each select="hl7:performer">
                <performer typeCode="PRF" contextControlCode="ON">
                    <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedPersonIdentified"/>
                </performer>
            </xsl:for-each>
            <xsl:for-each select="hl7:author">
                <author typeCode="AUT" contextControlCode="ON">
                    <!-- NOTE: time is mandatory in output, but optional in input, Now getting the century part of diagnosis itself, which is pretty meaningless, but validates -->
                    <xsl:choose>
                        <xsl:when test="hl7:time/@value">
                            <xsl:apply-templates select="hl7:time" mode="copy"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <time value="{substring((parent::hl7:ObservationDx/hl7:effectiveTime//@value)[1],1,2)}"/>
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:apply-templates select="hl7:AssignedPerson" mode="R_AssignedPersonIdentified2AssignedEntity"/>
                    <xsl:apply-templates select="hl7:Patient" mode="R_PatientNLIdentified"/>
                </author>
            </xsl:for-each>
        </observation>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Patch effectiveTime for common mistakes: have low and high with just a date+hour, date+hour+minute, or just a date. Fix by making low start of the day and high end of the day because that's what it semantically is anyway</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:effectiveTime" name="effectiveTime">
        <xsl:param name="xsiType" select="''"/>
        <xsl:choose>
            <xsl:when test="hl7:low/@value=hl7:high/@value and string-length(hl7:low/@value)=12 and translate(hl7:low/@value,'0123456789','')=''">
                <!-- patch date+hour+minute and overwrite xsi:type if not '' -->
                <effectiveTime>
                    <xsl:copy-of select="@*"/>
                    <xsl:if test="not($xsiType='')">
                        <xsl:attribute name="xsi:type">
                            <xsl:value-of select="$xsiType"/>
                        </xsl:attribute>
                    </xsl:if>
                    <low>
                        <xsl:copy-of select="hl7:low/@*"/>
                        <xsl:attribute name="value">
                            <xsl:value-of select="concat(hl7:low/@value,'00')"/>
                        </xsl:attribute>
                    </low>
                    <high>
                        <xsl:copy-of select="hl7:high/@*"/>
                        <xsl:attribute name="value">
                            <xsl:value-of select="concat(hl7:high/@value,'59')"/>
                        </xsl:attribute>    
                    </high>
                </effectiveTime>
            </xsl:when>
            <xsl:when test="hl7:low/@value=hl7:high/@value and string-length(hl7:low/@value)=10 and translate(hl7:low/@value,'0123456789','')=''">
                <!-- patch date+hour and overwrite xsi:type if not '' -->
                <effectiveTime>
                    <xsl:copy-of select="@*"/>
                    <xsl:if test="not($xsiType='')">
                        <xsl:attribute name="xsi:type">
                            <xsl:value-of select="$xsiType"/>
                        </xsl:attribute>
                    </xsl:if>
                    <low>
                        <xsl:copy-of select="hl7:low/@*"/>
                        <xsl:attribute name="value">
                            <xsl:value-of select="concat(hl7:low/@value,'0000')"/>
                        </xsl:attribute>
                    </low>
                    <high>
                        <xsl:copy-of select="hl7:high/@*"/>
                        <xsl:attribute name="value">
                            <xsl:value-of select="concat(hl7:high/@value,'5959')"/>
                        </xsl:attribute>    
                    </high>
                </effectiveTime>
            </xsl:when>
            <xsl:when test="hl7:low/@value=hl7:high/@value and string-length(hl7:low/@value)=8 and translate(hl7:low/@value,'0123456789','')=''">
                <!-- patch date and overwrite xsi:type if not '' -->
                <effectiveTime>
                    <xsl:copy-of select="@*"/>
                    <xsl:if test="not($xsiType='')">
                        <xsl:attribute name="xsi:type">
                            <xsl:value-of select="$xsiType"/>
                        </xsl:attribute>
                    </xsl:if>
                    <low>
                        <xsl:copy-of select="hl7:low/@*"/>
                        <xsl:attribute name="value">
                            <xsl:value-of select="concat(hl7:low/@value,'000000')"/>
                        </xsl:attribute>
                    </low>
                    <high>
                        <xsl:copy-of select="hl7:high/@*"/>
                        <xsl:attribute name="value">
                            <xsl:value-of select="concat(hl7:high/@value,'235959')"/>
                        </xsl:attribute>    
                    </high>
                </effectiveTime>
            </xsl:when>
            <xsl:when test="not($xsiType='')">
                <!-- just overwrite xsi:type -->
                <effectiveTime>
                    <xsl:copy-of select="@*"/>
                    <xsl:if test="not($xsiType='')">
                        <xsl:attribute name="xsi:type">
                            <xsl:value-of select="$xsiType"/>
                        </xsl:attribute>
                    </xsl:if>
                    <xsl:apply-templates select="hl7:*" mode="copy"/>
                </effectiveTime>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates select="self::hl7:effectiveTime" mode="copy"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Patch Encounter code for common mistakes</xd:p>
            <xd:ul>
                <xd:li><xd:pre>&lt;code="99" codeSystem="2.16.840.1.113883.2.4.4.30.14" displayName="..."/&gt;</xd:pre> is translated into 
                    <xd:pre>&lt;code nullFlavor="OTH" codeSystem="2.16.840.1.113883.2.4.4.30.14"&gt;
    &lt;originalText&gt;...&lt;/originalText&gt;
&lt;/code&gt;</xd:pre></xd:li>
                <xd:li><xd:pre>&lt;code="n" codeSystem="2.16.840.1.113883.2.4.4.30.14" displayName="..."/&gt;</xd:pre> is translated into
                    <xd:pre>&lt;code="0n" codeSystem="2.16.840.1.113883.2.4.4.30.14" displayName="..."/&gt;</xd:pre></xd:li>
                <xd:li><xd:pre>&lt;code="nnn" codeSystem="2.16.840.1.113883.2.4.4.30.14" displayName="..."/&gt;</xd:pre> is translated into
                    <xd:pre>&lt;code nullFlavor="OTH" codeSystem="2.16.840.1.113883.2.4.4.30.14"&gt;
    &lt;translation code="nnn" codeSystem="2.16.840.1.113883.2.4.4.30.15" displayName="..."/&gt;
&lt;/code&gt;</xd:pre></xd:li>
                <xd:li>Copy as-is</xd:li>
            </xd:ul>
        </xd:desc>
    </xd:doc>
    <xsl:template match="hl7:code" mode="EncounterCode" name="EncounterCode">
        <xsl:choose>
            <xsl:when test="@code='99' and @codeSystem='2.16.840.1.113883.2.4.4.30.14'">
                <!-- Patch for EncounterCode. code="99" displayName="overig" was legal in v3, but not in the target v7. In v7 this should copy into nullFlavor="OTH" -->
                <code nullFlavor="OTH" codeSystem="2.16.840.1.113883.2.4.4.30.14">
                    <xsl:if test="@displayName">
                        <originalText>
                            <xsl:value-of select="@displayName"/>
                        </originalText>
                    </xsl:if>
                    <xsl:apply-templates select="hl7:translation" mode="copy"/>
                </code>
            </xsl:when>
            <xsl:when test="string-length(@code)=1 and translate(@code,'123456789','')='' and @codeSystem='2.16.840.1.113883.2.4.4.30.14'">
                <!-- Patch for EncounterCode. code="1-9" codeSystem="2.16.840.1.113883.2.4.4.30.14" was never legal, but some systems apparently had a numeric code thus omitting the leading zero in the zero -->
                <code>
                    <xsl:copy-of select="@*"/>
                    <xsl:attribute name="code">
                        <xsl:value-of select="concat('0',@code)"/>
                    </xsl:attribute>
                    <xsl:apply-templates select="hl7:*" mode="copy"/>
                </code>
            </xsl:when>
            <xsl:when test="string-length(@code)=3 and translate(@code,'0123456789','')='' and @codeSystem='2.16.840.1.113883.2.4.4.30.14'">
                <!-- Patch for EncounterCode. code="nnn" codeSystem="2.16.840.1.113883.2.4.4.30.14" was never legal, but some systems apparently implemented Codesystem Tabel 15 as-if it were CodeSystem Tabel 14 -->
                <code nullFlavor="OTH" codeSystem="2.16.840.1.113883.2.4.4.30.14">
                    <translation code="{@code}" codeSystem="2.16.840.1.113883.2.4.4.30.15" displayName="{@displayName}"/>
                </code>
            </xsl:when>
            <xsl:otherwise>
                <xsl:apply-templates select="self::hl7:*" mode="copy"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Carbon copy without copying namespaces</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="text()|comment()|processing-instruction()" mode="copy">
        <xsl:copy-of select="."/>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Carbon copy without copying namespaces</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template match="*" mode="copy">
        <xsl:element name="{local-name(self::*)}">
            <xsl:copy-of select="@*"/>
            <xsl:apply-templates select="node()" mode="copy"/>
        </xsl:element>
    </xsl:template>
    
    <xd:doc>
        <xd:desc>
            <xd:p>Sanity check on parameters</xd:p>
        </xd:desc>
    </xd:doc>
    <xsl:template name="sanityCheck">
        <xsl:if test="string-length($g_outputInteractionId)=0">
            <xsl:message terminate="yes">[error] Required parameter g_outputInteractionId MUST have a value, e.g. 'QUPC_IN443230NL'. Exiting...</xsl:message>
        </xsl:if>
        <xsl:if test="not(string-length($g_tsToday)=14 and translate($g_tsToday,'0123456789','')='')">
            <xsl:message terminate="yes">[error] Required parameter g_tsToday MUST have the format YYYYMMddhhmmss (14 long and numeric). Found '<xsl:value-of select="$g_tsToday"/>'. Exiting...</xsl:message>
        </xsl:if>
    </xsl:template>
</xsl:stylesheet>