#!/bin/sh

# -----------------------------------------
# --  set defaults                       --
# -----------------------------------------

# These are used on the command line
export inputDir=../../xml-WDH
export outputDir=../../xml-WDH-CP

# These are used on the command line and must contain a forward slash in path
export jarDir=../lib
export xslDir=.

# -------------------------------------------
# --  use input params instead of defaults --
# --  if given                             --
# -------------------------------------------

if [ ! $1 = '' ]; then export inputDir=$1; fi
if [ ! $2 = '' ]; then export outputDir=$2; fi
if [ ! $3 = '' ]; then export jarDir=$5; fi
if [ ! $4 = '' ]; then export xslDir=$6; fi

echo "Input directory                 = ${inputDir}"
echo "Output directory                = ${outputDir}"
echo "Java jar path                   = $jarDir"
echo "XSL path                        = $xslDir"

# -------------------------------------------
# --  check input and output dirs          --
# --                                       --
# -------------------------------------------

if [ ! -e "${inputDir}" ]; then 
    echo ERROR The input directory \'${inputDir}\' does not exist or is empty!
    exit
fi

if [ "${inputDir}" = "${outputDir}" ]; then
    echo ERROR The input directory must not be equal to the output directory!
    exit
fi

if [ ! -e "${outputDir}" ]; then 
    echo "\nCreating output directory ${outputDir}..."
    echo "-----------------------\n"
    mkdir "${outputDir}"
else
    echo "\nRemoving contents of output directory ${outputDir}..."
    echo "-----------------------\n"
    rm ${outputDir}/*.*
fi

# -------------------------------------------
# --  generate output                      --
# --                                       --
# -------------------------------------------

echo "Transforming examples..."
for file in `ls ${inputDir}/*990002*.xml` ; do
    echo "    Processing `basename $file`..."
    java -jar ${jarDir}/saxon-6/saxon.jar -s:$file -xsl:${xslDir}/PrimaryCareProvision2CareProvision-XSLT1.0.xsl -o:${outputDir}/`basename $file` g_outputInteractionId=QUPC_IN443230NL g_tsToday=`date '+%Y%m%d%H%M%S'`
done

