<?xml version="1.0"?>
<!-- NB java decalaration requires Xalan as XSLT processor 
    Use this stylesheet to 'actualize' a REPC_MT000001NL type message
    The reference date for the examples (REPC_EX000001NL-1, REPC_EX000001NL-2 etc.)
    is 8 oct 2004. This styleysheet calculates the difference in days between the 
    reference date and now. This number of days is then added to all ts types.
    
    
    Copyright 2005 Nictiz
    
    author: Gerrit Boers
    
    acknowledgements: Sal Mangano; XSLT Cookbook
    
    version information:
    
    31-8-05    version 1.0
    
-->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0"
    xmlns:hl7="urn:hl7-org:v3" xmlns:date="http://www.ora.com/XSLTCookbook/namespaces/date"
    xmlns:cal="java:java.util.GregorianCalendar">
    <xsl:output method="xml"/>
    <xsl:include href="date.date-time.xslt"/>
    <xsl:strip-space elements="*"/>
    <!-- reference date is 8 october 2004 EMD congress -->
    <xsl:variable name="referenceDate" select="'2004-10-8'"/>
    <xsl:variable name="today">
        <xsl:call-template name="getToday"/>
    </xsl:variable>
    <xsl:variable name="daysToAdd">
        <xsl:call-template name="date:date-difference">
            <xsl:with-param name="from-year" select="substring-before($today,'-')"/>
            <xsl:with-param name="from-month"
                select="substring-before(substring-after($today,'-'),'-')"/>
            <xsl:with-param name="from-day"
                select="substring-after(substring-after($today,'-'),'-')"/>
            <xsl:with-param name="to-year" select="substring-before($referenceDate,'-')"/>
            <xsl:with-param name="to-month"
                select="substring-before(substring-after($referenceDate,'-'),'-')"/>
            <xsl:with-param name="to-day"
                select="substring-after(substring-after($referenceDate,'-'),'-')"/>
        </xsl:call-template>
    </xsl:variable>
    <xsl:template match="@*|node()">
        <xsl:copy>
            <xsl:choose>
                <!-- birthTime -->
                <xsl:when test="@value and name(.)='birthTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- time in participations TS -->
                <xsl:when test="@value and name(.)='time'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- availabilityTime TS -->
                <xsl:when test="@value and name(.)='availabilityTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- effectiveTime TS -->
                <xsl:when test="@value and name(.)='effectiveTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- effectiveTime IVL(TS) -->
                <xsl:when test="@value and name(.)='low' and name(..)='effectiveTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="@value and name(.)='high' and name(..)='effectiveTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="@value and name(.)='center' and name(..)='effectiveTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- expectedUseTime IVL(TS) -->
                <xsl:when test="@value and name(.)='low' and name(..)='expectedUseTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="@value and name(.)='high' and name(..)='expectedUseTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="@value and name(.)='center' and name(..)='expectedUseTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- effectiveTime COMP IVL(TS) -->
                <xsl:when test="@value and name(.)='low' and name(..)='comp'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="@value and name(.)='high' and name(..)='comp'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="@value and name(.)='center' and name(..)='comp'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- activityTime IVL(TS) -->
                <xsl:when test="@value and name(.)='low' and name(..)='activityTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="@value and name(.)='high' and name(..)='activityTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="@value and name(.)='center' and name(..)='activityTime'">
                    <xsl:call-template name="addDaysToHL7Date">
                        <xsl:with-param name="hl7date" select="@value"/>
                        <xsl:with-param name="days2add" select="$daysToAdd"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="@*|node()"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:copy>
    </xsl:template>
    <xsl:template name="addDaysToHL7Date">
        <xsl:param name="hl7date"/>
        <xsl:param name="days2add"/>
        <!-- test length of hl7date, add if needed -->
        <xsl:variable name="date">
            <xsl:choose>
                <xsl:when test="string-length($hl7date)=8">
                    <!-- complete date -->
                    <xsl:value-of select="$hl7date"/>
                </xsl:when>
                <xsl:when test="string-length($hl7date)=6">
                    <!-- only yyyymm, add 15 (middle of month) -->
                    <xsl:value-of select="concat($hl7date,'15')"/>
                </xsl:when>
                <xsl:when test="string-length($hl7date)=4">
                    <!-- only yyyy, add 0701 (middle of year) -->
                    <xsl:value-of select="concat($hl7date,'0701')"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="substring($hl7date,1,8)"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="jDay">
            <xsl:call-template name="date:calculate-julian-day">
                <xsl:with-param name="year" select="substring($date,1,4)"/>
                <xsl:with-param name="month" select="substring($date,5,2)"/>
                <xsl:with-param name="day" select="substring($date,7,2)"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="resultDate">
            <xsl:call-template name="date:julian-day-to-julian-date">
                <xsl:with-param name="j-day" select="$jDay+$days2add+13"/>
            </xsl:call-template>
        </xsl:variable>
        <xsl:variable name="resultYear">
            <xsl:value-of select="substring-before($resultDate,'/')"/>
        </xsl:variable>
        <xsl:variable name="resultMonth">
            <xsl:choose>
                <xsl:when
                    test="string-length(substring-before(substring-after($resultDate,'/'),'/'))=1">
                    <xsl:value-of
                        select="concat('0',substring-before(substring-after($resultDate,'/'),'/'))"
                    />
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="substring-before(substring-after($resultDate,'/'),'/')"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="resultDay">
            <xsl:choose>
                <xsl:when
                    test="string-length(substring-after(substring-after($resultDate,'/'),'/'))=1">
                    <xsl:value-of
                        select="concat('0',substring-after(substring-after($resultDate,'/'),'/'))"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="substring-after(substring-after($resultDate,'/'),'/')"/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="hl7Result">
            <xsl:choose>
                <xsl:when test="string-length($hl7date)=4">
                    <xsl:value-of select="$resultYear"/>
                </xsl:when>
                <xsl:when test="string-length($hl7date)=6">
                    <xsl:value-of select="concat($resultYear,$resultMonth)"/>
                </xsl:when>
                <xsl:when test="string-length($hl7date)=8">
                    <xsl:value-of select="concat($resultYear,$resultMonth,$resultDay)"/>
                </xsl:when>
                <xsl:when test="string-length($hl7date)>8">
                    <xsl:value-of
                        select="concat($resultYear,$resultMonth,$resultDay,substring($hl7date,9,(string-length($hl7date)-8)))"
                    />
                </xsl:when>
            </xsl:choose>
        </xsl:variable>
        <xsl:attribute name="value">
            <xsl:value-of select="$hl7Result"/>
        </xsl:attribute>
    </xsl:template>
    <xsl:template name="getToday">
        <xsl:variable name="rightNow" select="cal:getInstance()"/>
        <xsl:variable name="month" select="cal:get($rightNow, 2) + 1"/>
        <xsl:variable name="day" select="cal:get($rightNow, 5)"/>
        <xsl:variable name="year" select="cal:get($rightNow, 1)"/>
        <xsl:value-of select="$year"/>-<xsl:value-of select="$month"/>-<xsl:value-of select="$day"/>
    </xsl:template>
</xsl:stylesheet>
